{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "bf0d66b6",
   "metadata": {},
   "source": [
    "(HW2_2024)=\n",
    "# HW2\n",
    "\n",
    "**Deadline:** 03.11.2024 23:59 (GMT+5).\n",
    "\n",
    "**DO NOT ERASE ANY EXISTING CELLS!** \n",
    "\n",
    "In this task you are suggested to implement gradient descent and Newton's optimization methods, and investigate their performance for three types of functions:\n",
    "\n",
    "* quadratic function\n",
    "* loss function of linear regression\n",
    "* loss function of logistic regression\n",
    "\n",
    "`BaseSmoothOracle` is an abstract class for objective function $f$ (**oracle**). Each concrete oracle must inherit this class, implementing four methods:\n",
    "\n",
    "* `func(x)` calculates $f(\\boldsymbol x)$\n",
    "* `grad(x)` calculates $\\nabla f(\\boldsymbol x)$\n",
    "* `hess(x)` calculates $\\nabla^2 f(\\boldsymbol x)$\n",
    "* `get_opt(x)` calculates point of minimum by direct formula (works only for quadratic and linear regression oracles)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "1fe4a9b0",
   "metadata": {},
   "outputs": [],
   "source": [
    "class BaseSmoothOracle(object):\n",
    "    \"\"\"\n",
    "    Base class for implementation of oracles.\n",
    "    \"\"\"\n",
    "    def func(self, x):\n",
    "        \"\"\"\n",
    "        Computes the value of function at point x.\n",
    "        \"\"\"\n",
    "        raise NotImplementedError('Func oracle is not implemented.')\n",
    "\n",
    "    def grad(self, x):\n",
    "        \"\"\"\n",
    "        Computes the gradient at point x.\n",
    "        \"\"\"\n",
    "        raise NotImplementedError('Grad oracle is not implemented.')\n",
    "    \n",
    "    def hess(self, x):\n",
    "        \"\"\"\n",
    "        Computes the Hessian matrix at point x.\n",
    "        \"\"\"\n",
    "        raise NotImplementedError('Hessian oracle is not implemented.')\n",
    "        \n",
    "    def get_opt(self):\n",
    "        \"\"\"\n",
    "        Computes the point x at which minimum is attained\n",
    "        \"\"\"\n",
    "        raise NotImplementedError('True solution is unavailable.')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "9eec57e0",
   "metadata": {},
   "source": [
    "## Quadratic oracle\n",
    "\n",
    "### Task 2.1 (1 point)\n",
    "\n",
    "Implement quadratic oracle\n",
    "\n",
    "```{math}\n",
    ":label: quadratic-oracle\n",
    "    f(\\boldsymbol x) = \\frac 12 \\boldsymbol x^\\mathsf{T} \\boldsymbol{Ax} - \\boldsymbol b^\\mathsf{T} \\boldsymbol x, \\quad \\boldsymbol A^\\mathsf{T}  = \\boldsymbol A \\in \\mathbb R^{n\\times n}, \\quad \\boldsymbol b\\in\\mathbb R^n\n",
    "```\n",
    "\n",
    "<!-- Let $\\boldsymbol A$ be a symmetric positive definite matrix. Solve the optimization task\n",
    "\n",
    "$$\n",
    "    f(\\boldsymbol x) = \\frac 12 \\boldsymbol x^\\mathsf{T} \\boldsymbol{Ax} - \\boldsymbol b^\\mathsf{T}\\boldsymbol x \\to \\min\\limits_{\\boldsymbol x \\in \\mathbb R^n}\n",
    "$$\n",
    "\n",
    "analytically. Namely, -->\n",
    "\n",
    "Namely,\n",
    "\n",
    "* find solution $\\boldsymbol x_*$ of the equation $\\nabla f(\\boldsymbol x) = \\boldsymbol 0$ \n",
    "* find hessian $\\nabla^2 f$ and show that $\\nabla^2 f(\\boldsymbol x_*)$ is positive definite\n",
    "* prove that $\\boldsymbol x_*$ is the point of global minimum of $f$\n",
    "* finally, fill the gaps in cell below"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "4986f05e",
   "metadata": {},
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "\n",
    "class QuadraticOracle(BaseSmoothOracle):\n",
    "    \"\"\"\n",
    "    Oracle for quadratic function:\n",
    "       func(x) = 1/2 x^TAx - b^Tx.\n",
    "    \"\"\"\n",
    "\n",
    "    def __init__(self, A, b):\n",
    "        if not np.allclose(A, A.T):\n",
    "            raise ValueError('A should be a symmetric matrix.')\n",
    "        self.A = A\n",
    "        self.b = b\n",
    "\n",
    "    def func(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass\n",
    "\n",
    "    def grad(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass\n",
    "\n",
    "    def hess(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass\n",
    "    \n",
    "    def get_opt(self):\n",
    "        # YOUR CODE HERE\n",
    "        pass"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "d7df142c",
   "metadata": {},
   "source": [
    "Plot levels of the quadraric oracle in 2-dimensional case using the following function:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "fc39e08b",
   "metadata": {
    "tags": [
     "remove-input"
    ]
   },
   "outputs": [],
   "source": [
    "import matplotlib.pyplot as plt\n",
    "%config InlineBackend.figure_format = 'svg'\n",
    "\n",
    "def plot_levels(func, xrange=None, yrange=None, levels=None):\n",
    "    \"\"\"\n",
    "    Plotting the contour lines of the function.\n",
    "\n",
    "    Example:\n",
    "    --------\n",
    "    >> oracle = QuadraticOracle(np.array([[1.0, 2.0], [2.0, 5.0]]), np.zeros(2))\n",
    "    >> plot_levels(oracle.func)\n",
    "    \"\"\"\n",
    "    if xrange is None:\n",
    "        xrange = [-6, 6]\n",
    "    if yrange is None:\n",
    "        yrange = [-5, 5]\n",
    "    if levels is None:\n",
    "        levels = [0, 0.25, 1, 4, 9, 16, 25]\n",
    "        \n",
    "    x = np.linspace(xrange[0], xrange[1], 100)\n",
    "    y = np.linspace(yrange[0], yrange[1], 100)\n",
    "    X, Y = np.meshgrid(x, y)\n",
    "    Z = np.zeros(X.shape)\n",
    "    for i in range(Z.shape[0]):\n",
    "        for j in range(Z.shape[1]):\n",
    "            Z[i, j] = func(np.array([X[i, j], Y[i, j]]))\n",
    "\n",
    "    CS = plt.contour(X, Y, Z, levels=levels, colors='k')\n",
    "    plt.clabel(CS, inline=1, fontsize=8) \n",
    "    plt.grid()   "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "c036fa89",
   "metadata": {},
   "source": [
    "## Linear regression oracle\n",
    "\n",
    "### Task 2.2 (1.5 points)\n",
    "\n",
    "Implement linear regression oracle\n",
    "\n",
    "$$\n",
    "    f(\\boldsymbol x) = \\frac 1m \\Vert \\boldsymbol{Ax} - \\boldsymbol b\\Vert_2^2, \\quad \\boldsymbol A \\in \\mathbb R^{m\\times n}, \\quad \\boldsymbol b \\in \\mathbb R^n.\n",
    "$$\n",
    "\n",
    "Namely,\n",
    "\n",
    "* find $\\nabla f(\\boldsymbol x)$\n",
    "* find $\\nabla^2 f(\\boldsymbol x)$\n",
    "* find analytic solution of the minimization problem $f(\\boldsymbol x) \\to \\min\\limits_{\\boldsymbol x}$\n",
    "* finally, fill the gaps in the next cell"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "db56aa11",
   "metadata": {
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [],
   "source": [
    "class LinRegOracle(BaseSmoothOracle):\n",
    "    \"\"\"\n",
    "    Oracle for linear regression:\n",
    "       func(x) = 1/m ||Ax - b||^2.\n",
    "    \"\"\"\n",
    "\n",
    "    def __init__(self, A, b):\n",
    "        self.A = A\n",
    "        self.b = b\n",
    "\n",
    "    def func(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass\n",
    "\n",
    "    def grad(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass\n",
    "\n",
    "    def hess(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass\n",
    "    \n",
    "    def get_opt(self):\n",
    "        # YOUR CODE HERE\n",
    "        pass"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "c45bf248",
   "metadata": {},
   "source": [
    "## Logistic regression oracle\n",
    "\n",
    "### Task 2.3 (1.5 point)\n",
    "\n",
    "Implement logistic regression oracle\n",
    "\n",
    "```{math}\n",
    ":label: log-reg-oracle\n",
    "    f(\\boldsymbol x) = \\frac 1m \\sum_{i=1}^m \\log\\big(1 + \\exp(-b_i\\boldsymbol a_i^\\mathsf{T} \\boldsymbol x)\\big) + \\frac C2\\Vert \\boldsymbol x\\Vert_2^2\n",
    "```\n",
    "\n",
    "Namely, denote\n",
    "\n",
    "$$\n",
    "    \\boldsymbol A = \\begin{pmatrix} a_1^\\mathsf{T} \\\\\n",
    "    a_2^\\mathsf{T} \\\\\n",
    "    \\vdots\\\\\n",
    "    a_m^\\mathsf{T}\n",
    "    \\end{pmatrix} \\in \\mathbb R^{m\\times n}, \\quad\n",
    "    \\boldsymbol b = \\begin{pmatrix} b_1 \\\\\n",
    "    b_2\\\\\n",
    "    \\vdots\\\\\n",
    "    b_m\n",
    "    \\end{pmatrix}\\in \\mathbb R^m,\n",
    "    \\quad\n",
    "    \\boldsymbol x = \\begin{pmatrix} x_1 \\\\\n",
    "    x_2\\\\\n",
    "    \\vdots\\\\\n",
    "    x_n\n",
    "    \\end{pmatrix}\\in \\mathbb R^n,\n",
    "$$\n",
    "\n",
    "and then\n",
    "\n",
    "* find the gradient $\\nabla f(\\boldsymbol x)$ and hessian $\\nabla^2 f(\\boldsymbol x)$ of logistic regression oracle {eq}`log-reg-oracle` in matrix-vector form\n",
    "* fill the gaps in the cell below "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 59,
   "id": "9f1e7293",
   "metadata": {
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [],
   "source": [
    "from sklearn.linear_model import LogisticRegression\n",
    "from sklearn.metrics import log_loss\n",
    "from scipy.special import expit\n",
    "\n",
    "class LogRegOracle(BaseSmoothOracle):\n",
    "    \"\"\"\n",
    "    Oracle for logistic regression.\n",
    "    \"\"\"\n",
    "\n",
    "    def __init__(self, A, b, regcoef=1):\n",
    "        self.A = A\n",
    "        self.b = b\n",
    "        self.C = regcoef\n",
    "\n",
    "    def func(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass\n",
    "\n",
    "    def grad(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass\n",
    "\n",
    "    def hess(self, x):\n",
    "        # YOUR CODE HERE\n",
    "        pass \n",
    "    \n",
    "    def get_opt(self):\n",
    "        \"\"\"\n",
    "        Since there is no analytic solution for the optimal weights of logistic regression, \n",
    "        here we have to cheat a bit\n",
    "        \"\"\"\n",
    "        LR = LogisticRegression(fit_intercept=False, C= 1./self.C/self.A.shape[0])\n",
    "        LR.fit(self.A, (self.b + 1) / 2)\n",
    "        return LR.coef_[0]"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "cebd2b22",
   "metadata": {},
   "source": [
    "## Gradient descent\n",
    "\n",
    "Given a starting point $\\boldsymbol x_0 \\in\\mathbb R^n$ and learning rate $\\eta > 0$, iteratively calculate\n",
    "\n",
    "$$\n",
    "    \\boldsymbol x_{k+1} = \\boldsymbol x_k - \\eta \\nabla f(\\boldsymbol x_k), \\quad k = 0, 1,\\ldots\n",
    "$$\n",
    "\n",
    "The process should stop when either $k = \\mathrm{max\\_iter}$ or \n",
    "\n",
    "$$\n",
    "\\Vert \\nabla f(\\boldsymbol x_k)\\Vert_2^2 \\leqslant \\varepsilon \\Vert \\nabla f(\\boldsymbol x_0)\\Vert_2^2\n",
    "$$\n",
    "\n",
    "where $\\varepsilon > 0$ is tolerance.\n",
    "\n",
    "### Task 2.4 (1 point)\n",
    "\n",
    "Complete the implementation of gradient descent algorithm."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "6794e3a4",
   "metadata": {},
   "outputs": [],
   "source": [
    "from datetime import datetime\n",
    "from collections import defaultdict\n",
    "\n",
    "def gradient_descent(oracle, x_0, learning_rate, tolerance=1e-5, max_iter=10000,\n",
    "                     trace=False, display=False):\n",
    "    \"\"\"\n",
    "    Gradient descent optimization method.\n",
    "\n",
    "    Parameters\n",
    "    ----------\n",
    "    oracle : BaseSmoothOracle-descendant object\n",
    "        Oracle with .func(), .grad() and .hess() methods implemented for computing\n",
    "        function value, its gradient and Hessian respectively.\n",
    "    x_0 : np.array\n",
    "        Starting point for optimization algorithm.\n",
    "    learning_rate : float\n",
    "        Learning rate.\n",
    "    tolerance : float\n",
    "        Epsilon value for stopping criterion.\n",
    "    max_iter : int\n",
    "        Maximum number of iterations.\n",
    "    trace : bool\n",
    "        If True, the progress information is appended into history dictionary during training.\n",
    "        Otherwise None is returned instead of history.\n",
    "    display : bool\n",
    "        If True, debug information is displayed during optimization.\n",
    "        Printing format and is up to a student and is not checked in any way.\n",
    "\n",
    "    Returns\n",
    "    -------\n",
    "    x_star : np.array\n",
    "        The point found by the optimization procedure\n",
    "    message : string\n",
    "        \"success\" or the description of error:\n",
    "            - 'iterations_exceeded': if after max_iter iterations of the method x_k still doesn't satisfy\n",
    "                the stopping criterion.\n",
    "            - 'computational_error': in case of getting Infinity or None value during the computations.\n",
    "    history : dictionary of lists or None\n",
    "        Dictionary containing the progress information or None if trace=False.\n",
    "        Dictionary has to be organized as follows:\n",
    "            - history['time'] : list of floats, containing time in seconds passed from the start of the method\n",
    "            - history['func'] : list of function values f(x_k) on every step of the algorithm\n",
    "            - history['grad_norm'] : list of values Euclidian norms ||g(x_k)|| of the gradient on every step of the algorithm\n",
    "            - history['x'] : list of np.arrays, containing the trajectory of the algorithm. ONLY STORE IF x.size <= 2\n",
    "\n",
    "    Example:\n",
    "    --------\n",
    "    >> oracle = QuadraticOracle(np.eye(5), np.arange(5))\n",
    "    >> x_opt, message, history = gradient_descent(oracle, np.zeros(5))\n",
    "    >> print('Found optimal point: {}'.format(x_opt))\n",
    "       Found optimal point: [ 0.  1.  2.  3.  4.]\n",
    "    \"\"\"\n",
    "    history = defaultdict(list) if trace else None\n",
    "    x_k = np.copy(x_0)\n",
    "    grad_at_x_0 = oracle.grad(x_0)\n",
    "\n",
    "    INF = 1e100\n",
    "    start_time = datetime.now()\n",
    "\n",
    "    for i in range(max_iter + 1):     \n",
    "        grad_at_x_k = oracle.grad(x_k)\n",
    "        if np.any(np.abs(x_k) > INF) or np.any(np.abs(grad_at_x_k) > INF):\n",
    "            return x_k, 'computational_error', history\n",
    "\n",
    "        if trace:\n",
    "            history['time'].append((datetime.now() - start_time).microseconds * 1e-6)\n",
    "            history['func'].append(oracle.func(x_k))\n",
    "            history['grad_norm'].append(np.linalg.norm(grad_at_x_k))\n",
    "            if x_k.shape[0] <= 2:\n",
    "                history['x'].append(np.array(x_k))\n",
    "\n",
    "        if display:\n",
    "            print(\"iteration {}: |x_k-x_0| = {}, f(x_k) = {}, |grad(f(x_k))| = {}\".format(\n",
    "                i, np.linalg.norm(x_k - x_0), oracle.func(x_k), np.linalg.norm(grad_at_x_k))\n",
    "            )\n",
    "\n",
    "        # YOUR CODE HERE\n",
    "        pass"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "81fe4514",
   "metadata": {},
   "source": [
    "Now it's try to test gradient descent algorithm on different tasks. Here is some auxiliary code for visualization."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "4153de5b",
   "metadata": {},
   "outputs": [],
   "source": [
    "import colorsys\n",
    "\n",
    "def get_color_array(size):\n",
    "    HSV_tuples = [(float(i) / size, 1.0, 1.0) for i in range(size)]\n",
    "    RGB_tuples = list(map(lambda x: colorsys.hsv_to_rgb(*x), HSV_tuples))\n",
    "    return np.array(RGB_tuples)\n",
    "\n",
    "def plot_2d(history, oracle, x_0, x_opt, scale, title, n_levels=3, xlims=None, ylims=None, bound=None):\n",
    "    if bound is not None:\n",
    "        history['x'] = history['x'][:bound]\n",
    "    hist_x = np.array(history['x']).T\n",
    "    plt.figure(figsize=(12, 5))\n",
    "    plt.subplot(121)\n",
    "    \n",
    "    plt.plot(np.linalg.norm(hist_x - x_opt[:, None], axis=0), c='c', linewidth=3)\n",
    "    plt.plot(history['grad_norm'], c='m', linewidth=2)\n",
    "    plt.xlim(0, len(history['grad_norm']) - 1)\n",
    "    plt.ylim(0, 2)\n",
    "    plt.title(title)\n",
    "    plt.ylabel('Gradients/residuals norm')\n",
    "    plt.xlabel('Iteration')\n",
    "    plt.legend(['Residuals', 'Gradients'])\n",
    "    plt.grid(ls=\":\")\n",
    "    \n",
    "    plt.subplot(122)\n",
    "    if xlims is not None:\n",
    "        x_range = xlims\n",
    "    else:\n",
    "        x_range = [x_opt[0] - scale, x_opt[0] + scale]\n",
    "    if ylims is not None:\n",
    "        y_range = ylims\n",
    "    else:\n",
    "        y_range = [x_opt[1] - scale, x_opt[1] + scale]\n",
    "    func_opt = oracle.func(x_opt)\n",
    "    levels = [func_opt + 0.25 * scale / n_levels * i for i in range(1, 4*n_levels + 1, 4)]\n",
    "    # sizes = np.minimum(5 * float(hist_x.shape[1]) / (np.arange(1, hist_x.shape[1] + 1)), 20)\n",
    "    plt.scatter(hist_x[0], hist_x[1], s=8, c=get_color_array(hist_x.shape[1]))\n",
    "    plt.plot(hist_x[0], hist_x[1], alpha=0.6, ls=\"--\", c='r')\n",
    "    # plt.plot(hist_x[0], hist_x[1], c='r', linewidth=3)\n",
    "    plt.scatter(x_opt[0], x_opt[1], marker='s', c='r', edgecolors='k')\n",
    "    plot_levels(oracle.func, xrange=x_range, yrange=y_range, levels=levels)\n",
    "    plt.title('Trajectory')\n",
    "    plt.xlabel('x')\n",
    "    plt.ylabel('y')\n",
    "    plt.grid(ls=\":\")\n",
    "    if xlims is not None:\n",
    "        plt.xlim(xlims)\n",
    "    if ylims is not None:\n",
    "        plt.ylim(ylims)\n",
    "    plt.show()\n",
    "\n",
    "def test_2d(method, oracle, x_0, lr, tol=1e-5, scale=1.0, xlims=None, ylims=None, bound=None):\n",
    "    x_opt = oracle.get_opt()\n",
    "    if method == 'gd':\n",
    "        x_star, msg, history = gradient_descent(\n",
    "            oracle, x_0, lr, tol, trace=True\n",
    "        )\n",
    "    elif method == 'newton':\n",
    "        x_star, msg, history = newton(\n",
    "            oracle, x_0, lr, tol, trace=True\n",
    "        )\n",
    "    else:\n",
    "        raise ValueError(\"Unknown error\")\n",
    "    print(msg, len(history['grad_norm']), \"iterations\")\n",
    "    plot_2d(history, oracle, x_0, x_opt, scale, 'lr = {}'.format(lr), xlims=xlims, ylims=ylims, bound=bound)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "13bdf314",
   "metadata": {},
   "source": [
    "Take a simple quadratic function\n",
    "\n",
    "$$\n",
    "    f(x, y) = 2x^2 + 4xy + 5 y^2\n",
    "$$\n",
    "\n",
    "which ovbiously has minimum at $(0, 0)$. Now run gradient descent method with $\\eta = 0.01$, starting from point $(-2, -1)$:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "13ea22cd",
   "metadata": {
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [
    {
     "ename": "NameError",
     "evalue": "name 'np' is not defined",
     "output_type": "error",
     "traceback": [
      "\u001b[0;31m---------------------------------------------------------------------------\u001b[0m",
      "\u001b[0;31mNameError\u001b[0m                                 Traceback (most recent call last)",
      "Cell \u001b[0;32mIn[2], line 1\u001b[0m\n\u001b[0;32m----> 1\u001b[0m A \u001b[38;5;241m=\u001b[39m \u001b[43mnp\u001b[49m\u001b[38;5;241m.\u001b[39marray([[\u001b[38;5;241m2\u001b[39m, \u001b[38;5;241m2\u001b[39m], [\u001b[38;5;241m2\u001b[39m, \u001b[38;5;241m5\u001b[39m]])\n\u001b[1;32m      2\u001b[0m b \u001b[38;5;241m=\u001b[39m np\u001b[38;5;241m.\u001b[39mzeros(\u001b[38;5;241m2\u001b[39m)\n\u001b[1;32m      3\u001b[0m q_oracle \u001b[38;5;241m=\u001b[39m QuadraticOracle(A, b)\n",
      "\u001b[0;31mNameError\u001b[0m: name 'np' is not defined"
     ]
    }
   ],
   "source": [
    "import numpy as np\n",
    "\n",
    "A = np.array([[2, 2], [2, 5]])\n",
    "b = np.zeros(2)\n",
    "q_oracle = QuadraticOracle(A, b)\n",
    "test_2d(\"gd\", q_oracle, np.array([-2.0, -1.0]), lr=0.01)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "e8fcab8a",
   "metadata": {},
   "source": [
    "If you did all correctly, gradient descent should converge here to optimal point. But this is not always the case:\n",
    "\n",
    "* if $\\eta$ is very small, convergence could be too slow\n",
    "* if $\\eta$ is very big, than gradient descent often diverges\n",
    "\n",
    "### Task 2.5 (1 point)\n",
    "\n",
    "Take previous quadratic oracle and try different learning rates and starting points. Find the smallest and the largest learning rates for which gradient descent is still convergent. Provide some characteristic plots. Also, plot a graph of required iterations versus $\\eta$."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "1de464d0",
   "metadata": {},
   "source": [
    "### GD for linear regression\n",
    "\n",
    "Let's try it for simple linear regression. Here is a toy example:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 64,
   "id": "c18d7391",
   "metadata": {
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "success 282 iterations\n"
     ]
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"726.94375pt\" height=\"337.074375pt\" viewBox=\"0 0 726.94375 337.074375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-03-26T14:45:43.896905</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.7.1, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 337.074375 \n",
       "L 726.94375 337.074375 \n",
       "L 726.94375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 50.14375 299.518125 \n",
       "L 354.507386 299.518125 \n",
       "L 354.507386 22.318125 \n",
       "L 50.14375 22.318125 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <path d=\"M 50.14375 299.518125 \n",
       "L 50.14375 22.318125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_2\">\n",
       "      <defs>\n",
       "       <path id=\"mb9f4931835\" d=\"M 0 0 \n",
       "L 0 3.5 \n",
       "\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"50.14375\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(46.9625 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-30\" d=\"M 2034 4250 \n",
       "Q 1547 4250 1301 3770 \n",
       "Q 1056 3291 1056 2328 \n",
       "Q 1056 1369 1301 889 \n",
       "Q 1547 409 2034 409 \n",
       "Q 2525 409 2770 889 \n",
       "Q 3016 1369 3016 2328 \n",
       "Q 3016 3291 2770 3770 \n",
       "Q 2525 4250 2034 4250 \n",
       "z\n",
       "M 2034 4750 \n",
       "Q 2819 4750 3233 4129 \n",
       "Q 3647 3509 3647 2328 \n",
       "Q 3647 1150 3233 529 \n",
       "Q 2819 -91 2034 -91 \n",
       "Q 1250 -91 836 529 \n",
       "Q 422 1150 422 2328 \n",
       "Q 422 3509 836 4129 \n",
       "Q 1250 4750 2034 4750 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <path d=\"M 104.300981 299.518125 \n",
       "L 104.300981 22.318125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"104.300981\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 50 -->\n",
       "      <g transform=\"translate(97.938481 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-35\" d=\"M 691 4666 \n",
       "L 3169 4666 \n",
       "L 3169 4134 \n",
       "L 1269 4134 \n",
       "L 1269 2991 \n",
       "Q 1406 3038 1543 3061 \n",
       "Q 1681 3084 1819 3084 \n",
       "Q 2600 3084 3056 2656 \n",
       "Q 3513 2228 3513 1497 \n",
       "Q 3513 744 3044 326 \n",
       "Q 2575 -91 1722 -91 \n",
       "Q 1428 -91 1123 -41 \n",
       "Q 819 9 494 109 \n",
       "L 494 744 \n",
       "Q 775 591 1075 516 \n",
       "Q 1375 441 1709 441 \n",
       "Q 2250 441 2565 725 \n",
       "Q 2881 1009 2881 1497 \n",
       "Q 2881 1984 2565 2268 \n",
       "Q 2250 2553 1709 2553 \n",
       "Q 1456 2553 1204 2497 \n",
       "Q 953 2441 691 2322 \n",
       "L 691 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-35\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <path d=\"M 158.458211 299.518125 \n",
       "L 158.458211 22.318125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"158.458211\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 100 -->\n",
       "      <g transform=\"translate(148.914461 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-31\" d=\"M 794 531 \n",
       "L 1825 531 \n",
       "L 1825 4091 \n",
       "L 703 3866 \n",
       "L 703 4441 \n",
       "L 1819 4666 \n",
       "L 2450 4666 \n",
       "L 2450 531 \n",
       "L 3481 531 \n",
       "L 3481 0 \n",
       "L 794 0 \n",
       "L 794 531 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <path d=\"M 212.615442 299.518125 \n",
       "L 212.615442 22.318125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"212.615442\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 150 -->\n",
       "      <g transform=\"translate(203.071692 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <path d=\"M 266.772673 299.518125 \n",
       "L 266.772673 22.318125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"266.772673\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 200 -->\n",
       "      <g transform=\"translate(257.228923 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-32\" d=\"M 1228 531 \n",
       "L 3431 531 \n",
       "L 3431 0 \n",
       "L 469 0 \n",
       "L 469 531 \n",
       "Q 828 903 1448 1529 \n",
       "Q 2069 2156 2228 2338 \n",
       "Q 2531 2678 2651 2914 \n",
       "Q 2772 3150 2772 3378 \n",
       "Q 2772 3750 2511 3984 \n",
       "Q 2250 4219 1831 4219 \n",
       "Q 1534 4219 1204 4116 \n",
       "Q 875 4013 500 3803 \n",
       "L 500 4441 \n",
       "Q 881 4594 1212 4672 \n",
       "Q 1544 4750 1819 4750 \n",
       "Q 2544 4750 2975 4387 \n",
       "Q 3406 4025 3406 3419 \n",
       "Q 3406 3131 3298 2873 \n",
       "Q 3191 2616 2906 2266 \n",
       "Q 2828 2175 2409 1742 \n",
       "Q 1991 1309 1228 531 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <path d=\"M 320.929903 299.518125 \n",
       "L 320.929903 22.318125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"320.929903\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 250 -->\n",
       "      <g transform=\"translate(311.386153 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- Iteration -->\n",
       "     <g transform=\"translate(181.116974 327.794688) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-49\" d=\"M 628 4666 \n",
       "L 1259 4666 \n",
       "L 1259 0 \n",
       "L 628 0 \n",
       "L 628 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-74\" d=\"M 1172 4494 \n",
       "L 1172 3500 \n",
       "L 2356 3500 \n",
       "L 2356 3053 \n",
       "L 1172 3053 \n",
       "L 1172 1153 \n",
       "Q 1172 725 1289 603 \n",
       "Q 1406 481 1766 481 \n",
       "L 2356 481 \n",
       "L 2356 0 \n",
       "L 1766 0 \n",
       "Q 1100 0 847 248 \n",
       "Q 594 497 594 1153 \n",
       "L 594 3053 \n",
       "L 172 3053 \n",
       "L 172 3500 \n",
       "L 594 3500 \n",
       "L 594 4494 \n",
       "L 1172 4494 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-65\" d=\"M 3597 1894 \n",
       "L 3597 1613 \n",
       "L 953 1613 \n",
       "Q 991 1019 1311 708 \n",
       "Q 1631 397 2203 397 \n",
       "Q 2534 397 2845 478 \n",
       "Q 3156 559 3463 722 \n",
       "L 3463 178 \n",
       "Q 3153 47 2828 -22 \n",
       "Q 2503 -91 2169 -91 \n",
       "Q 1331 -91 842 396 \n",
       "Q 353 884 353 1716 \n",
       "Q 353 2575 817 3079 \n",
       "Q 1281 3584 2069 3584 \n",
       "Q 2775 3584 3186 3129 \n",
       "Q 3597 2675 3597 1894 \n",
       "z\n",
       "M 3022 2063 \n",
       "Q 3016 2534 2758 2815 \n",
       "Q 2500 3097 2075 3097 \n",
       "Q 1594 3097 1305 2825 \n",
       "Q 1016 2553 972 2059 \n",
       "L 3022 2063 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-72\" d=\"M 2631 2963 \n",
       "Q 2534 3019 2420 3045 \n",
       "Q 2306 3072 2169 3072 \n",
       "Q 1681 3072 1420 2755 \n",
       "Q 1159 2438 1159 1844 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1341 3275 1631 3429 \n",
       "Q 1922 3584 2338 3584 \n",
       "Q 2397 3584 2469 3576 \n",
       "Q 2541 3569 2628 3553 \n",
       "L 2631 2963 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-61\" d=\"M 2194 1759 \n",
       "Q 1497 1759 1228 1600 \n",
       "Q 959 1441 959 1056 \n",
       "Q 959 750 1161 570 \n",
       "Q 1363 391 1709 391 \n",
       "Q 2188 391 2477 730 \n",
       "Q 2766 1069 2766 1631 \n",
       "L 2766 1759 \n",
       "L 2194 1759 \n",
       "z\n",
       "M 3341 1997 \n",
       "L 3341 0 \n",
       "L 2766 0 \n",
       "L 2766 531 \n",
       "Q 2569 213 2275 61 \n",
       "Q 1981 -91 1556 -91 \n",
       "Q 1019 -91 701 211 \n",
       "Q 384 513 384 1019 \n",
       "Q 384 1609 779 1909 \n",
       "Q 1175 2209 1959 2209 \n",
       "L 2766 2209 \n",
       "L 2766 2266 \n",
       "Q 2766 2663 2505 2880 \n",
       "Q 2244 3097 1772 3097 \n",
       "Q 1472 3097 1187 3025 \n",
       "Q 903 2953 641 2809 \n",
       "L 641 3341 \n",
       "Q 956 3463 1253 3523 \n",
       "Q 1550 3584 1831 3584 \n",
       "Q 2591 3584 2966 3190 \n",
       "Q 3341 2797 3341 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-69\" d=\"M 603 3500 \n",
       "L 1178 3500 \n",
       "L 1178 0 \n",
       "L 603 0 \n",
       "L 603 3500 \n",
       "z\n",
       "M 603 4863 \n",
       "L 1178 4863 \n",
       "L 1178 4134 \n",
       "L 603 4134 \n",
       "L 603 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6f\" d=\"M 1959 3097 \n",
       "Q 1497 3097 1228 2736 \n",
       "Q 959 2375 959 1747 \n",
       "Q 959 1119 1226 758 \n",
       "Q 1494 397 1959 397 \n",
       "Q 2419 397 2687 759 \n",
       "Q 2956 1122 2956 1747 \n",
       "Q 2956 2369 2687 2733 \n",
       "Q 2419 3097 1959 3097 \n",
       "z\n",
       "M 1959 3584 \n",
       "Q 2709 3584 3137 3096 \n",
       "Q 3566 2609 3566 1747 \n",
       "Q 3566 888 3137 398 \n",
       "Q 2709 -91 1959 -91 \n",
       "Q 1206 -91 779 398 \n",
       "Q 353 888 353 1747 \n",
       "Q 353 2609 779 3096 \n",
       "Q 1206 3584 1959 3584 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6e\" d=\"M 3513 2113 \n",
       "L 3513 0 \n",
       "L 2938 0 \n",
       "L 2938 2094 \n",
       "Q 2938 2591 2744 2837 \n",
       "Q 2550 3084 2163 3084 \n",
       "Q 1697 3084 1428 2787 \n",
       "Q 1159 2491 1159 1978 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1366 3272 1645 3428 \n",
       "Q 1925 3584 2291 3584 \n",
       "Q 2894 3584 3203 3211 \n",
       "Q 3513 2838 3513 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-49\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"29.492188\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"68.701172\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"130.224609\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"171.337891\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"232.617188\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"271.826172\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6f\" x=\"299.609375\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"360.791016\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <path d=\"M 50.14375 299.518125 \n",
       "L 354.507386 299.518125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_14\">\n",
       "      <defs>\n",
       "       <path id=\"mf8caf999c3\" d=\"M 0 0 \n",
       "L -3.5 0 \n",
       "\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 0.00 -->\n",
       "      <g transform=\"translate(20.878125 303.317344) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-2e\" d=\"M 684 794 \n",
       "L 1344 794 \n",
       "L 1344 0 \n",
       "L 684 0 \n",
       "L 684 794 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <path d=\"M 50.14375 264.868125 \n",
       "L 354.507386 264.868125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"264.868125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 0.25 -->\n",
       "      <g transform=\"translate(20.878125 268.667344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-32\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <path d=\"M 50.14375 230.218125 \n",
       "L 354.507386 230.218125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"230.218125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 0.50 -->\n",
       "      <g transform=\"translate(20.878125 234.017344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <path d=\"M 50.14375 195.568125 \n",
       "L 354.507386 195.568125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"195.568125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 0.75 -->\n",
       "      <g transform=\"translate(20.878125 199.367344) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-37\" d=\"M 525 4666 \n",
       "L 3525 4666 \n",
       "L 3525 4397 \n",
       "L 1831 0 \n",
       "L 1172 0 \n",
       "L 2766 4134 \n",
       "L 525 4134 \n",
       "L 525 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-37\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <path d=\"M 50.14375 160.918125 \n",
       "L 354.507386 160.918125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"160.918125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 1.00 -->\n",
       "      <g transform=\"translate(20.878125 164.717344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <path d=\"M 50.14375 126.268125 \n",
       "L 354.507386 126.268125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"126.268125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 1.25 -->\n",
       "      <g transform=\"translate(20.878125 130.067344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-32\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <path d=\"M 50.14375 91.618125 \n",
       "L 354.507386 91.618125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"91.618125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 1.50 -->\n",
       "      <g transform=\"translate(20.878125 95.417344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <path d=\"M 50.14375 56.968125 \n",
       "L 354.507386 56.968125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"56.968125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 1.75 -->\n",
       "      <g transform=\"translate(20.878125 60.767344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-37\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <path d=\"M 50.14375 22.318125 \n",
       "L 354.507386 22.318125 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"50.14375\" y=\"22.318125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 2.00 -->\n",
       "      <g transform=\"translate(20.878125 26.117344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Gradients/residuals norm -->\n",
       "     <g transform=\"translate(14.798438 224.039219) rotate(-90) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-47\" d=\"M 3809 666 \n",
       "L 3809 1919 \n",
       "L 2778 1919 \n",
       "L 2778 2438 \n",
       "L 4434 2438 \n",
       "L 4434 434 \n",
       "Q 4069 175 3628 42 \n",
       "Q 3188 -91 2688 -91 \n",
       "Q 1594 -91 976 548 \n",
       "Q 359 1188 359 2328 \n",
       "Q 359 3472 976 4111 \n",
       "Q 1594 4750 2688 4750 \n",
       "Q 3144 4750 3555 4637 \n",
       "Q 3966 4525 4313 4306 \n",
       "L 4313 3634 \n",
       "Q 3963 3931 3569 4081 \n",
       "Q 3175 4231 2741 4231 \n",
       "Q 1884 4231 1454 3753 \n",
       "Q 1025 3275 1025 2328 \n",
       "Q 1025 1384 1454 906 \n",
       "Q 1884 428 2741 428 \n",
       "Q 3075 428 3337 486 \n",
       "Q 3600 544 3809 666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-64\" d=\"M 2906 2969 \n",
       "L 2906 4863 \n",
       "L 3481 4863 \n",
       "L 3481 0 \n",
       "L 2906 0 \n",
       "L 2906 525 \n",
       "Q 2725 213 2448 61 \n",
       "Q 2172 -91 1784 -91 \n",
       "Q 1150 -91 751 415 \n",
       "Q 353 922 353 1747 \n",
       "Q 353 2572 751 3078 \n",
       "Q 1150 3584 1784 3584 \n",
       "Q 2172 3584 2448 3432 \n",
       "Q 2725 3281 2906 2969 \n",
       "z\n",
       "M 947 1747 \n",
       "Q 947 1113 1208 752 \n",
       "Q 1469 391 1925 391 \n",
       "Q 2381 391 2643 752 \n",
       "Q 2906 1113 2906 1747 \n",
       "Q 2906 2381 2643 2742 \n",
       "Q 2381 3103 1925 3103 \n",
       "Q 1469 3103 1208 2742 \n",
       "Q 947 2381 947 1747 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-73\" d=\"M 2834 3397 \n",
       "L 2834 2853 \n",
       "Q 2591 2978 2328 3040 \n",
       "Q 2066 3103 1784 3103 \n",
       "Q 1356 3103 1142 2972 \n",
       "Q 928 2841 928 2578 \n",
       "Q 928 2378 1081 2264 \n",
       "Q 1234 2150 1697 2047 \n",
       "L 1894 2003 \n",
       "Q 2506 1872 2764 1633 \n",
       "Q 3022 1394 3022 966 \n",
       "Q 3022 478 2636 193 \n",
       "Q 2250 -91 1575 -91 \n",
       "Q 1294 -91 989 -36 \n",
       "Q 684 19 347 128 \n",
       "L 347 722 \n",
       "Q 666 556 975 473 \n",
       "Q 1284 391 1588 391 \n",
       "Q 1994 391 2212 530 \n",
       "Q 2431 669 2431 922 \n",
       "Q 2431 1156 2273 1281 \n",
       "Q 2116 1406 1581 1522 \n",
       "L 1381 1569 \n",
       "Q 847 1681 609 1914 \n",
       "Q 372 2147 372 2553 \n",
       "Q 372 3047 722 3315 \n",
       "Q 1072 3584 1716 3584 \n",
       "Q 2034 3584 2315 3537 \n",
       "Q 2597 3491 2834 3397 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2f\" d=\"M 1625 4666 \n",
       "L 2156 4666 \n",
       "L 531 -594 \n",
       "L 0 -594 \n",
       "L 1625 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-75\" d=\"M 544 1381 \n",
       "L 544 3500 \n",
       "L 1119 3500 \n",
       "L 1119 1403 \n",
       "Q 1119 906 1312 657 \n",
       "Q 1506 409 1894 409 \n",
       "Q 2359 409 2629 706 \n",
       "Q 2900 1003 2900 1516 \n",
       "L 2900 3500 \n",
       "L 3475 3500 \n",
       "L 3475 0 \n",
       "L 2900 0 \n",
       "L 2900 538 \n",
       "Q 2691 219 2414 64 \n",
       "Q 2138 -91 1772 -91 \n",
       "Q 1169 -91 856 284 \n",
       "Q 544 659 544 1381 \n",
       "z\n",
       "M 1991 3584 \n",
       "L 1991 3584 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6c\" d=\"M 603 4863 \n",
       "L 1178 4863 \n",
       "L 1178 0 \n",
       "L 603 0 \n",
       "L 603 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6d\" d=\"M 3328 2828 \n",
       "Q 3544 3216 3844 3400 \n",
       "Q 4144 3584 4550 3584 \n",
       "Q 5097 3584 5394 3201 \n",
       "Q 5691 2819 5691 2113 \n",
       "L 5691 0 \n",
       "L 5113 0 \n",
       "L 5113 2094 \n",
       "Q 5113 2597 4934 2840 \n",
       "Q 4756 3084 4391 3084 \n",
       "Q 3944 3084 3684 2787 \n",
       "Q 3425 2491 3425 1978 \n",
       "L 3425 0 \n",
       "L 2847 0 \n",
       "L 2847 2094 \n",
       "Q 2847 2600 2669 2842 \n",
       "Q 2491 3084 2119 3084 \n",
       "Q 1678 3084 1418 2786 \n",
       "Q 1159 2488 1159 1978 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1356 3278 1631 3431 \n",
       "Q 1906 3584 2284 3584 \n",
       "Q 2666 3584 2933 3390 \n",
       "Q 3200 3197 3328 2828 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-47\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"77.490234\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"118.603516\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"179.882812\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"243.359375\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"271.142578\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"332.666016\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"396.044922\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"435.253906\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2f\" x=\"487.353516\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"521.044922\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"559.908203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"621.431641\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"673.53125\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"701.314453\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-75\" x=\"764.791016\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"828.169922\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6c\" x=\"889.449219\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"917.232422\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-20\" x=\"969.332031\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"1001.119141\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6f\" x=\"1064.498047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"1125.679688\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6d\" x=\"1165.042969\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_31\">\n",
       "    <path d=\"M 54.435994 -1 \n",
       "L 54.476328 -0.467568 \n",
       "L 55.559473 10.590112 \n",
       "L 56.642618 19.409777 \n",
       "L 57.725762 26.695215 \n",
       "L 58.808907 32.930881 \n",
       "L 60.975196 43.460223 \n",
       "L 63.141485 52.530444 \n",
       "L 66.390919 64.779464 \n",
       "L 69.640353 76.113092 \n",
       "L 73.972931 90.256382 \n",
       "L 78.30551 103.47315 \n",
       "L 82.638088 115.84938 \n",
       "L 86.970667 127.443231 \n",
       "L 91.303245 138.305036 \n",
       "L 95.635824 148.48118 \n",
       "L 99.968402 158.014974 \n",
       "L 104.300981 166.946973 \n",
       "L 108.633559 175.315164 \n",
       "L 112.966138 183.155135 \n",
       "L 117.298716 190.50023 \n",
       "L 121.631294 197.381686 \n",
       "L 125.963873 203.828769 \n",
       "L 130.296451 209.868897 \n",
       "L 134.62903 215.527759 \n",
       "L 138.961608 220.829421 \n",
       "L 143.294187 225.796429 \n",
       "L 147.626765 230.449909 \n",
       "L 151.959344 234.809651 \n",
       "L 156.291922 238.894196 \n",
       "L 160.624501 242.720916 \n",
       "L 164.957079 246.306084 \n",
       "L 170.372802 250.470998 \n",
       "L 175.788525 254.309924 \n",
       "L 181.204248 257.848377 \n",
       "L 186.619971 261.109875 \n",
       "L 192.035694 264.116094 \n",
       "L 197.451417 266.887017 \n",
       "L 202.86714 269.441059 \n",
       "L 209.366008 272.243433 \n",
       "L 215.864876 274.784701 \n",
       "L 222.363744 277.089192 \n",
       "L 228.862611 279.178966 \n",
       "L 236.444624 281.372242 \n",
       "L 244.026636 283.329006 \n",
       "L 251.608648 285.074762 \n",
       "L 260.273805 286.840609 \n",
       "L 268.938962 288.390563 \n",
       "L 278.687263 289.908939 \n",
       "L 289.51871 291.354296 \n",
       "L 301.4333 292.694394 \n",
       "L 314.431036 293.906732 \n",
       "L 328.511916 294.978289 \n",
       "L 343.67594 295.904606 \n",
       "L 354.507386 296.44813 \n",
       "L 354.507386 296.44813 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke: #00bfbf; stroke-width: 3; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_32\">\n",
       "    <path d=\"M 81.874847 -1 \n",
       "L 84.804378 12.04319 \n",
       "L 89.136956 30.216494 \n",
       "L 93.469535 47.220476 \n",
       "L 97.802113 63.147012 \n",
       "L 102.134691 78.067464 \n",
       "L 106.46727 92.045963 \n",
       "L 110.799848 105.14208 \n",
       "L 115.132427 117.411536 \n",
       "L 119.465005 128.906516 \n",
       "L 123.797584 139.675906 \n",
       "L 128.130162 149.765508 \n",
       "L 132.462741 159.218232 \n",
       "L 136.795319 168.074278 \n",
       "L 141.127898 176.37131 \n",
       "L 145.460476 184.144616 \n",
       "L 149.793054 191.427252 \n",
       "L 154.125633 198.250192 \n",
       "L 158.458211 204.642453 \n",
       "L 162.79079 210.63122 \n",
       "L 167.123368 216.241962 \n",
       "L 171.455947 221.498542 \n",
       "L 175.788525 226.423314 \n",
       "L 180.121104 231.037223 \n",
       "L 184.453682 235.359893 \n",
       "L 188.786261 239.409705 \n",
       "L 193.118839 243.203885 \n",
       "L 198.534562 247.611609 \n",
       "L 203.950285 251.67434 \n",
       "L 209.366008 255.41908 \n",
       "L 214.781731 258.870719 \n",
       "L 220.197454 262.052198 \n",
       "L 225.613177 264.984662 \n",
       "L 231.0289 267.687601 \n",
       "L 237.527768 270.653351 \n",
       "L 244.026636 273.342772 \n",
       "L 250.525503 275.781611 \n",
       "L 257.024371 277.993217 \n",
       "L 264.606383 280.314358 \n",
       "L 272.188396 282.385199 \n",
       "L 279.770408 284.232731 \n",
       "L 288.435565 286.101525 \n",
       "L 297.100722 287.741839 \n",
       "L 306.849023 289.348735 \n",
       "L 316.597325 290.736367 \n",
       "L 327.428771 292.057267 \n",
       "L 339.343362 293.281971 \n",
       "L 352.341097 294.389918 \n",
       "L 354.507386 294.554408 \n",
       "L 354.507386 294.554408 \n",
       "\" clip-path=\"url(#pfa035fbd2e)\" style=\"fill: none; stroke: #bf00bf; stroke-width: 2; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 50.14375 299.518125 \n",
       "L 50.14375 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 354.507386 299.518125 \n",
       "L 354.507386 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 50.14375 299.518125 \n",
       "L 354.507386 299.518125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 50.14375 22.318125 \n",
       "L 354.507386 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_18\">\n",
       "    <!-- lr = 0.01 -->\n",
       "    <g transform=\"translate(175.991193 16.318125) scale(0.12 -0.12)\">\n",
       "     <defs>\n",
       "      <path id=\"DejaVuSans-3d\" d=\"M 678 2906 \n",
       "L 4684 2906 \n",
       "L 4684 2381 \n",
       "L 678 2381 \n",
       "L 678 2906 \n",
       "z\n",
       "M 678 1631 \n",
       "L 4684 1631 \n",
       "L 4684 1100 \n",
       "L 678 1100 \n",
       "L 678 1631 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#DejaVuSans-6c\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-72\" x=\"27.783203\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-20\" x=\"68.896484\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-3d\" x=\"100.683594\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-20\" x=\"184.472656\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-30\" x=\"216.259766\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-2e\" x=\"279.882812\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-30\" x=\"311.669922\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-31\" x=\"375.292969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"patch_7\">\n",
       "     <path d=\"M 266.773011 59.674375 \n",
       "L 347.507386 59.674375 \n",
       "Q 349.507386 59.674375 349.507386 57.674375 \n",
       "L 349.507386 29.318125 \n",
       "Q 349.507386 27.318125 347.507386 27.318125 \n",
       "L 266.773011 27.318125 \n",
       "Q 264.773011 27.318125 264.773011 29.318125 \n",
       "L 264.773011 57.674375 \n",
       "Q 264.773011 59.674375 266.773011 59.674375 \n",
       "z\n",
       "\" style=\"fill: #ffffff; opacity: 0.8; stroke: #cccccc; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"line2d_33\">\n",
       "     <path d=\"M 268.773011 35.416562 \n",
       "L 278.773011 35.416562 \n",
       "L 288.773011 35.416562 \n",
       "\" style=\"fill: none; stroke: #00bfbf; stroke-width: 3; stroke-linecap: square\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- Residuals -->\n",
       "     <g transform=\"translate(296.773011 38.916562) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-52\" d=\"M 2841 2188 \n",
       "Q 3044 2119 3236 1894 \n",
       "Q 3428 1669 3622 1275 \n",
       "L 4263 0 \n",
       "L 3584 0 \n",
       "L 2988 1197 \n",
       "Q 2756 1666 2539 1819 \n",
       "Q 2322 1972 1947 1972 \n",
       "L 1259 1972 \n",
       "L 1259 0 \n",
       "L 628 0 \n",
       "L 628 4666 \n",
       "L 2053 4666 \n",
       "Q 2853 4666 3247 4331 \n",
       "Q 3641 3997 3641 3322 \n",
       "Q 3641 2881 3436 2590 \n",
       "Q 3231 2300 2841 2188 \n",
       "z\n",
       "M 1259 4147 \n",
       "L 1259 2491 \n",
       "L 2053 2491 \n",
       "Q 2509 2491 2742 2702 \n",
       "Q 2975 2913 2975 3322 \n",
       "Q 2975 3731 2742 3939 \n",
       "Q 2509 4147 2053 4147 \n",
       "L 1259 4147 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-52\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"64.982422\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"126.505859\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"178.605469\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"206.388672\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-75\" x=\"269.865234\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"333.244141\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6c\" x=\"394.523438\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"422.306641\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_34\">\n",
       "     <path d=\"M 268.773011 50.094688 \n",
       "L 278.773011 50.094688 \n",
       "L 288.773011 50.094688 \n",
       "\" style=\"fill: none; stroke: #bf00bf; stroke-width: 2; stroke-linecap: square\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- Gradients -->\n",
       "     <g transform=\"translate(296.773011 53.594688) scale(0.1 -0.1)\">\n",
       "      <use xlink:href=\"#DejaVuSans-47\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"77.490234\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"118.603516\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"179.882812\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"243.359375\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"271.142578\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"332.666016\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"396.044922\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"435.253906\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 415.380114 299.518125 \n",
       "L 719.74375 299.518125 \n",
       "L 719.74375 22.318125 \n",
       "L 415.380114 22.318125 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"C0_0_25897c0149\" d=\"M 0 1.414214 \n",
       "C 0.375054 1.414214 0.734797 1.265203 1 1 \n",
       "C 1.265203 0.734797 1.414214 0.375054 1.414214 -0 \n",
       "C 1.414214 -0.375054 1.265203 -0.734797 1 -1 \n",
       "C 0.734797 -1.265203 0.375054 -1.414214 0 -1.414214 \n",
       "C -0.375054 -1.414214 -0.734797 -1.265203 -1 -1 \n",
       "C -1.265203 -0.734797 -1.414214 -0.375054 -1.414214 0 \n",
       "C -1.414214 0.375054 -1.265203 0.734797 -1 1 \n",
       "C -0.734797 1.265203 -0.375054 1.414214 0 1.414214 \n",
       "z\n",
       "\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"432.547078\" y=\"35.518125\" style=\"fill: #ff0000; stroke: #ff0000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"430.746019\" y=\"66.024589\" style=\"fill: #ff0500; stroke: #ff0500\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"429.922214\" y=\"90.616046\" style=\"fill: #ff0b00; stroke: #ff0b00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"429.87362\" y=\"110.45314\" style=\"fill: #ff1000; stroke: #ff1000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"430.438043\" y=\"126.468544\" style=\"fill: #ff1600; stroke: #ff1600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"431.485311\" y=\"139.411749\" style=\"fill: #ff1b00; stroke: #ff1b00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"432.910977\" y=\"149.885037\" style=\"fill: #ff2100; stroke: #ff2100\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"434.631269\" y=\"158.372407\" style=\"fill: #ff2600; stroke: #ff2600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"436.57902\" y=\"165.2628\" style=\"fill: #ff2b00; stroke: #ff2b00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"438.70041\" y=\"170.868779\" style=\"fill: #ff3100; stroke: #ff3100\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"440.952337\" y=\"175.441526\" style=\"fill: #ff3600; stroke: #ff3600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"443.300311\" y=\"179.182901\" style=\"fill: #ff3c00; stroke: #ff3c00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"445.71676\" y=\"182.255132\" style=\"fill: #ff4100; stroke: #ff4100\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"448.179669\" y=\"184.788595\" style=\"fill: #ff4700; stroke: #ff4700\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"450.671487\" y=\"186.888075\" style=\"fill: #ff4c00; stroke: #ff4c00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"453.178244\" y=\"188.637791\" style=\"fill: #ff5100; stroke: #ff5100\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"455.688852\" y=\"190.105434\" style=\"fill: #ff5700; stroke: #ff5700\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"458.194529\" y=\"191.345417\" style=\"fill: #ff5c00; stroke: #ff5c00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"460.688351\" y=\"192.401478\" style=\"fill: #ff6200; stroke: #ff6200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"463.16488\" y=\"193.308782\" style=\"fill: #ff6700; stroke: #ff6700\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"465.619872\" y=\"194.095599\" style=\"fill: #ff6d00; stroke: #ff6d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"468.05004\" y=\"194.784664\" style=\"fill: #ff7200; stroke: #ff7200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"470.452864\" y=\"195.39426\" style=\"fill: #ff7700; stroke: #ff7700\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"472.826441\" y=\"195.939093\" style=\"fill: #ff7d00; stroke: #ff7d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"475.169356\" y=\"196.430997\" style=\"fill: #ff8200; stroke: #ff8200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"477.480589\" y=\"196.879493\" style=\"fill: #ff8800; stroke: #ff8800\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"479.759436\" y=\"197.292247\" style=\"fill: #ff8d00; stroke: #ff8d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"482.005441\" y=\"197.675435\" style=\"fill: #ff9200; stroke: #ff9200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"484.218348\" y=\"198.03403\" style=\"fill: #ff9800; stroke: #ff9800\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"486.398061\" y=\"198.372045\" style=\"fill: #ff9d00; stroke: #ff9d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"488.544609\" y=\"198.692715\" style=\"fill: #ffa300; stroke: #ffa300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"490.65812\" y=\"198.998655\" style=\"fill: #ffa800; stroke: #ffa800\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"492.7388\" y=\"199.291978\" style=\"fill: #ffae00; stroke: #ffae00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"494.786916\" y=\"199.574394\" style=\"fill: #ffb300; stroke: #ffb300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"496.802784\" y=\"199.847291\" style=\"fill: #ffb800; stroke: #ffb800\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"498.786754\" y=\"200.111796\" style=\"fill: #ffbe00; stroke: #ffbe00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"500.739205\" y=\"200.368825\" style=\"fill: #ffc300; stroke: #ffc300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"502.660538\" y=\"200.619129\" style=\"fill: #ffc900; stroke: #ffc900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"504.551167\" y=\"200.863321\" style=\"fill: #ffce00; stroke: #ffce00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"506.411518\" y=\"201.101905\" style=\"fill: #ffd400; stroke: #ffd400\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"508.242022\" y=\"201.335297\" style=\"fill: #ffd900; stroke: #ffd900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"510.043118\" y=\"201.563845\" style=\"fill: #ffde00; stroke: #ffde00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"511.815243\" y=\"201.787836\" style=\"fill: #ffe400; stroke: #ffe400\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"513.558837\" y=\"202.007514\" style=\"fill: #ffe900; stroke: #ffe900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"515.274336\" y=\"202.223084\" style=\"fill: #ffef00; stroke: #ffef00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"516.962177\" y=\"202.434721\" style=\"fill: #fff400; stroke: #fff400\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"518.622791\" y=\"202.642578\" style=\"fill: #fffa00; stroke: #fffa00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"520.256605\" y=\"202.846785\" style=\"fill: #ffff00; stroke: #ffff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"521.864044\" y=\"203.047459\" style=\"fill: #faff00; stroke: #faff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"523.445526\" y=\"203.244702\" style=\"fill: #f4ff00; stroke: #f4ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"525.001463\" y=\"203.438606\" style=\"fill: #efff00; stroke: #efff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"526.532265\" y=\"203.629254\" style=\"fill: #e9ff00; stroke: #e9ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"528.038332\" y=\"203.816724\" style=\"fill: #e4ff00; stroke: #e4ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"529.520062\" y=\"204.001084\" style=\"fill: #deff00; stroke: #deff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"530.977846\" y=\"204.182402\" style=\"fill: #d9ff00; stroke: #d9ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"532.412069\" y=\"204.360738\" style=\"fill: #d4ff00; stroke: #d4ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"533.823109\" y=\"204.536149\" style=\"fill: #ceff00; stroke: #ceff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"535.211341\" y=\"204.708693\" style=\"fill: #c9ff00; stroke: #c9ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"536.577131\" y=\"204.87842\" style=\"fill: #c3ff00; stroke: #c3ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"537.920843\" y=\"205.045383\" style=\"fill: #beff00; stroke: #beff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"539.242832\" y=\"205.209629\" style=\"fill: #b8ff00; stroke: #b8ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"540.543448\" y=\"205.371206\" style=\"fill: #b3ff00; stroke: #b3ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"541.823037\" y=\"205.53016\" style=\"fill: #aeff00; stroke: #aeff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"543.081939\" y=\"205.686535\" style=\"fill: #a8ff00; stroke: #a8ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"544.320488\" y=\"205.840374\" style=\"fill: #a3ff00; stroke: #a3ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"545.539012\" y=\"205.991721\" style=\"fill: #9dff00; stroke: #9dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"546.737835\" y=\"206.140616\" style=\"fill: #98ff00; stroke: #98ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"547.917276\" y=\"206.2871\" style=\"fill: #92ff00; stroke: #92ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"549.077647\" y=\"206.431212\" style=\"fill: #8dff00; stroke: #8dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"550.219257\" y=\"206.572992\" style=\"fill: #88ff00; stroke: #88ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"551.34241\" y=\"206.712478\" style=\"fill: #82ff00; stroke: #82ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"552.447403\" y=\"206.849708\" style=\"fill: #7dff00; stroke: #7dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"553.53453\" y=\"206.984717\" style=\"fill: #77ff00; stroke: #77ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"554.604081\" y=\"207.117542\" style=\"fill: #72ff00; stroke: #72ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"555.656338\" y=\"207.248219\" style=\"fill: #6dff00; stroke: #6dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"556.691582\" y=\"207.376782\" style=\"fill: #67ff00; stroke: #67ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"557.710088\" y=\"207.503267\" style=\"fill: #62ff00; stroke: #62ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"558.712126\" y=\"207.627705\" style=\"fill: #5cff00; stroke: #5cff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"559.697963\" y=\"207.750132\" style=\"fill: #57ff00; stroke: #57ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"560.667861\" y=\"207.870578\" style=\"fill: #51ff00; stroke: #51ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"561.622076\" y=\"207.989078\" style=\"fill: #4cff00; stroke: #4cff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"562.560864\" y=\"208.105661\" style=\"fill: #47ff00; stroke: #47ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"563.484473\" y=\"208.220358\" style=\"fill: #41ff00; stroke: #41ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"564.393148\" y=\"208.333202\" style=\"fill: #3cff00; stroke: #3cff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"565.287132\" y=\"208.44422\" style=\"fill: #36ff00; stroke: #36ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"566.166661\" y=\"208.553444\" style=\"fill: #31ff00; stroke: #31ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"567.031969\" y=\"208.660901\" style=\"fill: #2bff00; stroke: #2bff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"567.883287\" y=\"208.766622\" style=\"fill: #26ff00; stroke: #26ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"568.72084\" y=\"208.870632\" style=\"fill: #21ff00; stroke: #21ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"569.544852\" y=\"208.972961\" style=\"fill: #1bff00; stroke: #1bff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"570.35554\" y=\"209.073636\" style=\"fill: #16ff00; stroke: #16ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"571.153121\" y=\"209.172682\" style=\"fill: #10ff00; stroke: #10ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"571.937806\" y=\"209.270128\" style=\"fill: #0bff00; stroke: #0bff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"572.709804\" y=\"209.365997\" style=\"fill: #05ff00; stroke: #05ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"573.46932\" y=\"209.460317\" style=\"fill: #00ff00; stroke: #00ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"574.216555\" y=\"209.553111\" style=\"fill: #00ff05; stroke: #00ff05\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"574.951709\" y=\"209.644406\" style=\"fill: #00ff0b; stroke: #00ff0b\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"575.674977\" y=\"209.734224\" style=\"fill: #00ff10; stroke: #00ff10\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"576.38655\" y=\"209.82259\" style=\"fill: #00ff16; stroke: #00ff16\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"577.086619\" y=\"209.909527\" style=\"fill: #00ff1b; stroke: #00ff1b\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"577.775368\" y=\"209.995058\" style=\"fill: #00ff21; stroke: #00ff21\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"578.452982\" y=\"210.079207\" style=\"fill: #00ff26; stroke: #00ff26\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"579.119639\" y=\"210.161995\" style=\"fill: #00ff2b; stroke: #00ff2b\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"579.775517\" y=\"210.243445\" style=\"fill: #00ff31; stroke: #00ff31\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"580.420791\" y=\"210.323577\" style=\"fill: #00ff36; stroke: #00ff36\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"581.055632\" y=\"210.402414\" style=\"fill: #00ff3c; stroke: #00ff3c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"581.680209\" y=\"210.479976\" style=\"fill: #00ff41; stroke: #00ff41\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"582.294687\" y=\"210.556285\" style=\"fill: #00ff47; stroke: #00ff47\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"582.89923\" y=\"210.631359\" style=\"fill: #00ff4c; stroke: #00ff4c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"583.493998\" y=\"210.70522\" style=\"fill: #00ff51; stroke: #00ff51\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"584.07915\" y=\"210.777886\" style=\"fill: #00ff57; stroke: #00ff57\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"584.65484\" y=\"210.849377\" style=\"fill: #00ff5c; stroke: #00ff5c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"585.221223\" y=\"210.919713\" style=\"fill: #00ff62; stroke: #00ff62\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"585.778448\" y=\"210.988911\" style=\"fill: #00ff67; stroke: #00ff67\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"586.326664\" y=\"211.056991\" style=\"fill: #00ff6d; stroke: #00ff6d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"586.866016\" y=\"211.12397\" style=\"fill: #00ff72; stroke: #00ff72\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"587.396647\" y=\"211.189865\" style=\"fill: #00ff77; stroke: #00ff77\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"587.918699\" y=\"211.254696\" style=\"fill: #00ff7d; stroke: #00ff7d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"588.43231\" y=\"211.318478\" style=\"fill: #00ff82; stroke: #00ff82\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"588.937617\" y=\"211.381229\" style=\"fill: #00ff88; stroke: #00ff88\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"589.434754\" y=\"211.442965\" style=\"fill: #00ff8d; stroke: #00ff8d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"589.923852\" y=\"211.503703\" style=\"fill: #00ff92; stroke: #00ff92\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"590.405043\" y=\"211.563459\" style=\"fill: #00ff98; stroke: #00ff98\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"590.878454\" y=\"211.622249\" style=\"fill: #00ff9d; stroke: #00ff9d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"591.34421\" y=\"211.680089\" style=\"fill: #00ffa3; stroke: #00ffa3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"591.802436\" y=\"211.736993\" style=\"fill: #00ffa8; stroke: #00ffa8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"592.253253\" y=\"211.792977\" style=\"fill: #00ffae; stroke: #00ffae\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"592.696781\" y=\"211.848056\" style=\"fill: #00ffb3; stroke: #00ffb3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"593.133138\" y=\"211.902245\" style=\"fill: #00ffb8; stroke: #00ffb8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"593.562439\" y=\"211.955557\" style=\"fill: #00ffbe; stroke: #00ffbe\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"593.984799\" y=\"212.008007\" style=\"fill: #00ffc3; stroke: #00ffc3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"594.400331\" y=\"212.059609\" style=\"fill: #00ffc9; stroke: #00ffc9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"594.809144\" y=\"212.110377\" style=\"fill: #00ffce; stroke: #00ffce\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"595.211347\" y=\"212.160324\" style=\"fill: #00ffd4; stroke: #00ffd4\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"595.607047\" y=\"212.209464\" style=\"fill: #00ffd9; stroke: #00ffd9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"595.996349\" y=\"212.257809\" style=\"fill: #00ffde; stroke: #00ffde\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"596.379357\" y=\"212.305372\" style=\"fill: #00ffe4; stroke: #00ffe4\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"596.756172\" y=\"212.352167\" style=\"fill: #00ffe9; stroke: #00ffe9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"597.126894\" y=\"212.398204\" style=\"fill: #00ffef; stroke: #00ffef\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"597.491623\" y=\"212.443498\" style=\"fill: #00fff4; stroke: #00fff4\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"597.850454\" y=\"212.488059\" style=\"fill: #00fffa; stroke: #00fffa\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"598.203484\" y=\"212.531899\" style=\"fill: #00ffff; stroke: #00ffff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"598.550805\" y=\"212.575031\" style=\"fill: #00faff; stroke: #00faff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"598.892511\" y=\"212.617465\" style=\"fill: #00f4ff; stroke: #00f4ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"599.228693\" y=\"212.659214\" style=\"fill: #00efff; stroke: #00efff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"599.559438\" y=\"212.700287\" style=\"fill: #00e9ff; stroke: #00e9ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"599.884836\" y=\"212.740696\" style=\"fill: #00e4ff; stroke: #00e4ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"600.204973\" y=\"212.780452\" style=\"fill: #00deff; stroke: #00deff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"600.519934\" y=\"212.819565\" style=\"fill: #00d9ff; stroke: #00d9ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"600.829802\" y=\"212.858045\" style=\"fill: #00d4ff; stroke: #00d4ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"601.13466\" y=\"212.895904\" style=\"fill: #00ceff; stroke: #00ceff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"601.434589\" y=\"212.93315\" style=\"fill: #00c9ff; stroke: #00c9ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"601.729668\" y=\"212.969794\" style=\"fill: #00c3ff; stroke: #00c3ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"602.019977\" y=\"213.005846\" style=\"fill: #00beff; stroke: #00beff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"602.305592\" y=\"213.041315\" style=\"fill: #00b8ff; stroke: #00b8ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"602.586589\" y=\"213.07621\" style=\"fill: #00b3ff; stroke: #00b3ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"602.863042\" y=\"213.110541\" style=\"fill: #00aeff; stroke: #00aeff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"603.135026\" y=\"213.144317\" style=\"fill: #00a8ff; stroke: #00a8ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"603.402612\" y=\"213.177547\" style=\"fill: #00a3ff; stroke: #00a3ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"603.665872\" y=\"213.210239\" style=\"fill: #009dff; stroke: #009dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"603.924875\" y=\"213.242403\" style=\"fill: #0098ff; stroke: #0098ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"604.17969\" y=\"213.274047\" style=\"fill: #0092ff; stroke: #0092ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"604.430386\" y=\"213.30518\" style=\"fill: #008dff; stroke: #008dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"604.677028\" y=\"213.335809\" style=\"fill: #0088ff; stroke: #0088ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"604.919682\" y=\"213.365942\" style=\"fill: #0082ff; stroke: #0082ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"605.158413\" y=\"213.395589\" style=\"fill: #007dff; stroke: #007dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"605.393284\" y=\"213.424756\" style=\"fill: #0077ff; stroke: #0077ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"605.624358\" y=\"213.453452\" style=\"fill: #0072ff; stroke: #0072ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"605.851695\" y=\"213.481683\" style=\"fill: #006dff; stroke: #006dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"606.075357\" y=\"213.509458\" style=\"fill: #0067ff; stroke: #0067ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"606.295402\" y=\"213.536784\" style=\"fill: #0062ff; stroke: #0062ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"606.51189\" y=\"213.563669\" style=\"fill: #005cff; stroke: #005cff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"606.724877\" y=\"213.590118\" style=\"fill: #0057ff; stroke: #0057ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"606.934421\" y=\"213.61614\" style=\"fill: #0051ff; stroke: #0051ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"607.140576\" y=\"213.641741\" style=\"fill: #004cff; stroke: #004cff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"607.343399\" y=\"213.666929\" style=\"fill: #0047ff; stroke: #0047ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"607.542942\" y=\"213.691709\" style=\"fill: #0041ff; stroke: #0041ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"607.739259\" y=\"213.716088\" style=\"fill: #003cff; stroke: #003cff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"607.932401\" y=\"213.740073\" style=\"fill: #0036ff; stroke: #0036ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"608.122421\" y=\"213.763671\" style=\"fill: #0031ff; stroke: #0031ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"608.309369\" y=\"213.786886\" style=\"fill: #002bff; stroke: #002bff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"608.493294\" y=\"213.809727\" style=\"fill: #0026ff; stroke: #0026ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"608.674245\" y=\"213.832198\" style=\"fill: #0021ff; stroke: #0021ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"608.85227\" y=\"213.854306\" style=\"fill: #001bff; stroke: #001bff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"609.027417\" y=\"213.876056\" style=\"fill: #0016ff; stroke: #0016ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"609.199732\" y=\"213.897455\" style=\"fill: #0010ff; stroke: #0010ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"609.369261\" y=\"213.918508\" style=\"fill: #000bff; stroke: #000bff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"609.536049\" y=\"213.93922\" style=\"fill: #0005ff; stroke: #0005ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"609.70014\" y=\"213.959598\" style=\"fill: #0000ff; stroke: #0000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"609.861578\" y=\"213.979646\" style=\"fill: #0500ff; stroke: #0500ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"610.020406\" y=\"213.99937\" style=\"fill: #0b00ff; stroke: #0b00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"610.176666\" y=\"214.018775\" style=\"fill: #1000ff; stroke: #1000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"610.3304\" y=\"214.037866\" style=\"fill: #1600ff; stroke: #1600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"610.481648\" y=\"214.056648\" style=\"fill: #1b00ff; stroke: #1b00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"610.63045\" y=\"214.075127\" style=\"fill: #2100ff; stroke: #2100ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"610.776846\" y=\"214.093307\" style=\"fill: #2600ff; stroke: #2600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"610.920876\" y=\"214.111193\" style=\"fill: #2b00ff; stroke: #2b00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"611.062577\" y=\"214.12879\" style=\"fill: #3100ff; stroke: #3100ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"611.201986\" y=\"214.146103\" style=\"fill: #3600ff; stroke: #3600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"611.339142\" y=\"214.163135\" style=\"fill: #3c00ff; stroke: #3c00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"611.47408\" y=\"214.179892\" style=\"fill: #4100ff; stroke: #4100ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"611.606836\" y=\"214.196378\" style=\"fill: #4700ff; stroke: #4700ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"611.737446\" y=\"214.212598\" style=\"fill: #4c00ff; stroke: #4c00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"611.865944\" y=\"214.228555\" style=\"fill: #5100ff; stroke: #5100ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"611.992364\" y=\"214.244255\" style=\"fill: #5700ff; stroke: #5700ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"612.116741\" y=\"214.2597\" style=\"fill: #5c00ff; stroke: #5c00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"612.239106\" y=\"214.274896\" style=\"fill: #6200ff; stroke: #6200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"612.359493\" y=\"214.289846\" style=\"fill: #6700ff; stroke: #6700ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"612.477934\" y=\"214.304555\" style=\"fill: #6d00ff; stroke: #6d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"612.594459\" y=\"214.319025\" style=\"fill: #7200ff; stroke: #7200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"612.7091\" y=\"214.333262\" style=\"fill: #7700ff; stroke: #7700ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"612.821888\" y=\"214.347268\" style=\"fill: #7d00ff; stroke: #7d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"612.932852\" y=\"214.361048\" style=\"fill: #8200ff; stroke: #8200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.042023\" y=\"214.374605\" style=\"fill: #8800ff; stroke: #8800ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.149428\" y=\"214.387943\" style=\"fill: #8d00ff; stroke: #8d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.255096\" y=\"214.401066\" style=\"fill: #9200ff; stroke: #9200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.359056\" y=\"214.413976\" style=\"fill: #9800ff; stroke: #9800ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.461335\" y=\"214.426677\" style=\"fill: #9d00ff; stroke: #9d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.56196\" y=\"214.439173\" style=\"fill: #a300ff; stroke: #a300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.660959\" y=\"214.451467\" style=\"fill: #a800ff; stroke: #a800ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.758356\" y=\"214.463562\" style=\"fill: #ae00ff; stroke: #ae00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.854179\" y=\"214.475462\" style=\"fill: #b300ff; stroke: #b300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"613.948453\" y=\"214.487169\" style=\"fill: #b800ff; stroke: #b800ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.041202\" y=\"214.498687\" style=\"fill: #be00ff; stroke: #be00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.132452\" y=\"214.510019\" style=\"fill: #c300ff; stroke: #c300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.222227\" y=\"214.521168\" style=\"fill: #c900ff; stroke: #c900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.310549\" y=\"214.532136\" style=\"fill: #ce00ff; stroke: #ce00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.397444\" y=\"214.542927\" style=\"fill: #d400ff; stroke: #d400ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.482934\" y=\"214.553543\" style=\"fill: #d900ff; stroke: #d900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.567042\" y=\"214.563988\" style=\"fill: #de00ff; stroke: #de00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.64979\" y=\"214.574264\" style=\"fill: #e400ff; stroke: #e400ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.731199\" y=\"214.584374\" style=\"fill: #e900ff; stroke: #e900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.811293\" y=\"214.59432\" style=\"fill: #ef00ff; stroke: #ef00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.890092\" y=\"214.604106\" style=\"fill: #f400ff; stroke: #f400ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"614.967616\" y=\"214.613733\" style=\"fill: #fa00ff; stroke: #fa00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.043887\" y=\"214.623204\" style=\"fill: #ff00ff; stroke: #ff00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.118925\" y=\"214.632523\" style=\"fill: #ff00fa; stroke: #ff00fa\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.19275\" y=\"214.641691\" style=\"fill: #ff00f4; stroke: #ff00f4\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.265381\" y=\"214.65071\" style=\"fill: #ff00ef; stroke: #ff00ef\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.336837\" y=\"214.659584\" style=\"fill: #ff00e9; stroke: #ff00e9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.407139\" y=\"214.668314\" style=\"fill: #ff00e4; stroke: #ff00e4\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.476303\" y=\"214.676904\" style=\"fill: #ff00de; stroke: #ff00de\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.54435\" y=\"214.685354\" style=\"fill: #ff00d9; stroke: #ff00d9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.611296\" y=\"214.693667\" style=\"fill: #ff00d4; stroke: #ff00d4\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.677159\" y=\"214.701847\" style=\"fill: #ff00ce; stroke: #ff00ce\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.741958\" y=\"214.709894\" style=\"fill: #ff00c9; stroke: #ff00c9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.805709\" y=\"214.71781\" style=\"fill: #ff00c3; stroke: #ff00c3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.86843\" y=\"214.725599\" style=\"fill: #ff00be; stroke: #ff00be\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.930136\" y=\"214.733262\" style=\"fill: #ff00b8; stroke: #ff00b8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"615.990845\" y=\"214.740801\" style=\"fill: #ff00b3; stroke: #ff00b3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.050572\" y=\"214.748218\" style=\"fill: #ff00ae; stroke: #ff00ae\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.109333\" y=\"214.755516\" style=\"fill: #ff00a8; stroke: #ff00a8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.167144\" y=\"214.762695\" style=\"fill: #ff00a3; stroke: #ff00a3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.224021\" y=\"214.769758\" style=\"fill: #ff009d; stroke: #ff009d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.279978\" y=\"214.776707\" style=\"fill: #ff0098; stroke: #ff0098\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.33503\" y=\"214.783543\" style=\"fill: #ff0092; stroke: #ff0092\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.389192\" y=\"214.790269\" style=\"fill: #ff008d; stroke: #ff008d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.442478\" y=\"214.796887\" style=\"fill: #ff0088; stroke: #ff0088\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.494903\" y=\"214.803397\" style=\"fill: #ff0082; stroke: #ff0082\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.54648\" y=\"214.809802\" style=\"fill: #ff007d; stroke: #ff007d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.597223\" y=\"214.816104\" style=\"fill: #ff0077; stroke: #ff0077\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.647146\" y=\"214.822303\" style=\"fill: #ff0072; stroke: #ff0072\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.696262\" y=\"214.828403\" style=\"fill: #ff006d; stroke: #ff006d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.744583\" y=\"214.834403\" style=\"fill: #ff0067; stroke: #ff0067\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.792123\" y=\"214.840307\" style=\"fill: #ff0062; stroke: #ff0062\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.838895\" y=\"214.846115\" style=\"fill: #ff005c; stroke: #ff005c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.88491\" y=\"214.85183\" style=\"fill: #ff0057; stroke: #ff0057\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.930182\" y=\"214.857452\" style=\"fill: #ff0051; stroke: #ff0051\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"616.974721\" y=\"214.862983\" style=\"fill: #ff004c; stroke: #ff004c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.01854\" y=\"214.868424\" style=\"fill: #ff0047; stroke: #ff0047\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.061651\" y=\"214.873778\" style=\"fill: #ff0041; stroke: #ff0041\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.104065\" y=\"214.879045\" style=\"fill: #ff003c; stroke: #ff003c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.145792\" y=\"214.884227\" style=\"fill: #ff0036; stroke: #ff0036\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.186846\" y=\"214.889325\" style=\"fill: #ff0031; stroke: #ff0031\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.227235\" y=\"214.894341\" style=\"fill: #ff002b; stroke: #ff002b\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.266972\" y=\"214.899276\" style=\"fill: #ff0026; stroke: #ff0026\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.306066\" y=\"214.90413\" style=\"fill: #ff0021; stroke: #ff0021\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.344528\" y=\"214.908907\" style=\"fill: #ff001b; stroke: #ff001b\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.382368\" y=\"214.913606\" style=\"fill: #ff0016; stroke: #ff0016\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.419596\" y=\"214.918229\" style=\"fill: #ff0010; stroke: #ff0010\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.456222\" y=\"214.922777\" style=\"fill: #ff000b; stroke: #ff000b\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#C0_0_25897c0149\" x=\"617.492256\" y=\"214.927252\" style=\"fill: #ff0005; stroke: #ff0005\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"mf603de8594\" d=\"M -3 3 \n",
       "L 3 3 \n",
       "L 3 -3 \n",
       "L -3 -3 \n",
       "z\n",
       "\" style=\"stroke: #000000\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <use xlink:href=\"#mf603de8594\" x=\"619.684883\" y=\"215.199541\" style=\"fill: #ff0000; stroke: #000000\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_35\">\n",
       "      <path d=\"M 432.547078 299.518125 \n",
       "L 432.547078 22.318125 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"432.547078\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- −1.0 -->\n",
       "      <g transform=\"translate(420.405672 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-2212\" d=\"M 678 2272 \n",
       "L 4684 2272 \n",
       "L 4684 1741 \n",
       "L 678 1741 \n",
       "L 678 2272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-2212\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-31\" x=\"83.789062\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"147.412109\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"179.199219\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <path d=\"M 482.576512 299.518125 \n",
       "L 482.576512 22.318125 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"482.576512\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- −0.5 -->\n",
       "      <g transform=\"translate(470.435105 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-2212\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"83.789062\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"147.412109\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"179.199219\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <path d=\"M 532.605945 299.518125 \n",
       "L 532.605945 22.318125 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"532.605945\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.0 -->\n",
       "      <g transform=\"translate(524.654383 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_41\">\n",
       "      <path d=\"M 582.635378 299.518125 \n",
       "L 582.635378 22.318125 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_42\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"582.635378\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.5 -->\n",
       "      <g transform=\"translate(574.683816 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_43\">\n",
       "      <path d=\"M 632.664812 299.518125 \n",
       "L 632.664812 22.318125 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_44\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"632.664812\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 1.0 -->\n",
       "      <g transform=\"translate(624.713249 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_45\">\n",
       "      <path d=\"M 682.694245 299.518125 \n",
       "L 682.694245 22.318125 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_46\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9f4931835\" x=\"682.694245\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 1.5 -->\n",
       "      <g transform=\"translate(674.742683 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_27\">\n",
       "     <!-- x -->\n",
       "     <g transform=\"translate(564.602557 327.794688) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-78\" d=\"M 3513 3500 \n",
       "L 2247 1797 \n",
       "L 3578 0 \n",
       "L 2900 0 \n",
       "L 1881 1375 \n",
       "L 863 0 \n",
       "L 184 0 \n",
       "L 1544 1831 \n",
       "L 300 3500 \n",
       "L 978 3500 \n",
       "L 1906 2253 \n",
       "L 2834 3500 \n",
       "L 3513 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-78\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_47\">\n",
       "      <path d=\"M 415.380114 288.473877 \n",
       "L 719.74375 288.473877 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_48\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"415.380114\" y=\"288.473877\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.0 -->\n",
       "      <g transform=\"translate(392.476989 292.273096) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_49\">\n",
       "      <path d=\"M 415.380114 246.314585 \n",
       "L 719.74375 246.314585 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_50\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"415.380114\" y=\"246.314585\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- 0.5 -->\n",
       "      <g transform=\"translate(392.476989 250.113804) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_51\">\n",
       "      <path d=\"M 415.380114 204.155293 \n",
       "L 719.74375 204.155293 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_52\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"415.380114\" y=\"204.155293\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- 1.0 -->\n",
       "      <g transform=\"translate(392.476989 207.954512) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_53\">\n",
       "      <path d=\"M 415.380114 161.996001 \n",
       "L 719.74375 161.996001 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_54\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"415.380114\" y=\"161.996001\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- 1.5 -->\n",
       "      <g transform=\"translate(392.476989 165.79522) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_55\">\n",
       "      <path d=\"M 415.380114 119.836709 \n",
       "L 719.74375 119.836709 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_56\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"415.380114\" y=\"119.836709\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_32\">\n",
       "      <!-- 2.0 -->\n",
       "      <g transform=\"translate(392.476989 123.635928) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_57\">\n",
       "      <path d=\"M 415.380114 77.677417 \n",
       "L 719.74375 77.677417 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_58\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"415.380114\" y=\"77.677417\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_33\">\n",
       "      <!-- 2.5 -->\n",
       "      <g transform=\"translate(392.476989 81.476636) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_59\">\n",
       "      <path d=\"M 415.380114 35.518125 \n",
       "L 719.74375 35.518125 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_60\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mf8caf999c3\" x=\"415.380114\" y=\"35.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_34\">\n",
       "      <!-- 3.0 -->\n",
       "      <g transform=\"translate(392.476989 39.317344) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-33\" d=\"M 2597 2516 \n",
       "Q 3050 2419 3304 2112 \n",
       "Q 3559 1806 3559 1356 \n",
       "Q 3559 666 3084 287 \n",
       "Q 2609 -91 1734 -91 \n",
       "Q 1441 -91 1130 -33 \n",
       "Q 819 25 488 141 \n",
       "L 488 750 \n",
       "Q 750 597 1062 519 \n",
       "Q 1375 441 1716 441 \n",
       "Q 2309 441 2620 675 \n",
       "Q 2931 909 2931 1356 \n",
       "Q 2931 1769 2642 2001 \n",
       "Q 2353 2234 1838 2234 \n",
       "L 1294 2234 \n",
       "L 1294 2753 \n",
       "L 1863 2753 \n",
       "Q 2328 2753 2575 2939 \n",
       "Q 2822 3125 2822 3475 \n",
       "Q 2822 3834 2567 4026 \n",
       "Q 2313 4219 1838 4219 \n",
       "Q 1578 4219 1281 4162 \n",
       "Q 984 4106 628 3988 \n",
       "L 628 4550 \n",
       "Q 988 4650 1302 4700 \n",
       "Q 1616 4750 1894 4750 \n",
       "Q 2613 4750 3031 4423 \n",
       "Q 3450 4097 3450 3541 \n",
       "Q 3450 3153 3228 2886 \n",
       "Q 3006 2619 2597 2516 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-33\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_35\">\n",
       "     <!-- y -->\n",
       "     <g transform=\"translate(386.397301 163.8775) rotate(-90) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-79\" d=\"M 2059 -325 \n",
       "Q 1816 -950 1584 -1140 \n",
       "Q 1353 -1331 966 -1331 \n",
       "L 506 -1331 \n",
       "L 506 -850 \n",
       "L 844 -850 \n",
       "Q 1081 -850 1212 -737 \n",
       "Q 1344 -625 1503 -206 \n",
       "L 1606 56 \n",
       "L 191 3500 \n",
       "L 800 3500 \n",
       "L 1894 763 \n",
       "L 2988 3500 \n",
       "L 3597 3500 \n",
       "L 2059 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-79\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_61\">\n",
       "    <path d=\"M 432.547078 35.518125 \n",
       "L 430.746019 66.024589 \n",
       "L 429.922214 90.616046 \n",
       "L 429.87362 110.45314 \n",
       "L 430.438043 126.468544 \n",
       "L 431.485311 139.411749 \n",
       "L 432.910977 149.885037 \n",
       "L 434.631269 158.372407 \n",
       "L 436.57902 165.2628 \n",
       "L 438.70041 170.868779 \n",
       "L 440.952337 175.441526 \n",
       "L 443.300311 179.182901 \n",
       "L 445.71676 182.255132 \n",
       "L 448.179669 184.788595 \n",
       "L 450.671487 186.888075 \n",
       "L 453.178244 188.637791 \n",
       "L 455.688852 190.105434 \n",
       "L 458.194529 191.345417 \n",
       "L 460.688351 192.401478 \n",
       "L 465.619872 194.095599 \n",
       "L 470.452864 195.39426 \n",
       "L 475.169356 196.430997 \n",
       "L 482.005441 197.675435 \n",
       "L 490.65812 198.998655 \n",
       "L 504.551167 200.863321 \n",
       "L 540.543448 205.371206 \n",
       "L 617.492256 214.927252 \n",
       "L 617.492256 214.927252 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke-dasharray: 5.55,2.4; stroke-dashoffset: 0; stroke: #ff0000; stroke-opacity: 0.6; stroke-width: 1.5\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_3\">\n",
       "    <path d=\"M 588.036996 211.368252 \n",
       "L 587.996603 210.941027 \n",
       "L 588.353319 210.502507 \n",
       "L 589.608709 209.237621 \n",
       "L 590.37471 208.894688 \n",
       "L 592.396101 208.148318 \n",
       "L 594.417493 207.565576 \n",
       "L 594.552252 207.534215 \n",
       "L 596.438884 207.239711 \n",
       "L 598.460275 206.996531 \n",
       "L 600.481666 206.818594 \n",
       "L 602.503058 206.699041 \n",
       "L 604.524449 206.631942 \n",
       "L 606.54584 206.612145 \n",
       "L 608.567231 206.635149 \n",
       "L 610.588623 206.697009 \n",
       "L 612.610014 206.794249 \n",
       "L 614.631405 206.923796 \n",
       "L 616.652796 207.082923 \n",
       "L 618.674188 207.269201 \n",
       "L 620.695579 207.48046 \n",
       "L 621.150023 207.534215 \n",
       "L 622.71697 207.757716 \n",
       "L 624.738361 208.070888 \n",
       "L 626.759753 208.404704 \n",
       "L 628.781144 208.75735 \n",
       "L 630.802535 209.127218 \n",
       "L 631.369674 209.237621 \n",
       "L 632.823926 209.583867 \n",
       "L 634.845318 210.081389 \n",
       "L 636.866709 210.589171 \n",
       "L 638.228054 210.941027 \n",
       "L 638.8881 211.156579 \n",
       "L 640.909491 211.833878 \n",
       "L 642.930883 212.509494 \n",
       "L 643.323569 212.644432 \n",
       "L 644.952274 213.384242 \n",
       "L 646.973665 214.285793 \n",
       "L 647.110264 214.347838 \n",
       "L 648.995056 215.582242 \n",
       "L 649.726138 216.051244 \n",
       "L 651.016448 217.534437 \n",
       "L 651.212113 217.75465 \n",
       "L 651.373164 219.458055 \n",
       "L 651.016448 219.896575 \n",
       "L 649.761057 221.161461 \n",
       "L 648.995056 221.504394 \n",
       "L 646.973665 222.250763 \n",
       "L 644.952274 222.833506 \n",
       "L 644.817514 222.864867 \n",
       "L 642.930883 223.159371 \n",
       "L 640.909491 223.40255 \n",
       "L 638.8881 223.580487 \n",
       "L 636.866709 223.700041 \n",
       "L 634.845318 223.767139 \n",
       "L 632.823926 223.786937 \n",
       "L 630.802535 223.763933 \n",
       "L 628.781144 223.702073 \n",
       "L 626.759753 223.604832 \n",
       "L 624.738361 223.475285 \n",
       "L 622.71697 223.316159 \n",
       "L 620.695579 223.129881 \n",
       "L 619.78298 223.034504 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_4\">\n",
       "    <path d=\"M 625.327382 233.314199 \n",
       "L 620.695579 232.841589 \n",
       "L 610.588623 231.552236 \n",
       "L 604.524449 230.589817 \n",
       "L 596.438884 229.111583 \n",
       "L 588.353319 227.359846 \n",
       "L 582.289145 225.846711 \n",
       "L 576.224971 224.119813 \n",
       "L 570.160798 222.126934 \n",
       "L 566.118015 220.617818 \n",
       "L 562.075233 218.902202 \n",
       "L 559.611919 217.75465 \n",
       "L 556.011059 215.746128 \n",
       "L 553.848139 214.347838 \n",
       "L 551.726403 212.644432 \n",
       "L 549.946885 210.660861 \n",
       "L 549.061655 209.237621 \n",
       "L 548.583226 207.534215 \n",
       "L 548.759091 205.830809 \n",
       "L 549.946885 203.868042 \n",
       "L 551.968276 202.163324 \n",
       "L 554.608628 200.720592 \n",
       "L 558.03245 199.471295 \n",
       "L 560.053841 198.866834 \n",
       "L 564.096624 197.96462 \n",
       "L 568.139406 197.253747 \n",
       "L 574.20358 196.567041 \n",
       "L 580.267754 196.137061 \n",
       "L 586.331928 195.928251 \n",
       "L 592.396101 195.911333 \n",
       "L 600.481666 196.145806 \n",
       "L 608.567231 196.631504 \n",
       "L 616.652796 197.332467 \n",
       "L 626.759753 198.568491 \n",
       "L 632.823926 199.473571 \n",
       "L 640.909491 200.881466 \n",
       "L 648.995056 202.559761 \n",
       "L 657.080621 204.55237 \n",
       "L 663.144795 206.279268 \n",
       "L 669.208969 208.272148 \n",
       "L 673.251751 209.781264 \n",
       "L 677.294534 211.49688 \n",
       "L 679.757847 212.644432 \n",
       "L 683.358708 214.652954 \n",
       "L 685.521627 216.051244 \n",
       "L 687.643363 217.75465 \n",
       "L 689.422881 219.738221 \n",
       "L 690.308111 221.161461 \n",
       "L 690.78654 222.864867 \n",
       "L 690.610675 224.568272 \n",
       "L 689.422881 226.53104 \n",
       "L 687.40149 228.235757 \n",
       "L 684.761138 229.67849 \n",
       "L 681.337316 230.927787 \n",
       "L 679.315925 231.532248 \n",
       "L 675.273143 232.434462 \n",
       "L 671.23036 233.145335 \n",
       "L 665.166186 233.832041 \n",
       "L 660.563466 234.177329 \n",
       "L 660.563466 234.177329 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_5\">\n",
       "    <path d=\"M 640.128211 194.55603 \n",
       "L 648.995056 196.154242 \n",
       "L 657.080621 197.818504 \n",
       "L 665.166186 199.703574 \n",
       "L 673.251751 201.835774 \n",
       "L 679.315925 203.627946 \n",
       "L 683.358708 204.936405 \n",
       "L 689.422881 207.087483 \n",
       "L 693.465664 208.689567 \n",
       "L 697.508446 210.455511 \n",
       "L 699.529838 211.417478 \n",
       "L 703.57262 213.556416 \n",
       "L 705.594011 214.752031 \n",
       "L 707.615403 216.058868 \n",
       "L 709.855602 217.75465 \n",
       "L 711.729111 219.458055 \n",
       "L 713.207024 221.161461 \n",
       "L 714.280836 222.864867 \n",
       "L 714.924368 224.568272 \n",
       "L 715.106348 226.271678 \n",
       "L 714.778453 227.975084 \n",
       "L 713.679576 229.916265 \n",
       "L 712.324373 231.381895 \n",
       "L 709.977883 233.085301 \n",
       "L 707.615403 234.314734 \n",
       "L 705.594011 235.192881 \n",
       "L 701.551229 236.597783 \n",
       "L 697.508446 237.64827 \n",
       "L 693.465664 238.502783 \n",
       "L 687.40149 239.466681 \n",
       "L 681.337316 240.1637 \n",
       "L 675.273143 240.631373 \n",
       "L 667.187578 240.995744 \n",
       "L 659.102013 241.09946 \n",
       "L 651.016448 240.975235 \n",
       "L 642.930883 240.650527 \n",
       "L 632.823926 239.997747 \n",
       "L 624.738361 239.25793 \n",
       "L 614.631405 238.120056 \n",
       "L 603.149069 236.492113 \n",
       "L 593.183685 234.788707 \n",
       "L 584.310536 233.027925 \n",
       "L 574.20358 230.695508 \n",
       "L 566.118015 228.563308 \n",
       "L 560.053841 226.771136 \n",
       "L 556.011059 225.462677 \n",
       "L 549.946885 223.311599 \n",
       "L 545.904103 221.709515 \n",
       "L 541.86132 219.943571 \n",
       "L 539.839929 218.981603 \n",
       "L 535.797147 216.842666 \n",
       "L 533.775755 215.647051 \n",
       "L 531.754364 214.340214 \n",
       "L 529.514165 212.644432 \n",
       "L 527.640656 210.941027 \n",
       "L 526.162742 209.237621 \n",
       "L 525.088931 207.534215 \n",
       "L 524.445399 205.830809 \n",
       "L 524.263418 204.127404 \n",
       "L 524.591313 202.423998 \n",
       "L 525.69019 200.482817 \n",
       "L 527.045393 199.017186 \n",
       "L 529.391883 197.313781 \n",
       "L 531.754364 196.084348 \n",
       "L 533.775755 195.206201 \n",
       "L 537.818538 193.801299 \n",
       "L 541.86132 192.750811 \n",
       "L 545.904103 191.896299 \n",
       "L 551.968276 190.932401 \n",
       "L 558.03245 190.235382 \n",
       "L 564.096624 189.767709 \n",
       "L 572.182189 189.403338 \n",
       "L 580.267754 189.299621 \n",
       "L 588.353319 189.423846 \n",
       "L 596.438884 189.748555 \n",
       "L 605.208538 190.301564 \n",
       "L 605.208538 190.301564 \n",
       "\" clip-path=\"url(#p727fca3bc1)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 415.380114 299.518125 \n",
       "L 415.380114 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 719.74375 299.518125 \n",
       "L 719.74375 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 415.380114 299.518125 \n",
       "L 719.74375 299.518125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 415.380114 22.318125 \n",
       "L 719.74375 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_36\">\n",
       "    <!-- Trajectory -->\n",
       "    <g transform=\"translate(537.939744 16.318125) scale(0.12 -0.12)\">\n",
       "     <defs>\n",
       "      <path id=\"DejaVuSans-54\" d=\"M -19 4666 \n",
       "L 3928 4666 \n",
       "L 3928 4134 \n",
       "L 2272 4134 \n",
       "L 2272 0 \n",
       "L 1638 0 \n",
       "L 1638 4134 \n",
       "L -19 4134 \n",
       "L -19 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"DejaVuSans-6a\" d=\"M 603 3500 \n",
       "L 1178 3500 \n",
       "L 1178 -63 \n",
       "Q 1178 -731 923 -1031 \n",
       "Q 669 -1331 103 -1331 \n",
       "L -116 -1331 \n",
       "L -116 -844 \n",
       "L 38 -844 \n",
       "Q 366 -844 484 -692 \n",
       "Q 603 -541 603 -63 \n",
       "L 603 3500 \n",
       "z\n",
       "M 603 4863 \n",
       "L 1178 4863 \n",
       "L 1178 4134 \n",
       "L 603 4134 \n",
       "L 603 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"DejaVuSans-63\" d=\"M 3122 3366 \n",
       "L 3122 2828 \n",
       "Q 2878 2963 2633 3030 \n",
       "Q 2388 3097 2138 3097 \n",
       "Q 1578 3097 1268 2742 \n",
       "Q 959 2388 959 1747 \n",
       "Q 959 1106 1268 751 \n",
       "Q 1578 397 2138 397 \n",
       "Q 2388 397 2633 464 \n",
       "Q 2878 531 3122 666 \n",
       "L 3122 134 \n",
       "Q 2881 22 2623 -34 \n",
       "Q 2366 -91 2075 -91 \n",
       "Q 1284 -91 818 406 \n",
       "Q 353 903 353 1747 \n",
       "Q 353 2603 823 3093 \n",
       "Q 1294 3584 2113 3584 \n",
       "Q 2378 3584 2631 3529 \n",
       "Q 2884 3475 3122 3366 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#DejaVuSans-54\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-72\" x=\"46.333984\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-61\" x=\"87.447266\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-6a\" x=\"148.726562\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-65\" x=\"176.509766\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-63\" x=\"238.033203\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-74\" x=\"293.013672\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-6f\" x=\"332.222656\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-72\" x=\"393.404297\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-79\" x=\"434.517578\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_37\">\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <!-- 0.0871 -->\n",
       "     <g transform=\"translate(588.478897 217.787295) rotate(-342.830279) scale(0.08 -0.08)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-38\" d=\"M 2034 2216 \n",
       "Q 1584 2216 1326 1975 \n",
       "Q 1069 1734 1069 1313 \n",
       "Q 1069 891 1326 650 \n",
       "Q 1584 409 2034 409 \n",
       "Q 2484 409 2743 651 \n",
       "Q 3003 894 3003 1313 \n",
       "Q 3003 1734 2745 1975 \n",
       "Q 2488 2216 2034 2216 \n",
       "z\n",
       "M 1403 2484 \n",
       "Q 997 2584 770 2862 \n",
       "Q 544 3141 544 3541 \n",
       "Q 544 4100 942 4425 \n",
       "Q 1341 4750 2034 4750 \n",
       "Q 2731 4750 3128 4425 \n",
       "Q 3525 4100 3525 3541 \n",
       "Q 3525 3141 3298 2862 \n",
       "Q 3072 2584 2669 2484 \n",
       "Q 3125 2378 3379 2068 \n",
       "Q 3634 1759 3634 1313 \n",
       "Q 3634 634 3220 271 \n",
       "Q 2806 -91 2034 -91 \n",
       "Q 1263 -91 848 271 \n",
       "Q 434 634 434 1313 \n",
       "Q 434 1759 690 2068 \n",
       "Q 947 2378 1403 2484 \n",
       "z\n",
       "M 1172 3481 \n",
       "Q 1172 3119 1398 2916 \n",
       "Q 1625 2713 2034 2713 \n",
       "Q 2441 2713 2670 2916 \n",
       "Q 2900 3119 2900 3481 \n",
       "Q 2900 3844 2670 4047 \n",
       "Q 2441 4250 2034 4250 \n",
       "Q 1625 4250 1398 4047 \n",
       "Q 1172 3844 1172 3481 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-38\" x=\"159.033203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-37\" x=\"222.65625\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-31\" x=\"286.279297\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_38\">\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <!-- 0.4204 -->\n",
       "     <g transform=\"translate(628.881505 236.243915) rotate(-358.495689) scale(0.08 -0.08)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-34\" d=\"M 2419 4116 \n",
       "L 825 1625 \n",
       "L 2419 1625 \n",
       "L 2419 4116 \n",
       "z\n",
       "M 2253 4666 \n",
       "L 3047 4666 \n",
       "L 3047 1625 \n",
       "L 3713 1625 \n",
       "L 3713 1100 \n",
       "L 3047 1100 \n",
       "L 3047 0 \n",
       "L 2419 0 \n",
       "L 2419 1100 \n",
       "L 313 1100 \n",
       "L 313 1709 \n",
       "L 2253 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-34\" x=\"95.410156\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-32\" x=\"159.033203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-30\" x=\"222.65625\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-34\" x=\"286.279297\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_39\">\n",
       "    <g clip-path=\"url(#p727fca3bc1)\">\n",
       "     <!-- 0.7538 -->\n",
       "     <g transform=\"translate(608.556606 192.53311) rotate(-353.068116) scale(0.08 -0.08)\">\n",
       "      <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-37\" x=\"95.410156\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-33\" x=\"222.65625\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-38\" x=\"286.279297\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pfa035fbd2e\">\n",
       "   <rect x=\"50.14375\" y=\"22.318125\" width=\"304.363636\" height=\"277.2\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p727fca3bc1\">\n",
       "   <rect x=\"415.380114\" y=\"22.318125\" width=\"304.363636\" height=\"277.2\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1200x500 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "A = np.array([[1, -2.1], [1, 1.2], [1, 4.8]])\n",
    "b = np.array([-1, 2, 5])\n",
    "oracle = LinRegOracle(A, b)\n",
    "test_2d(\"gd\", oracle, np.array([-1, 3.0]), lr=0.01, tol=1e-6)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "de8a1c6f",
   "metadata": {},
   "source": [
    "### Task 2.6 (0.5 points)\n",
    "\n",
    "Apply gradient descent algorithm to simple linear regression trained on `boston` dataset. Take `lstat` as feature, `medv` as target. Provide some visualizations."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "2f1c6dde",
   "metadata": {
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [],
   "source": [
    "import pandas as pd\n",
    "boston = pd.read_csv(\"../datasets/ISLP/Boston.csv\").drop(\"Unnamed: 0\", axis=1)\n",
    "# YOUR CODE HERE"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "78bf78dd",
   "metadata": {},
   "source": [
    "### GD for logistic regression\n",
    "\n",
    "The targets must be from $\\{-1, 1\\}$. One more toy example:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 66,
   "id": "adf1cddf",
   "metadata": {
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "success 525 iterations\n"
     ]
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"726.94375pt\" height=\"337.074375pt\" viewBox=\"0 0 726.94375 337.074375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-03-26T14:49:22.473723</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.7.1, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 337.074375 \n",
       "L 726.94375 337.074375 \n",
       "L 726.94375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 50.14375 299.518125 \n",
       "L 354.507386 299.518125 \n",
       "L 354.507386 22.318125 \n",
       "L 50.14375 22.318125 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <path d=\"M 50.14375 299.518125 \n",
       "L 50.14375 22.318125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_2\">\n",
       "      <defs>\n",
       "       <path id=\"mcef5502930\" d=\"M 0 0 \n",
       "L 0 3.5 \n",
       "\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"50.14375\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(46.9625 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-30\" d=\"M 2034 4250 \n",
       "Q 1547 4250 1301 3770 \n",
       "Q 1056 3291 1056 2328 \n",
       "Q 1056 1369 1301 889 \n",
       "Q 1547 409 2034 409 \n",
       "Q 2525 409 2770 889 \n",
       "Q 3016 1369 3016 2328 \n",
       "Q 3016 3291 2770 3770 \n",
       "Q 2525 4250 2034 4250 \n",
       "z\n",
       "M 2034 4750 \n",
       "Q 2819 4750 3233 4129 \n",
       "Q 3647 3509 3647 2328 \n",
       "Q 3647 1150 3233 529 \n",
       "Q 2819 -91 2034 -91 \n",
       "Q 1250 -91 836 529 \n",
       "Q 422 1150 422 2328 \n",
       "Q 422 3509 836 4129 \n",
       "Q 1250 4750 2034 4750 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <path d=\"M 108.228413 299.518125 \n",
       "L 108.228413 22.318125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"108.228413\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 100 -->\n",
       "      <g transform=\"translate(98.684663 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-31\" d=\"M 794 531 \n",
       "L 1825 531 \n",
       "L 1825 4091 \n",
       "L 703 3866 \n",
       "L 703 4441 \n",
       "L 1819 4666 \n",
       "L 2450 4666 \n",
       "L 2450 531 \n",
       "L 3481 531 \n",
       "L 3481 0 \n",
       "L 794 0 \n",
       "L 794 531 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <path d=\"M 166.313077 299.518125 \n",
       "L 166.313077 22.318125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"166.313077\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 200 -->\n",
       "      <g transform=\"translate(156.769327 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-32\" d=\"M 1228 531 \n",
       "L 3431 531 \n",
       "L 3431 0 \n",
       "L 469 0 \n",
       "L 469 531 \n",
       "Q 828 903 1448 1529 \n",
       "Q 2069 2156 2228 2338 \n",
       "Q 2531 2678 2651 2914 \n",
       "Q 2772 3150 2772 3378 \n",
       "Q 2772 3750 2511 3984 \n",
       "Q 2250 4219 1831 4219 \n",
       "Q 1534 4219 1204 4116 \n",
       "Q 875 4013 500 3803 \n",
       "L 500 4441 \n",
       "Q 881 4594 1212 4672 \n",
       "Q 1544 4750 1819 4750 \n",
       "Q 2544 4750 2975 4387 \n",
       "Q 3406 4025 3406 3419 \n",
       "Q 3406 3131 3298 2873 \n",
       "Q 3191 2616 2906 2266 \n",
       "Q 2828 2175 2409 1742 \n",
       "Q 1991 1309 1228 531 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <path d=\"M 224.39774 299.518125 \n",
       "L 224.39774 22.318125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"224.39774\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 300 -->\n",
       "      <g transform=\"translate(214.85399 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-33\" d=\"M 2597 2516 \n",
       "Q 3050 2419 3304 2112 \n",
       "Q 3559 1806 3559 1356 \n",
       "Q 3559 666 3084 287 \n",
       "Q 2609 -91 1734 -91 \n",
       "Q 1441 -91 1130 -33 \n",
       "Q 819 25 488 141 \n",
       "L 488 750 \n",
       "Q 750 597 1062 519 \n",
       "Q 1375 441 1716 441 \n",
       "Q 2309 441 2620 675 \n",
       "Q 2931 909 2931 1356 \n",
       "Q 2931 1769 2642 2001 \n",
       "Q 2353 2234 1838 2234 \n",
       "L 1294 2234 \n",
       "L 1294 2753 \n",
       "L 1863 2753 \n",
       "Q 2328 2753 2575 2939 \n",
       "Q 2822 3125 2822 3475 \n",
       "Q 2822 3834 2567 4026 \n",
       "Q 2313 4219 1838 4219 \n",
       "Q 1578 4219 1281 4162 \n",
       "Q 984 4106 628 3988 \n",
       "L 628 4550 \n",
       "Q 988 4650 1302 4700 \n",
       "Q 1616 4750 1894 4750 \n",
       "Q 2613 4750 3031 4423 \n",
       "Q 3450 4097 3450 3541 \n",
       "Q 3450 3153 3228 2886 \n",
       "Q 3006 2619 2597 2516 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-33\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <path d=\"M 282.482404 299.518125 \n",
       "L 282.482404 22.318125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"282.482404\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 400 -->\n",
       "      <g transform=\"translate(272.938654 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-34\" d=\"M 2419 4116 \n",
       "L 825 1625 \n",
       "L 2419 1625 \n",
       "L 2419 4116 \n",
       "z\n",
       "M 2253 4666 \n",
       "L 3047 4666 \n",
       "L 3047 1625 \n",
       "L 3713 1625 \n",
       "L 3713 1100 \n",
       "L 3047 1100 \n",
       "L 3047 0 \n",
       "L 2419 0 \n",
       "L 2419 1100 \n",
       "L 313 1100 \n",
       "L 313 1709 \n",
       "L 2253 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-34\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <path d=\"M 340.567067 299.518125 \n",
       "L 340.567067 22.318125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"340.567067\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 500 -->\n",
       "      <g transform=\"translate(331.023317 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-35\" d=\"M 691 4666 \n",
       "L 3169 4666 \n",
       "L 3169 4134 \n",
       "L 1269 4134 \n",
       "L 1269 2991 \n",
       "Q 1406 3038 1543 3061 \n",
       "Q 1681 3084 1819 3084 \n",
       "Q 2600 3084 3056 2656 \n",
       "Q 3513 2228 3513 1497 \n",
       "Q 3513 744 3044 326 \n",
       "Q 2575 -91 1722 -91 \n",
       "Q 1428 -91 1123 -41 \n",
       "Q 819 9 494 109 \n",
       "L 494 744 \n",
       "Q 775 591 1075 516 \n",
       "Q 1375 441 1709 441 \n",
       "Q 2250 441 2565 725 \n",
       "Q 2881 1009 2881 1497 \n",
       "Q 2881 1984 2565 2268 \n",
       "Q 2250 2553 1709 2553 \n",
       "Q 1456 2553 1204 2497 \n",
       "Q 953 2441 691 2322 \n",
       "L 691 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-35\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- Iteration -->\n",
       "     <g transform=\"translate(181.116974 327.794688) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-49\" d=\"M 628 4666 \n",
       "L 1259 4666 \n",
       "L 1259 0 \n",
       "L 628 0 \n",
       "L 628 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-74\" d=\"M 1172 4494 \n",
       "L 1172 3500 \n",
       "L 2356 3500 \n",
       "L 2356 3053 \n",
       "L 1172 3053 \n",
       "L 1172 1153 \n",
       "Q 1172 725 1289 603 \n",
       "Q 1406 481 1766 481 \n",
       "L 2356 481 \n",
       "L 2356 0 \n",
       "L 1766 0 \n",
       "Q 1100 0 847 248 \n",
       "Q 594 497 594 1153 \n",
       "L 594 3053 \n",
       "L 172 3053 \n",
       "L 172 3500 \n",
       "L 594 3500 \n",
       "L 594 4494 \n",
       "L 1172 4494 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-65\" d=\"M 3597 1894 \n",
       "L 3597 1613 \n",
       "L 953 1613 \n",
       "Q 991 1019 1311 708 \n",
       "Q 1631 397 2203 397 \n",
       "Q 2534 397 2845 478 \n",
       "Q 3156 559 3463 722 \n",
       "L 3463 178 \n",
       "Q 3153 47 2828 -22 \n",
       "Q 2503 -91 2169 -91 \n",
       "Q 1331 -91 842 396 \n",
       "Q 353 884 353 1716 \n",
       "Q 353 2575 817 3079 \n",
       "Q 1281 3584 2069 3584 \n",
       "Q 2775 3584 3186 3129 \n",
       "Q 3597 2675 3597 1894 \n",
       "z\n",
       "M 3022 2063 \n",
       "Q 3016 2534 2758 2815 \n",
       "Q 2500 3097 2075 3097 \n",
       "Q 1594 3097 1305 2825 \n",
       "Q 1016 2553 972 2059 \n",
       "L 3022 2063 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-72\" d=\"M 2631 2963 \n",
       "Q 2534 3019 2420 3045 \n",
       "Q 2306 3072 2169 3072 \n",
       "Q 1681 3072 1420 2755 \n",
       "Q 1159 2438 1159 1844 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1341 3275 1631 3429 \n",
       "Q 1922 3584 2338 3584 \n",
       "Q 2397 3584 2469 3576 \n",
       "Q 2541 3569 2628 3553 \n",
       "L 2631 2963 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-61\" d=\"M 2194 1759 \n",
       "Q 1497 1759 1228 1600 \n",
       "Q 959 1441 959 1056 \n",
       "Q 959 750 1161 570 \n",
       "Q 1363 391 1709 391 \n",
       "Q 2188 391 2477 730 \n",
       "Q 2766 1069 2766 1631 \n",
       "L 2766 1759 \n",
       "L 2194 1759 \n",
       "z\n",
       "M 3341 1997 \n",
       "L 3341 0 \n",
       "L 2766 0 \n",
       "L 2766 531 \n",
       "Q 2569 213 2275 61 \n",
       "Q 1981 -91 1556 -91 \n",
       "Q 1019 -91 701 211 \n",
       "Q 384 513 384 1019 \n",
       "Q 384 1609 779 1909 \n",
       "Q 1175 2209 1959 2209 \n",
       "L 2766 2209 \n",
       "L 2766 2266 \n",
       "Q 2766 2663 2505 2880 \n",
       "Q 2244 3097 1772 3097 \n",
       "Q 1472 3097 1187 3025 \n",
       "Q 903 2953 641 2809 \n",
       "L 641 3341 \n",
       "Q 956 3463 1253 3523 \n",
       "Q 1550 3584 1831 3584 \n",
       "Q 2591 3584 2966 3190 \n",
       "Q 3341 2797 3341 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-69\" d=\"M 603 3500 \n",
       "L 1178 3500 \n",
       "L 1178 0 \n",
       "L 603 0 \n",
       "L 603 3500 \n",
       "z\n",
       "M 603 4863 \n",
       "L 1178 4863 \n",
       "L 1178 4134 \n",
       "L 603 4134 \n",
       "L 603 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6f\" d=\"M 1959 3097 \n",
       "Q 1497 3097 1228 2736 \n",
       "Q 959 2375 959 1747 \n",
       "Q 959 1119 1226 758 \n",
       "Q 1494 397 1959 397 \n",
       "Q 2419 397 2687 759 \n",
       "Q 2956 1122 2956 1747 \n",
       "Q 2956 2369 2687 2733 \n",
       "Q 2419 3097 1959 3097 \n",
       "z\n",
       "M 1959 3584 \n",
       "Q 2709 3584 3137 3096 \n",
       "Q 3566 2609 3566 1747 \n",
       "Q 3566 888 3137 398 \n",
       "Q 2709 -91 1959 -91 \n",
       "Q 1206 -91 779 398 \n",
       "Q 353 888 353 1747 \n",
       "Q 353 2609 779 3096 \n",
       "Q 1206 3584 1959 3584 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6e\" d=\"M 3513 2113 \n",
       "L 3513 0 \n",
       "L 2938 0 \n",
       "L 2938 2094 \n",
       "Q 2938 2591 2744 2837 \n",
       "Q 2550 3084 2163 3084 \n",
       "Q 1697 3084 1428 2787 \n",
       "Q 1159 2491 1159 1978 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1366 3272 1645 3428 \n",
       "Q 1925 3584 2291 3584 \n",
       "Q 2894 3584 3203 3211 \n",
       "Q 3513 2838 3513 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-49\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"29.492188\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"68.701172\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"130.224609\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"171.337891\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"232.617188\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"271.826172\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6f\" x=\"299.609375\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"360.791016\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <path d=\"M 50.14375 299.518125 \n",
       "L 354.507386 299.518125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_14\">\n",
       "      <defs>\n",
       "       <path id=\"m27c10034a7\" d=\"M 0 0 \n",
       "L -3.5 0 \n",
       "\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 0.00 -->\n",
       "      <g transform=\"translate(20.878125 303.317344) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-2e\" d=\"M 684 794 \n",
       "L 1344 794 \n",
       "L 1344 0 \n",
       "L 684 0 \n",
       "L 684 794 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <path d=\"M 50.14375 264.868125 \n",
       "L 354.507386 264.868125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"264.868125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 0.25 -->\n",
       "      <g transform=\"translate(20.878125 268.667344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-32\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <path d=\"M 50.14375 230.218125 \n",
       "L 354.507386 230.218125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"230.218125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 0.50 -->\n",
       "      <g transform=\"translate(20.878125 234.017344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <path d=\"M 50.14375 195.568125 \n",
       "L 354.507386 195.568125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"195.568125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 0.75 -->\n",
       "      <g transform=\"translate(20.878125 199.367344) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-37\" d=\"M 525 4666 \n",
       "L 3525 4666 \n",
       "L 3525 4397 \n",
       "L 1831 0 \n",
       "L 1172 0 \n",
       "L 2766 4134 \n",
       "L 525 4134 \n",
       "L 525 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-37\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <path d=\"M 50.14375 160.918125 \n",
       "L 354.507386 160.918125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"160.918125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 1.00 -->\n",
       "      <g transform=\"translate(20.878125 164.717344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <path d=\"M 50.14375 126.268125 \n",
       "L 354.507386 126.268125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"126.268125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 1.25 -->\n",
       "      <g transform=\"translate(20.878125 130.067344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-32\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <path d=\"M 50.14375 91.618125 \n",
       "L 354.507386 91.618125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"91.618125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 1.50 -->\n",
       "      <g transform=\"translate(20.878125 95.417344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <path d=\"M 50.14375 56.968125 \n",
       "L 354.507386 56.968125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"56.968125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 1.75 -->\n",
       "      <g transform=\"translate(20.878125 60.767344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-37\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <path d=\"M 50.14375 22.318125 \n",
       "L 354.507386 22.318125 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"50.14375\" y=\"22.318125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 2.00 -->\n",
       "      <g transform=\"translate(20.878125 26.117344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Gradients/residuals norm -->\n",
       "     <g transform=\"translate(14.798438 224.039219) rotate(-90) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-47\" d=\"M 3809 666 \n",
       "L 3809 1919 \n",
       "L 2778 1919 \n",
       "L 2778 2438 \n",
       "L 4434 2438 \n",
       "L 4434 434 \n",
       "Q 4069 175 3628 42 \n",
       "Q 3188 -91 2688 -91 \n",
       "Q 1594 -91 976 548 \n",
       "Q 359 1188 359 2328 \n",
       "Q 359 3472 976 4111 \n",
       "Q 1594 4750 2688 4750 \n",
       "Q 3144 4750 3555 4637 \n",
       "Q 3966 4525 4313 4306 \n",
       "L 4313 3634 \n",
       "Q 3963 3931 3569 4081 \n",
       "Q 3175 4231 2741 4231 \n",
       "Q 1884 4231 1454 3753 \n",
       "Q 1025 3275 1025 2328 \n",
       "Q 1025 1384 1454 906 \n",
       "Q 1884 428 2741 428 \n",
       "Q 3075 428 3337 486 \n",
       "Q 3600 544 3809 666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-64\" d=\"M 2906 2969 \n",
       "L 2906 4863 \n",
       "L 3481 4863 \n",
       "L 3481 0 \n",
       "L 2906 0 \n",
       "L 2906 525 \n",
       "Q 2725 213 2448 61 \n",
       "Q 2172 -91 1784 -91 \n",
       "Q 1150 -91 751 415 \n",
       "Q 353 922 353 1747 \n",
       "Q 353 2572 751 3078 \n",
       "Q 1150 3584 1784 3584 \n",
       "Q 2172 3584 2448 3432 \n",
       "Q 2725 3281 2906 2969 \n",
       "z\n",
       "M 947 1747 \n",
       "Q 947 1113 1208 752 \n",
       "Q 1469 391 1925 391 \n",
       "Q 2381 391 2643 752 \n",
       "Q 2906 1113 2906 1747 \n",
       "Q 2906 2381 2643 2742 \n",
       "Q 2381 3103 1925 3103 \n",
       "Q 1469 3103 1208 2742 \n",
       "Q 947 2381 947 1747 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-73\" d=\"M 2834 3397 \n",
       "L 2834 2853 \n",
       "Q 2591 2978 2328 3040 \n",
       "Q 2066 3103 1784 3103 \n",
       "Q 1356 3103 1142 2972 \n",
       "Q 928 2841 928 2578 \n",
       "Q 928 2378 1081 2264 \n",
       "Q 1234 2150 1697 2047 \n",
       "L 1894 2003 \n",
       "Q 2506 1872 2764 1633 \n",
       "Q 3022 1394 3022 966 \n",
       "Q 3022 478 2636 193 \n",
       "Q 2250 -91 1575 -91 \n",
       "Q 1294 -91 989 -36 \n",
       "Q 684 19 347 128 \n",
       "L 347 722 \n",
       "Q 666 556 975 473 \n",
       "Q 1284 391 1588 391 \n",
       "Q 1994 391 2212 530 \n",
       "Q 2431 669 2431 922 \n",
       "Q 2431 1156 2273 1281 \n",
       "Q 2116 1406 1581 1522 \n",
       "L 1381 1569 \n",
       "Q 847 1681 609 1914 \n",
       "Q 372 2147 372 2553 \n",
       "Q 372 3047 722 3315 \n",
       "Q 1072 3584 1716 3584 \n",
       "Q 2034 3584 2315 3537 \n",
       "Q 2597 3491 2834 3397 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2f\" d=\"M 1625 4666 \n",
       "L 2156 4666 \n",
       "L 531 -594 \n",
       "L 0 -594 \n",
       "L 1625 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-75\" d=\"M 544 1381 \n",
       "L 544 3500 \n",
       "L 1119 3500 \n",
       "L 1119 1403 \n",
       "Q 1119 906 1312 657 \n",
       "Q 1506 409 1894 409 \n",
       "Q 2359 409 2629 706 \n",
       "Q 2900 1003 2900 1516 \n",
       "L 2900 3500 \n",
       "L 3475 3500 \n",
       "L 3475 0 \n",
       "L 2900 0 \n",
       "L 2900 538 \n",
       "Q 2691 219 2414 64 \n",
       "Q 2138 -91 1772 -91 \n",
       "Q 1169 -91 856 284 \n",
       "Q 544 659 544 1381 \n",
       "z\n",
       "M 1991 3584 \n",
       "L 1991 3584 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6c\" d=\"M 603 4863 \n",
       "L 1178 4863 \n",
       "L 1178 0 \n",
       "L 603 0 \n",
       "L 603 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6d\" d=\"M 3328 2828 \n",
       "Q 3544 3216 3844 3400 \n",
       "Q 4144 3584 4550 3584 \n",
       "Q 5097 3584 5394 3201 \n",
       "Q 5691 2819 5691 2113 \n",
       "L 5691 0 \n",
       "L 5113 0 \n",
       "L 5113 2094 \n",
       "Q 5113 2597 4934 2840 \n",
       "Q 4756 3084 4391 3084 \n",
       "Q 3944 3084 3684 2787 \n",
       "Q 3425 2491 3425 1978 \n",
       "L 3425 0 \n",
       "L 2847 0 \n",
       "L 2847 2094 \n",
       "Q 2847 2600 2669 2842 \n",
       "Q 2491 3084 2119 3084 \n",
       "Q 1678 3084 1418 2786 \n",
       "Q 1159 2488 1159 1978 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1356 3278 1631 3431 \n",
       "Q 1906 3584 2284 3584 \n",
       "Q 2666 3584 2933 3390 \n",
       "Q 3200 3197 3328 2828 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-47\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"77.490234\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"118.603516\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"179.882812\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"243.359375\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"271.142578\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"332.666016\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"396.044922\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"435.253906\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2f\" x=\"487.353516\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"521.044922\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"559.908203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"621.431641\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"673.53125\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"701.314453\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-75\" x=\"764.791016\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"828.169922\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6c\" x=\"889.449219\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"917.232422\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-20\" x=\"969.332031\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"1001.119141\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6f\" x=\"1064.498047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"1125.679688\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6d\" x=\"1165.042969\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_31\">\n",
       "    <path d=\"M 50.14375 53.055654 \n",
       "L 53.62883 70.901706 \n",
       "L 57.11391 87.650546 \n",
       "L 60.598989 103.360655 \n",
       "L 64.084069 118.087027 \n",
       "L 67.569149 131.881419 \n",
       "L 71.054229 144.792571 \n",
       "L 74.539309 156.866414 \n",
       "L 78.024388 168.146256 \n",
       "L 81.509468 178.672967 \n",
       "L 84.994548 188.485156 \n",
       "L 88.479628 197.619362 \n",
       "L 91.964708 206.110248 \n",
       "L 95.449787 213.990806 \n",
       "L 98.934867 221.292576 \n",
       "L 102.419947 228.045855 \n",
       "L 105.905027 234.27991 \n",
       "L 109.390107 240.023162 \n",
       "L 112.875187 245.303352 \n",
       "L 116.360266 250.147652 \n",
       "L 119.845346 254.58275 \n",
       "L 123.330426 258.634869 \n",
       "L 126.815506 262.329751 \n",
       "L 130.300586 265.692598 \n",
       "L 133.785665 268.747984 \n",
       "L 137.270745 271.519739 \n",
       "L 140.755825 274.030839 \n",
       "L 144.821751 276.660301 \n",
       "L 148.887678 278.997935 \n",
       "L 152.953604 281.074609 \n",
       "L 157.019531 282.918877 \n",
       "L 161.666304 284.775489 \n",
       "L 166.313077 286.397885 \n",
       "L 171.540697 287.98189 \n",
       "L 177.349163 289.487501 \n",
       "L 183.157629 290.768804 \n",
       "L 189.546942 291.963876 \n",
       "L 197.097948 293.140431 \n",
       "L 205.229801 294.17934 \n",
       "L 214.523348 295.140222 \n",
       "L 224.978587 295.999169 \n",
       "L 237.176366 296.777579 \n",
       "L 251.697532 297.473598 \n",
       "L 269.122931 298.073675 \n",
       "L 290.03341 298.562995 \n",
       "L 316.752355 298.953779 \n",
       "L 352.764846 299.240161 \n",
       "L 354.507386 299.249528 \n",
       "L 354.507386 299.249528 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke: #00bfbf; stroke-width: 3; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_32\">\n",
       "    <path d=\"M 51.190543 -1 \n",
       "L 54.790523 17.94154 \n",
       "L 58.85645 38.078338 \n",
       "L 62.922376 56.974037 \n",
       "L 66.988302 74.713613 \n",
       "L 71.054229 91.375264 \n",
       "L 75.120155 107.031106 \n",
       "L 79.186082 121.747618 \n",
       "L 83.252008 135.585807 \n",
       "L 87.317935 148.601082 \n",
       "L 91.383861 160.842961 \n",
       "L 95.449787 172.354714 \n",
       "L 99.515714 183.17315 \n",
       "L 103.58164 193.328684 \n",
       "L 107.647567 202.845803 \n",
       "L 111.713493 211.743984 \n",
       "L 115.77942 220.038996 \n",
       "L 119.264499 226.679272 \n",
       "L 122.749579 232.894604 \n",
       "L 126.234659 238.693596 \n",
       "L 129.719739 244.085857 \n",
       "L 133.204819 249.082424 \n",
       "L 136.689899 253.696024 \n",
       "L 140.174978 257.941153 \n",
       "L 143.660058 261.833994 \n",
       "L 147.145138 265.392222 \n",
       "L 150.630218 268.634701 \n",
       "L 154.115298 271.581144 \n",
       "L 157.600377 274.251746 \n",
       "L 161.085457 276.66683 \n",
       "L 165.151384 279.188303 \n",
       "L 169.21731 281.420452 \n",
       "L 173.283236 283.39299 \n",
       "L 177.349163 285.133883 \n",
       "L 181.995936 286.873053 \n",
       "L 186.642709 288.378886 \n",
       "L 191.870329 289.833309 \n",
       "L 197.678795 291.19779 \n",
       "L 204.068108 292.445969 \n",
       "L 211.038268 293.563418 \n",
       "L 218.589274 294.546076 \n",
       "L 227.301973 295.451833 \n",
       "L 237.176366 296.255252 \n",
       "L 248.793299 296.97813 \n",
       "L 262.733618 297.620433 \n",
       "L 280.159017 298.187795 \n",
       "L 301.650343 298.652662 \n",
       "L 329.530981 299.019382 \n",
       "L 354.507386 299.212901 \n",
       "L 354.507386 299.212901 \n",
       "\" clip-path=\"url(#pb08c8a6baf)\" style=\"fill: none; stroke: #bf00bf; stroke-width: 2; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 50.14375 299.518125 \n",
       "L 50.14375 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 354.507386 299.518125 \n",
       "L 354.507386 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 50.14375 299.518125 \n",
       "L 354.507386 299.518125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 50.14375 22.318125 \n",
       "L 354.507386 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_18\">\n",
       "    <!-- lr = 0.01 -->\n",
       "    <g transform=\"translate(175.991193 16.318125) scale(0.12 -0.12)\">\n",
       "     <defs>\n",
       "      <path id=\"DejaVuSans-3d\" d=\"M 678 2906 \n",
       "L 4684 2906 \n",
       "L 4684 2381 \n",
       "L 678 2381 \n",
       "L 678 2906 \n",
       "z\n",
       "M 678 1631 \n",
       "L 4684 1631 \n",
       "L 4684 1100 \n",
       "L 678 1100 \n",
       "L 678 1631 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#DejaVuSans-6c\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-72\" x=\"27.783203\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-20\" x=\"68.896484\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-3d\" x=\"100.683594\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-20\" x=\"184.472656\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-30\" x=\"216.259766\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-2e\" x=\"279.882812\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-30\" x=\"311.669922\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-31\" x=\"375.292969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"patch_7\">\n",
       "     <path d=\"M 266.773011 59.674375 \n",
       "L 347.507386 59.674375 \n",
       "Q 349.507386 59.674375 349.507386 57.674375 \n",
       "L 349.507386 29.318125 \n",
       "Q 349.507386 27.318125 347.507386 27.318125 \n",
       "L 266.773011 27.318125 \n",
       "Q 264.773011 27.318125 264.773011 29.318125 \n",
       "L 264.773011 57.674375 \n",
       "Q 264.773011 59.674375 266.773011 59.674375 \n",
       "z\n",
       "\" style=\"fill: #ffffff; opacity: 0.8; stroke: #cccccc; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"line2d_33\">\n",
       "     <path d=\"M 268.773011 35.416562 \n",
       "L 278.773011 35.416562 \n",
       "L 288.773011 35.416562 \n",
       "\" style=\"fill: none; stroke: #00bfbf; stroke-width: 3; stroke-linecap: square\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- Residuals -->\n",
       "     <g transform=\"translate(296.773011 38.916562) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-52\" d=\"M 2841 2188 \n",
       "Q 3044 2119 3236 1894 \n",
       "Q 3428 1669 3622 1275 \n",
       "L 4263 0 \n",
       "L 3584 0 \n",
       "L 2988 1197 \n",
       "Q 2756 1666 2539 1819 \n",
       "Q 2322 1972 1947 1972 \n",
       "L 1259 1972 \n",
       "L 1259 0 \n",
       "L 628 0 \n",
       "L 628 4666 \n",
       "L 2053 4666 \n",
       "Q 2853 4666 3247 4331 \n",
       "Q 3641 3997 3641 3322 \n",
       "Q 3641 2881 3436 2590 \n",
       "Q 3231 2300 2841 2188 \n",
       "z\n",
       "M 1259 4147 \n",
       "L 1259 2491 \n",
       "L 2053 2491 \n",
       "Q 2509 2491 2742 2702 \n",
       "Q 2975 2913 2975 3322 \n",
       "Q 2975 3731 2742 3939 \n",
       "Q 2509 4147 2053 4147 \n",
       "L 1259 4147 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-52\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"64.982422\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"126.505859\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"178.605469\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"206.388672\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-75\" x=\"269.865234\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"333.244141\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6c\" x=\"394.523438\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"422.306641\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_34\">\n",
       "     <path d=\"M 268.773011 50.094688 \n",
       "L 278.773011 50.094688 \n",
       "L 288.773011 50.094688 \n",
       "\" style=\"fill: none; stroke: #bf00bf; stroke-width: 2; stroke-linecap: square\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- Gradients -->\n",
       "     <g transform=\"translate(296.773011 53.594688) scale(0.1 -0.1)\">\n",
       "      <use xlink:href=\"#DejaVuSans-47\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"77.490234\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"118.603516\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"179.882812\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"243.359375\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"271.142578\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"332.666016\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"396.044922\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"435.253906\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 415.380114 299.518125 \n",
       "L 719.74375 299.518125 \n",
       "L 719.74375 22.318125 \n",
       "L 415.380114 22.318125 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"C0_0_4dbeaaca78\" d=\"M 0 1.414214 \n",
       "C 0.375054 1.414214 0.734797 1.265203 1 1 \n",
       "C 1.265203 0.734797 1.414214 0.375054 1.414214 -0 \n",
       "C 1.414214 -0.375054 1.265203 -0.734797 1 -1 \n",
       "C 0.734797 -1.265203 0.375054 -1.414214 0 -1.414214 \n",
       "C -0.375054 -1.414214 -0.734797 -1.265203 -1 -1 \n",
       "C -1.265203 -0.734797 -1.414214 -0.375054 -1.414214 0 \n",
       "C -1.414214 0.375054 -1.265203 0.734797 -1 1 \n",
       "C -0.734797 1.265203 -0.375054 1.414214 0 1.414214 \n",
       "z\n",
       "\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"708.403503\" y=\"35.518125\" style=\"fill: #ff0000; stroke: #ff0000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"706.879236\" y=\"37.582576\" style=\"fill: #ff0300; stroke: #ff0300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"705.370177\" y=\"39.625355\" style=\"fill: #ff0600; stroke: #ff0600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"703.876174\" y=\"41.646658\" style=\"fill: #ff0900; stroke: #ff0900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"702.397078\" y=\"43.646677\" style=\"fill: #ff0c00; stroke: #ff0c00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"700.932743\" y=\"45.625606\" style=\"fill: #ff0f00; stroke: #ff0f00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"699.483021\" y=\"47.583632\" style=\"fill: #ff1100; stroke: #ff1100\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"698.047769\" y=\"49.520943\" style=\"fill: #ff1400; stroke: #ff1400\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"696.626843\" y=\"51.437725\" style=\"fill: #ff1700; stroke: #ff1700\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"695.220102\" y=\"53.334161\" style=\"fill: #ff1a00; stroke: #ff1a00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"693.827406\" y=\"55.210433\" style=\"fill: #ff1d00; stroke: #ff1d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"692.448618\" y=\"57.066721\" style=\"fill: #ff2000; stroke: #ff2000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"691.0836\" y=\"58.903203\" style=\"fill: #ff2300; stroke: #ff2300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"689.732217\" y=\"60.720055\" style=\"fill: #ff2600; stroke: #ff2600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"688.394335\" y=\"62.517451\" style=\"fill: #ff2900; stroke: #ff2900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"687.069823\" y=\"64.295564\" style=\"fill: #ff2c00; stroke: #ff2c00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"685.758548\" y=\"66.054565\" style=\"fill: #ff2f00; stroke: #ff2f00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"684.460382\" y=\"67.794624\" style=\"fill: #ff3200; stroke: #ff3200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"683.175197\" y=\"69.515907\" style=\"fill: #ff3400; stroke: #ff3400\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"681.902865\" y=\"71.218582\" style=\"fill: #ff3700; stroke: #ff3700\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"680.643263\" y=\"72.902811\" style=\"fill: #ff3a00; stroke: #ff3a00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"679.396266\" y=\"74.568758\" style=\"fill: #ff3d00; stroke: #ff3d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"678.161752\" y=\"76.216584\" style=\"fill: #ff4000; stroke: #ff4000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"676.939599\" y=\"77.846448\" style=\"fill: #ff4300; stroke: #ff4300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"675.729689\" y=\"79.458508\" style=\"fill: #ff4600; stroke: #ff4600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"674.531902\" y=\"81.05292\" style=\"fill: #ff4900; stroke: #ff4900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"673.346123\" y=\"82.62984\" style=\"fill: #ff4c00; stroke: #ff4c00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"672.172235\" y=\"84.18942\" style=\"fill: #ff4f00; stroke: #ff4f00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"671.010124\" y=\"85.731813\" style=\"fill: #ff5200; stroke: #ff5200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"669.859676\" y=\"87.257169\" style=\"fill: #ff5500; stroke: #ff5500\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"668.720781\" y=\"88.765636\" style=\"fill: #ff5700; stroke: #ff5700\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"667.593328\" y=\"90.257363\" style=\"fill: #ff5a00; stroke: #ff5a00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"666.477207\" y=\"91.732496\" style=\"fill: #ff5d00; stroke: #ff5d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"665.37231\" y=\"93.191179\" style=\"fill: #ff6000; stroke: #ff6000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"664.278532\" y=\"94.633555\" style=\"fill: #ff6300; stroke: #ff6300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"663.195766\" y=\"96.059767\" style=\"fill: #ff6600; stroke: #ff6600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"662.123907\" y=\"97.469954\" style=\"fill: #ff6900; stroke: #ff6900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"661.062854\" y=\"98.864258\" style=\"fill: #ff6c00; stroke: #ff6c00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"660.012504\" y=\"100.242814\" style=\"fill: #ff6f00; stroke: #ff6f00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"658.972756\" y=\"101.605761\" style=\"fill: #ff7200; stroke: #ff7200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"657.943511\" y=\"102.953233\" style=\"fill: #ff7500; stroke: #ff7500\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"656.924671\" y=\"104.285365\" style=\"fill: #ff7700; stroke: #ff7700\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"655.916138\" y=\"105.60229\" style=\"fill: #ff7a00; stroke: #ff7a00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"654.917815\" y=\"106.904138\" style=\"fill: #ff7d00; stroke: #ff7d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"653.929609\" y=\"108.191041\" style=\"fill: #ff8000; stroke: #ff8000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"652.951425\" y=\"109.463128\" style=\"fill: #ff8300; stroke: #ff8300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"651.983169\" y=\"110.720526\" style=\"fill: #ff8600; stroke: #ff8600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"651.024752\" y=\"111.963363\" style=\"fill: #ff8900; stroke: #ff8900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"650.076081\" y=\"113.191764\" style=\"fill: #ff8c00; stroke: #ff8c00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"649.137066\" y=\"114.405853\" style=\"fill: #ff8f00; stroke: #ff8f00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"648.207621\" y=\"115.605754\" style=\"fill: #ff9200; stroke: #ff9200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"647.287656\" y=\"116.79159\" style=\"fill: #ff9500; stroke: #ff9500\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"646.377085\" y=\"117.963481\" style=\"fill: #ff9800; stroke: #ff9800\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"645.475823\" y=\"119.121547\" style=\"fill: #ff9a00; stroke: #ff9a00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"644.583784\" y=\"120.265908\" style=\"fill: #ff9d00; stroke: #ff9d00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"643.700886\" y=\"121.39668\" style=\"fill: #ffa000; stroke: #ffa000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"642.827045\" y=\"122.513982\" style=\"fill: #ffa300; stroke: #ffa300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"641.96218\" y=\"123.617929\" style=\"fill: #ffa600; stroke: #ffa600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"641.10621\" y=\"124.708635\" style=\"fill: #ffa900; stroke: #ffa900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"640.259054\" y=\"125.786214\" style=\"fill: #ffac00; stroke: #ffac00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"639.420634\" y=\"126.85078\" style=\"fill: #ffaf00; stroke: #ffaf00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"638.590872\" y=\"127.902443\" style=\"fill: #ffb200; stroke: #ffb200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"637.76969\" y=\"128.941316\" style=\"fill: #ffb500; stroke: #ffb500\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"636.957011\" y=\"129.967507\" style=\"fill: #ffb800; stroke: #ffb800\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"636.152761\" y=\"130.981126\" style=\"fill: #ffbb00; stroke: #ffbb00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"635.356864\" y=\"131.98228\" style=\"fill: #ffbd00; stroke: #ffbd00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"634.569246\" y=\"132.971078\" style=\"fill: #ffc000; stroke: #ffc000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"633.789834\" y=\"133.947626\" style=\"fill: #ffc300; stroke: #ffc300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"633.018556\" y=\"134.912028\" style=\"fill: #ffc600; stroke: #ffc600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"632.25534\" y=\"135.86439\" style=\"fill: #ffc900; stroke: #ffc900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"631.500114\" y=\"136.804815\" style=\"fill: #ffcc00; stroke: #ffcc00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"630.75281\" y=\"137.733407\" style=\"fill: #ffcf00; stroke: #ffcf00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"630.013356\" y=\"138.650268\" style=\"fill: #ffd200; stroke: #ffd200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"629.281686\" y=\"139.555499\" style=\"fill: #ffd500; stroke: #ffd500\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"628.557729\" y=\"140.449201\" style=\"fill: #ffd800; stroke: #ffd800\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"627.84142\" y=\"141.331474\" style=\"fill: #ffdb00; stroke: #ffdb00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"627.132691\" y=\"142.202417\" style=\"fill: #ffdd00; stroke: #ffdd00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"626.431476\" y=\"143.062129\" style=\"fill: #ffe000; stroke: #ffe000\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"625.73771\" y=\"143.910708\" style=\"fill: #ffe300; stroke: #ffe300\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"625.051328\" y=\"144.748251\" style=\"fill: #ffe600; stroke: #ffe600\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"624.372265\" y=\"145.574855\" style=\"fill: #ffe900; stroke: #ffe900\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"623.700459\" y=\"146.390616\" style=\"fill: #ffec00; stroke: #ffec00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"623.035845\" y=\"147.195629\" style=\"fill: #ffef00; stroke: #ffef00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"622.378363\" y=\"147.98999\" style=\"fill: #fff200; stroke: #fff200\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"621.727948\" y=\"148.773791\" style=\"fill: #fff500; stroke: #fff500\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"621.084541\" y=\"149.547128\" style=\"fill: #fff800; stroke: #fff800\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"620.44808\" y=\"150.310093\" style=\"fill: #fffb00; stroke: #fffb00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"619.818505\" y=\"151.062779\" style=\"fill: #fffe00; stroke: #fffe00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"619.195756\" y=\"151.805278\" style=\"fill: #feff00; stroke: #feff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"618.579773\" y=\"152.537682\" style=\"fill: #fbff00; stroke: #fbff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"617.970499\" y=\"153.260082\" style=\"fill: #f8ff00; stroke: #f8ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"617.367873\" y=\"153.97257\" style=\"fill: #f5ff00; stroke: #f5ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"616.771839\" y=\"154.675234\" style=\"fill: #f2ff00; stroke: #f2ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"616.182338\" y=\"155.368165\" style=\"fill: #efff00; stroke: #efff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"615.599314\" y=\"156.051454\" style=\"fill: #ecff00; stroke: #ecff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"615.02271\" y=\"156.725188\" style=\"fill: #e9ff00; stroke: #e9ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"614.45247\" y=\"157.389457\" style=\"fill: #e6ff00; stroke: #e6ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"613.888537\" y=\"158.044349\" style=\"fill: #e3ff00; stroke: #e3ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"613.330856\" y=\"158.689952\" style=\"fill: #e0ff00; stroke: #e0ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"612.779372\" y=\"159.326354\" style=\"fill: #ddff00; stroke: #ddff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"612.234031\" y=\"159.953643\" style=\"fill: #dbff00; stroke: #dbff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"611.694777\" y=\"160.571904\" style=\"fill: #d8ff00; stroke: #d8ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"611.161556\" y=\"161.181226\" style=\"fill: #d5ff00; stroke: #d5ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"610.634316\" y=\"161.781695\" style=\"fill: #d2ff00; stroke: #d2ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"610.113002\" y=\"162.373397\" style=\"fill: #cfff00; stroke: #cfff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"609.597561\" y=\"162.956418\" style=\"fill: #ccff00; stroke: #ccff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"609.087941\" y=\"163.530843\" style=\"fill: #c9ff00; stroke: #c9ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"608.584089\" y=\"164.096758\" style=\"fill: #c6ff00; stroke: #c6ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"608.085953\" y=\"164.654249\" style=\"fill: #c3ff00; stroke: #c3ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"607.593481\" y=\"165.203399\" style=\"fill: #c0ff00; stroke: #c0ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"607.106622\" y=\"165.744295\" style=\"fill: #bdff00; stroke: #bdff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"606.625323\" y=\"166.27702\" style=\"fill: #bbff00; stroke: #bbff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"606.149535\" y=\"166.801658\" style=\"fill: #b8ff00; stroke: #b8ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"605.679206\" y=\"167.318294\" style=\"fill: #b5ff00; stroke: #b5ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"605.214286\" y=\"167.827011\" style=\"fill: #b2ff00; stroke: #b2ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"604.754725\" y=\"168.327892\" style=\"fill: #afff00; stroke: #afff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"604.300472\" y=\"168.821022\" style=\"fill: #acff00; stroke: #acff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"603.851478\" y=\"169.306483\" style=\"fill: #a9ff00; stroke: #a9ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"603.407694\" y=\"169.784358\" style=\"fill: #a6ff00; stroke: #a6ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"602.96907\" y=\"170.25473\" style=\"fill: #a3ff00; stroke: #a3ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"602.535557\" y=\"170.717681\" style=\"fill: #a0ff00; stroke: #a0ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"602.107106\" y=\"171.173294\" style=\"fill: #9dff00; stroke: #9dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"601.68367\" y=\"171.621649\" style=\"fill: #9aff00; stroke: #9aff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"601.2652\" y=\"172.06283\" style=\"fill: #98ff00; stroke: #98ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"600.851647\" y=\"172.496917\" style=\"fill: #95ff00; stroke: #95ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"600.442965\" y=\"172.923992\" style=\"fill: #92ff00; stroke: #92ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"600.039105\" y=\"173.344136\" style=\"fill: #8fff00; stroke: #8fff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"599.64002\" y=\"173.757429\" style=\"fill: #8cff00; stroke: #8cff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"599.245664\" y=\"174.163952\" style=\"fill: #89ff00; stroke: #89ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"598.855989\" y=\"174.563785\" style=\"fill: #86ff00; stroke: #86ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"598.470948\" y=\"174.957009\" style=\"fill: #83ff00; stroke: #83ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"598.090496\" y=\"175.343702\" style=\"fill: #80ff00; stroke: #80ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"597.714587\" y=\"175.723944\" style=\"fill: #7dff00; stroke: #7dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"597.343173\" y=\"176.097815\" style=\"fill: #7aff00; stroke: #7aff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"596.976211\" y=\"176.465392\" style=\"fill: #77ff00; stroke: #77ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"596.613653\" y=\"176.826755\" style=\"fill: #75ff00; stroke: #75ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"596.255456\" y=\"177.181982\" style=\"fill: #72ff00; stroke: #72ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"595.901575\" y=\"177.53115\" style=\"fill: #6fff00; stroke: #6fff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"595.551963\" y=\"177.874336\" style=\"fill: #6cff00; stroke: #6cff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"595.206578\" y=\"178.211619\" style=\"fill: #69ff00; stroke: #69ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"594.865375\" y=\"178.543074\" style=\"fill: #66ff00; stroke: #66ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"594.52831\" y=\"178.868778\" style=\"fill: #63ff00; stroke: #63ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"594.195339\" y=\"179.188807\" style=\"fill: #60ff00; stroke: #60ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"593.866419\" y=\"179.503237\" style=\"fill: #5dff00; stroke: #5dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"593.541506\" y=\"179.812142\" style=\"fill: #5aff00; stroke: #5aff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"593.220559\" y=\"180.115597\" style=\"fill: #57ff00; stroke: #57ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"592.903533\" y=\"180.413678\" style=\"fill: #55ff00; stroke: #55ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"592.590387\" y=\"180.706457\" style=\"fill: #52ff00; stroke: #52ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"592.281079\" y=\"180.994008\" style=\"fill: #4fff00; stroke: #4fff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"591.975566\" y=\"181.276405\" style=\"fill: #4cff00; stroke: #4cff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"591.673807\" y=\"181.553719\" style=\"fill: #49ff00; stroke: #49ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"591.375761\" y=\"181.826022\" style=\"fill: #46ff00; stroke: #46ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"591.081386\" y=\"182.093388\" style=\"fill: #43ff00; stroke: #43ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"590.790643\" y=\"182.355885\" style=\"fill: #40ff00; stroke: #40ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"590.503489\" y=\"182.613585\" style=\"fill: #3dff00; stroke: #3dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"590.219886\" y=\"182.866558\" style=\"fill: #3aff00; stroke: #3aff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"589.939793\" y=\"183.114874\" style=\"fill: #37ff00; stroke: #37ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"589.66317\" y=\"183.358601\" style=\"fill: #34ff00; stroke: #34ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"589.389978\" y=\"183.597809\" style=\"fill: #32ff00; stroke: #32ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"589.120178\" y=\"183.832563\" style=\"fill: #2fff00; stroke: #2fff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"588.853732\" y=\"184.062934\" style=\"fill: #2cff00; stroke: #2cff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"588.5906\" y=\"184.288985\" style=\"fill: #29ff00; stroke: #29ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"588.330745\" y=\"184.510786\" style=\"fill: #26ff00; stroke: #26ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"588.074128\" y=\"184.728399\" style=\"fill: #23ff00; stroke: #23ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"587.820712\" y=\"184.941892\" style=\"fill: #20ff00; stroke: #20ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"587.57046\" y=\"185.151328\" style=\"fill: #1dff00; stroke: #1dff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"587.323334\" y=\"185.35677\" style=\"fill: #1aff00; stroke: #1aff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"587.079299\" y=\"185.558283\" style=\"fill: #17ff00; stroke: #17ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"586.838317\" y=\"185.755929\" style=\"fill: #14ff00; stroke: #14ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"586.600352\" y=\"185.949769\" style=\"fill: #11ff00; stroke: #11ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"586.365369\" y=\"186.139866\" style=\"fill: #0fff00; stroke: #0fff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"586.133333\" y=\"186.326279\" style=\"fill: #0cff00; stroke: #0cff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"585.904207\" y=\"186.509069\" style=\"fill: #09ff00; stroke: #09ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"585.677958\" y=\"186.688296\" style=\"fill: #06ff00; stroke: #06ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"585.45455\" y=\"186.864018\" style=\"fill: #03ff00; stroke: #03ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"585.23395\" y=\"187.036293\" style=\"fill: #00ff00; stroke: #00ff00\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"585.016123\" y=\"187.205179\" style=\"fill: #00ff03; stroke: #00ff03\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"584.801037\" y=\"187.370733\" style=\"fill: #00ff06; stroke: #00ff06\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"584.588657\" y=\"187.53301\" style=\"fill: #00ff09; stroke: #00ff09\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"584.37895\" y=\"187.692067\" style=\"fill: #00ff0c; stroke: #00ff0c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"584.171885\" y=\"187.847959\" style=\"fill: #00ff0f; stroke: #00ff0f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"583.967429\" y=\"188.000739\" style=\"fill: #00ff11; stroke: #00ff11\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"583.765549\" y=\"188.150461\" style=\"fill: #00ff14; stroke: #00ff14\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"583.566215\" y=\"188.297178\" style=\"fill: #00ff17; stroke: #00ff17\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"583.369394\" y=\"188.440942\" style=\"fill: #00ff1a; stroke: #00ff1a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"583.175056\" y=\"188.581805\" style=\"fill: #00ff1d; stroke: #00ff1d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"582.98317\" y=\"188.719819\" style=\"fill: #00ff20; stroke: #00ff20\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"582.793705\" y=\"188.855032\" style=\"fill: #00ff23; stroke: #00ff23\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"582.606632\" y=\"188.987495\" style=\"fill: #00ff26; stroke: #00ff26\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"582.42192\" y=\"189.117256\" style=\"fill: #00ff29; stroke: #00ff29\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"582.23954\" y=\"189.244364\" style=\"fill: #00ff2c; stroke: #00ff2c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"582.059463\" y=\"189.368867\" style=\"fill: #00ff2f; stroke: #00ff2f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"581.88166\" y=\"189.490812\" style=\"fill: #00ff32; stroke: #00ff32\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"581.706103\" y=\"189.610244\" style=\"fill: #00ff34; stroke: #00ff34\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"581.532763\" y=\"189.72721\" style=\"fill: #00ff37; stroke: #00ff37\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"581.361612\" y=\"189.841754\" style=\"fill: #00ff3a; stroke: #00ff3a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"581.192623\" y=\"189.953922\" style=\"fill: #00ff3d; stroke: #00ff3d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"581.025768\" y=\"190.063756\" style=\"fill: #00ff40; stroke: #00ff40\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"580.86102\" y=\"190.171299\" style=\"fill: #00ff43; stroke: #00ff43\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"580.698354\" y=\"190.276596\" style=\"fill: #00ff46; stroke: #00ff46\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"580.537741\" y=\"190.379686\" style=\"fill: #00ff49; stroke: #00ff49\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"580.379156\" y=\"190.480612\" style=\"fill: #00ff4c; stroke: #00ff4c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"580.222574\" y=\"190.579413\" style=\"fill: #00ff4f; stroke: #00ff4f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"580.067969\" y=\"190.676131\" style=\"fill: #00ff52; stroke: #00ff52\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"579.915315\" y=\"190.770804\" style=\"fill: #00ff55; stroke: #00ff55\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"579.764588\" y=\"190.863471\" style=\"fill: #00ff57; stroke: #00ff57\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"579.615762\" y=\"190.95417\" style=\"fill: #00ff5a; stroke: #00ff5a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"579.468815\" y=\"191.042939\" style=\"fill: #00ff5d; stroke: #00ff5d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"579.323721\" y=\"191.129814\" style=\"fill: #00ff60; stroke: #00ff60\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"579.180457\" y=\"191.214833\" style=\"fill: #00ff63; stroke: #00ff63\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"579.038999\" y=\"191.298031\" style=\"fill: #00ff66; stroke: #00ff66\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"578.899324\" y=\"191.379443\" style=\"fill: #00ff69; stroke: #00ff69\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"578.76141\" y=\"191.459103\" style=\"fill: #00ff6c; stroke: #00ff6c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"578.625233\" y=\"191.537047\" style=\"fill: #00ff6f; stroke: #00ff6f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"578.490771\" y=\"191.613306\" style=\"fill: #00ff72; stroke: #00ff72\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"578.358002\" y=\"191.687915\" style=\"fill: #00ff75; stroke: #00ff75\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"578.226905\" y=\"191.760906\" style=\"fill: #00ff77; stroke: #00ff77\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"578.097457\" y=\"191.832311\" style=\"fill: #00ff7a; stroke: #00ff7a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.969638\" y=\"191.90216\" style=\"fill: #00ff7d; stroke: #00ff7d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.843426\" y=\"191.970485\" style=\"fill: #00ff80; stroke: #00ff80\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.718801\" y=\"192.037315\" style=\"fill: #00ff83; stroke: #00ff83\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.595742\" y=\"192.102682\" style=\"fill: #00ff86; stroke: #00ff86\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.474228\" y=\"192.166613\" style=\"fill: #00ff89; stroke: #00ff89\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.35424\" y=\"192.229138\" style=\"fill: #00ff8c; stroke: #00ff8c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.235759\" y=\"192.290285\" style=\"fill: #00ff8f; stroke: #00ff8f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.118764\" y=\"192.350081\" style=\"fill: #00ff92; stroke: #00ff92\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"577.003236\" y=\"192.408554\" style=\"fill: #00ff95; stroke: #00ff95\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.889157\" y=\"192.465731\" style=\"fill: #00ff98; stroke: #00ff98\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.776507\" y=\"192.521637\" style=\"fill: #00ff9a; stroke: #00ff9a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.665269\" y=\"192.5763\" style=\"fill: #00ff9d; stroke: #00ff9d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.555423\" y=\"192.629743\" style=\"fill: #00ffa0; stroke: #00ffa0\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.446951\" y=\"192.681992\" style=\"fill: #00ffa3; stroke: #00ffa3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.339837\" y=\"192.733071\" style=\"fill: #00ffa6; stroke: #00ffa6\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.234062\" y=\"192.783004\" style=\"fill: #00ffa9; stroke: #00ffa9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.129608\" y=\"192.831816\" style=\"fill: #00ffac; stroke: #00ffac\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"576.02646\" y=\"192.879528\" style=\"fill: #00ffaf; stroke: #00ffaf\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.924599\" y=\"192.926164\" style=\"fill: #00ffb2; stroke: #00ffb2\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.82401\" y=\"192.971746\" style=\"fill: #00ffb5; stroke: #00ffb5\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.724675\" y=\"193.016295\" style=\"fill: #00ffb8; stroke: #00ffb8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.626578\" y=\"193.059834\" style=\"fill: #00ffbb; stroke: #00ffbb\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.529704\" y=\"193.102383\" style=\"fill: #00ffbd; stroke: #00ffbd\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.434036\" y=\"193.143963\" style=\"fill: #00ffc0; stroke: #00ffc0\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.33956\" y=\"193.184594\" style=\"fill: #00ffc3; stroke: #00ffc3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.246258\" y=\"193.224296\" style=\"fill: #00ffc6; stroke: #00ffc6\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.154117\" y=\"193.263089\" style=\"fill: #00ffc9; stroke: #00ffc9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"575.063121\" y=\"193.300991\" style=\"fill: #00ffcc; stroke: #00ffcc\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.973256\" y=\"193.338022\" style=\"fill: #00ffcf; stroke: #00ffcf\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.884506\" y=\"193.374199\" style=\"fill: #00ffd2; stroke: #00ffd2\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.796857\" y=\"193.409542\" style=\"fill: #00ffd5; stroke: #00ffd5\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.710295\" y=\"193.444067\" style=\"fill: #00ffd8; stroke: #00ffd8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.624807\" y=\"193.477792\" style=\"fill: #00ffdb; stroke: #00ffdb\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.540377\" y=\"193.510734\" style=\"fill: #00ffdd; stroke: #00ffdd\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.456993\" y=\"193.542909\" style=\"fill: #00ffe0; stroke: #00ffe0\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.374641\" y=\"193.574335\" style=\"fill: #00ffe3; stroke: #00ffe3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.293307\" y=\"193.605026\" style=\"fill: #00ffe6; stroke: #00ffe6\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.212979\" y=\"193.635\" style=\"fill: #00ffe9; stroke: #00ffe9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.133643\" y=\"193.66427\" style=\"fill: #00ffec; stroke: #00ffec\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"574.055286\" y=\"193.692853\" style=\"fill: #00ffef; stroke: #00ffef\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.977897\" y=\"193.720763\" style=\"fill: #00fff2; stroke: #00fff2\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.901462\" y=\"193.748014\" style=\"fill: #00fff5; stroke: #00fff5\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.825969\" y=\"193.774622\" style=\"fill: #00fff8; stroke: #00fff8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.751407\" y=\"193.800599\" style=\"fill: #00fffb; stroke: #00fffb\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.677762\" y=\"193.82596\" style=\"fill: #00fffe; stroke: #00fffe\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.605024\" y=\"193.850717\" style=\"fill: #00feff; stroke: #00feff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.533181\" y=\"193.874885\" style=\"fill: #00fbff; stroke: #00fbff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.46222\" y=\"193.898475\" style=\"fill: #00f8ff; stroke: #00f8ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.392132\" y=\"193.921501\" style=\"fill: #00f5ff; stroke: #00f5ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.322904\" y=\"193.943975\" style=\"fill: #00f2ff; stroke: #00f2ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.254525\" y=\"193.965908\" style=\"fill: #00efff; stroke: #00efff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.186985\" y=\"193.987313\" style=\"fill: #00ecff; stroke: #00ecff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.120273\" y=\"194.008202\" style=\"fill: #00e9ff; stroke: #00e9ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"573.054379\" y=\"194.028585\" style=\"fill: #00e6ff; stroke: #00e6ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.989291\" y=\"194.048474\" style=\"fill: #00e3ff; stroke: #00e3ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.925\" y=\"194.06788\" style=\"fill: #00e0ff; stroke: #00e0ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.861494\" y=\"194.086813\" style=\"fill: #00ddff; stroke: #00ddff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.798766\" y=\"194.105284\" style=\"fill: #00dbff; stroke: #00dbff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.736803\" y=\"194.123304\" style=\"fill: #00d8ff; stroke: #00d8ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.675597\" y=\"194.140881\" style=\"fill: #00d5ff; stroke: #00d5ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.615138\" y=\"194.158027\" style=\"fill: #00d2ff; stroke: #00d2ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.555416\" y=\"194.17475\" style=\"fill: #00cfff; stroke: #00cfff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.496423\" y=\"194.19106\" style=\"fill: #00ccff; stroke: #00ccff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.438148\" y=\"194.206966\" style=\"fill: #00c9ff; stroke: #00c9ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.380582\" y=\"194.222478\" style=\"fill: #00c6ff; stroke: #00c6ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.323717\" y=\"194.237604\" style=\"fill: #00c3ff; stroke: #00c3ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.267544\" y=\"194.252353\" style=\"fill: #00c0ff; stroke: #00c0ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.212053\" y=\"194.266733\" style=\"fill: #00bdff; stroke: #00bdff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.157237\" y=\"194.280753\" style=\"fill: #00bbff; stroke: #00bbff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.103086\" y=\"194.29442\" style=\"fill: #00b8ff; stroke: #00b8ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"572.049592\" y=\"194.307743\" style=\"fill: #00b5ff; stroke: #00b5ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.996748\" y=\"194.32073\" style=\"fill: #00b2ff; stroke: #00b2ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.944543\" y=\"194.333387\" style=\"fill: #00afff; stroke: #00afff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.892972\" y=\"194.345724\" style=\"fill: #00acff; stroke: #00acff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.842025\" y=\"194.357746\" style=\"fill: #00a9ff; stroke: #00a9ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.791694\" y=\"194.369461\" style=\"fill: #00a6ff; stroke: #00a6ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.741972\" y=\"194.380876\" style=\"fill: #00a3ff; stroke: #00a3ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.692852\" y=\"194.391998\" style=\"fill: #00a0ff; stroke: #00a0ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.644325\" y=\"194.402834\" style=\"fill: #009dff; stroke: #009dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.596384\" y=\"194.41339\" style=\"fill: #009aff; stroke: #009aff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.549022\" y=\"194.423672\" style=\"fill: #0098ff; stroke: #0098ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.502231\" y=\"194.433687\" style=\"fill: #0095ff; stroke: #0095ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.456004\" y=\"194.443441\" style=\"fill: #0092ff; stroke: #0092ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.410335\" y=\"194.452941\" style=\"fill: #008fff; stroke: #008fff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.365215\" y=\"194.462191\" style=\"fill: #008cff; stroke: #008cff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.320639\" y=\"194.471197\" style=\"fill: #0089ff; stroke: #0089ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.2766\" y=\"194.479966\" style=\"fill: #0086ff; stroke: #0086ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.23309\" y=\"194.488503\" style=\"fill: #0083ff; stroke: #0083ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.190103\" y=\"194.496813\" style=\"fill: #0080ff; stroke: #0080ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.147632\" y=\"194.504901\" style=\"fill: #007dff; stroke: #007dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.105672\" y=\"194.512773\" style=\"fill: #007aff; stroke: #007aff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.064215\" y=\"194.520434\" style=\"fill: #0077ff; stroke: #0077ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"571.023256\" y=\"194.527888\" style=\"fill: #0075ff; stroke: #0075ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.982788\" y=\"194.535141\" style=\"fill: #0072ff; stroke: #0072ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.942805\" y=\"194.542197\" style=\"fill: #006fff; stroke: #006fff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.903301\" y=\"194.54906\" style=\"fill: #006cff; stroke: #006cff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.86427\" y=\"194.555736\" style=\"fill: #0069ff; stroke: #0069ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.825706\" y=\"194.562229\" style=\"fill: #0066ff; stroke: #0066ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.787603\" y=\"194.568543\" style=\"fill: #0063ff; stroke: #0063ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.749956\" y=\"194.574682\" style=\"fill: #0060ff; stroke: #0060ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.712759\" y=\"194.58065\" style=\"fill: #005dff; stroke: #005dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.676007\" y=\"194.586452\" style=\"fill: #005aff; stroke: #005aff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.639693\" y=\"194.592091\" style=\"fill: #0057ff; stroke: #0057ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.603812\" y=\"194.597572\" style=\"fill: #0055ff; stroke: #0055ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.56836\" y=\"194.602898\" style=\"fill: #0052ff; stroke: #0052ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.53333\" y=\"194.608072\" style=\"fill: #004fff; stroke: #004fff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.498718\" y=\"194.613099\" style=\"fill: #004cff; stroke: #004cff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.464518\" y=\"194.617982\" style=\"fill: #0049ff; stroke: #0049ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.430726\" y=\"194.622725\" style=\"fill: #0046ff; stroke: #0046ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.397335\" y=\"194.62733\" style=\"fill: #0043ff; stroke: #0043ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.364342\" y=\"194.631801\" style=\"fill: #0040ff; stroke: #0040ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.331741\" y=\"194.636142\" style=\"fill: #003dff; stroke: #003dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.299528\" y=\"194.640355\" style=\"fill: #003aff; stroke: #003aff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.267697\" y=\"194.644443\" style=\"fill: #0037ff; stroke: #0037ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.236245\" y=\"194.648411\" style=\"fill: #0034ff; stroke: #0034ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.205166\" y=\"194.65226\" style=\"fill: #0032ff; stroke: #0032ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.174455\" y=\"194.655993\" style=\"fill: #002fff; stroke: #002fff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.144109\" y=\"194.659614\" style=\"fill: #002cff; stroke: #002cff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.114123\" y=\"194.663124\" style=\"fill: #0029ff; stroke: #0029ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.084492\" y=\"194.666528\" style=\"fill: #0026ff; stroke: #0026ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.055212\" y=\"194.669827\" style=\"fill: #0023ff; stroke: #0023ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"570.026279\" y=\"194.673023\" style=\"fill: #0020ff; stroke: #0020ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.997688\" y=\"194.676121\" style=\"fill: #001dff; stroke: #001dff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.969435\" y=\"194.679121\" style=\"fill: #001aff; stroke: #001aff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.941517\" y=\"194.682027\" style=\"fill: #0017ff; stroke: #0017ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.913929\" y=\"194.68484\" style=\"fill: #0014ff; stroke: #0014ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.886666\" y=\"194.687563\" style=\"fill: #0011ff; stroke: #0011ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.859726\" y=\"194.690199\" style=\"fill: #000fff; stroke: #000fff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.833104\" y=\"194.692749\" style=\"fill: #000cff; stroke: #000cff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.806796\" y=\"194.695216\" style=\"fill: #0009ff; stroke: #0009ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.780799\" y=\"194.697601\" style=\"fill: #0006ff; stroke: #0006ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.755108\" y=\"194.699907\" style=\"fill: #0003ff; stroke: #0003ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.72972\" y=\"194.702136\" style=\"fill: #0000ff; stroke: #0000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.704631\" y=\"194.70429\" style=\"fill: #0300ff; stroke: #0300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.679838\" y=\"194.70637\" style=\"fill: #0600ff; stroke: #0600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.655337\" y=\"194.708378\" style=\"fill: #0900ff; stroke: #0900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.631124\" y=\"194.710318\" style=\"fill: #0c00ff; stroke: #0c00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.607197\" y=\"194.712189\" style=\"fill: #0f00ff; stroke: #0f00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.58355\" y=\"194.713994\" style=\"fill: #1100ff; stroke: #1100ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.560182\" y=\"194.715734\" style=\"fill: #1400ff; stroke: #1400ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.537089\" y=\"194.717412\" style=\"fill: #1700ff; stroke: #1700ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.514266\" y=\"194.719029\" style=\"fill: #1a00ff; stroke: #1a00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.491712\" y=\"194.720586\" style=\"fill: #1d00ff; stroke: #1d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.469423\" y=\"194.722085\" style=\"fill: #2000ff; stroke: #2000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.447396\" y=\"194.723527\" style=\"fill: #2300ff; stroke: #2300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.425627\" y=\"194.724915\" style=\"fill: #2600ff; stroke: #2600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.404113\" y=\"194.726248\" style=\"fill: #2900ff; stroke: #2900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.382852\" y=\"194.72753\" style=\"fill: #2c00ff; stroke: #2c00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.36184\" y=\"194.728761\" style=\"fill: #2f00ff; stroke: #2f00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.341074\" y=\"194.729942\" style=\"fill: #3200ff; stroke: #3200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.320552\" y=\"194.731076\" style=\"fill: #3400ff; stroke: #3400ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.300269\" y=\"194.732162\" style=\"fill: #3700ff; stroke: #3700ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.280225\" y=\"194.733203\" style=\"fill: #3a00ff; stroke: #3a00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.260415\" y=\"194.7342\" style=\"fill: #3d00ff; stroke: #3d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.240836\" y=\"194.735153\" style=\"fill: #4000ff; stroke: #4000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.221487\" y=\"194.736064\" style=\"fill: #4300ff; stroke: #4300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.202364\" y=\"194.736935\" style=\"fill: #4600ff; stroke: #4600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.183464\" y=\"194.737765\" style=\"fill: #4900ff; stroke: #4900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.164786\" y=\"194.738557\" style=\"fill: #4c00ff; stroke: #4c00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.146325\" y=\"194.739312\" style=\"fill: #4f00ff; stroke: #4f00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.12808\" y=\"194.740029\" style=\"fill: #5200ff; stroke: #5200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.110049\" y=\"194.740712\" style=\"fill: #5500ff; stroke: #5500ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.092227\" y=\"194.741359\" style=\"fill: #5700ff; stroke: #5700ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.074614\" y=\"194.741973\" style=\"fill: #5a00ff; stroke: #5a00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.057206\" y=\"194.742555\" style=\"fill: #5d00ff; stroke: #5d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.040001\" y=\"194.743104\" style=\"fill: #6000ff; stroke: #6000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.022997\" y=\"194.743623\" style=\"fill: #6300ff; stroke: #6300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"569.00619\" y=\"194.744112\" style=\"fill: #6600ff; stroke: #6600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.98958\" y=\"194.744571\" style=\"fill: #6900ff; stroke: #6900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.973163\" y=\"194.745003\" style=\"fill: #6c00ff; stroke: #6c00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.956937\" y=\"194.745407\" style=\"fill: #6f00ff; stroke: #6f00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.940901\" y=\"194.745784\" style=\"fill: #7200ff; stroke: #7200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.92505\" y=\"194.746135\" style=\"fill: #7500ff; stroke: #7500ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.909385\" y=\"194.746461\" style=\"fill: #7700ff; stroke: #7700ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.893901\" y=\"194.746763\" style=\"fill: #7a00ff; stroke: #7a00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.878598\" y=\"194.747041\" style=\"fill: #7d00ff; stroke: #7d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.863472\" y=\"194.747295\" style=\"fill: #8000ff; stroke: #8000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.848523\" y=\"194.747528\" style=\"fill: #8300ff; stroke: #8300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.833747\" y=\"194.747739\" style=\"fill: #8600ff; stroke: #8600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.819142\" y=\"194.747929\" style=\"fill: #8900ff; stroke: #8900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.804708\" y=\"194.748098\" style=\"fill: #8c00ff; stroke: #8c00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.79044\" y=\"194.748248\" style=\"fill: #8f00ff; stroke: #8f00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.776339\" y=\"194.748379\" style=\"fill: #9200ff; stroke: #9200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.762401\" y=\"194.748491\" style=\"fill: #9500ff; stroke: #9500ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.748625\" y=\"194.748585\" style=\"fill: #9800ff; stroke: #9800ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.735009\" y=\"194.748662\" style=\"fill: #9a00ff; stroke: #9a00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.72155\" y=\"194.748721\" style=\"fill: #9d00ff; stroke: #9d00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.708248\" y=\"194.748765\" style=\"fill: #a000ff; stroke: #a000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.6951\" y=\"194.748792\" style=\"fill: #a300ff; stroke: #a300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.682104\" y=\"194.748805\" style=\"fill: #a600ff; stroke: #a600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.669259\" y=\"194.748802\" style=\"fill: #a900ff; stroke: #a900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.656562\" y=\"194.748785\" style=\"fill: #ac00ff; stroke: #ac00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.644013\" y=\"194.748754\" style=\"fill: #af00ff; stroke: #af00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.631609\" y=\"194.74871\" style=\"fill: #b200ff; stroke: #b200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.619349\" y=\"194.748653\" style=\"fill: #b500ff; stroke: #b500ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.60723\" y=\"194.748583\" style=\"fill: #b800ff; stroke: #b800ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.595252\" y=\"194.748502\" style=\"fill: #bb00ff; stroke: #bb00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.583412\" y=\"194.748408\" style=\"fill: #bd00ff; stroke: #bd00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.571709\" y=\"194.748303\" style=\"fill: #c000ff; stroke: #c000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.560141\" y=\"194.748188\" style=\"fill: #c300ff; stroke: #c300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.548708\" y=\"194.748061\" style=\"fill: #c600ff; stroke: #c600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.537406\" y=\"194.747925\" style=\"fill: #c900ff; stroke: #c900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.526235\" y=\"194.747779\" style=\"fill: #cc00ff; stroke: #cc00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.515193\" y=\"194.747623\" style=\"fill: #cf00ff; stroke: #cf00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.504278\" y=\"194.747459\" style=\"fill: #d200ff; stroke: #d200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.49349\" y=\"194.747285\" style=\"fill: #d500ff; stroke: #d500ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.482826\" y=\"194.747103\" style=\"fill: #d800ff; stroke: #d800ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.472285\" y=\"194.746913\" style=\"fill: #db00ff; stroke: #db00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.461866\" y=\"194.746715\" style=\"fill: #dd00ff; stroke: #dd00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.451567\" y=\"194.74651\" style=\"fill: #e000ff; stroke: #e000ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.441387\" y=\"194.746298\" style=\"fill: #e300ff; stroke: #e300ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.431325\" y=\"194.746078\" style=\"fill: #e600ff; stroke: #e600ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.421378\" y=\"194.745852\" style=\"fill: #e900ff; stroke: #e900ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.411546\" y=\"194.74562\" style=\"fill: #ec00ff; stroke: #ec00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.401828\" y=\"194.745381\" style=\"fill: #ef00ff; stroke: #ef00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.392221\" y=\"194.745136\" style=\"fill: #f200ff; stroke: #f200ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.382725\" y=\"194.744886\" style=\"fill: #f500ff; stroke: #f500ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.373339\" y=\"194.744631\" style=\"fill: #f800ff; stroke: #f800ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.364061\" y=\"194.74437\" style=\"fill: #fb00ff; stroke: #fb00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.35489\" y=\"194.744105\" style=\"fill: #fe00ff; stroke: #fe00ff\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.345824\" y=\"194.743835\" style=\"fill: #ff00fe; stroke: #ff00fe\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.336862\" y=\"194.74356\" style=\"fill: #ff00fb; stroke: #ff00fb\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.328004\" y=\"194.743281\" style=\"fill: #ff00f8; stroke: #ff00f8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.319248\" y=\"194.742999\" style=\"fill: #ff00f5; stroke: #ff00f5\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.310592\" y=\"194.742712\" style=\"fill: #ff00f2; stroke: #ff00f2\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.302037\" y=\"194.742421\" style=\"fill: #ff00ef; stroke: #ff00ef\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.293579\" y=\"194.742128\" style=\"fill: #ff00ec; stroke: #ff00ec\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.285219\" y=\"194.741831\" style=\"fill: #ff00e9; stroke: #ff00e9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.276955\" y=\"194.74153\" style=\"fill: #ff00e6; stroke: #ff00e6\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.268786\" y=\"194.741227\" style=\"fill: #ff00e3; stroke: #ff00e3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.260711\" y=\"194.740921\" style=\"fill: #ff00e0; stroke: #ff00e0\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.252729\" y=\"194.740613\" style=\"fill: #ff00dd; stroke: #ff00dd\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.244838\" y=\"194.740302\" style=\"fill: #ff00db; stroke: #ff00db\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.237038\" y=\"194.739989\" style=\"fill: #ff00d8; stroke: #ff00d8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.229328\" y=\"194.739673\" style=\"fill: #ff00d5; stroke: #ff00d5\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.221706\" y=\"194.739356\" style=\"fill: #ff00d2; stroke: #ff00d2\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.214172\" y=\"194.739037\" style=\"fill: #ff00cf; stroke: #ff00cf\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.206725\" y=\"194.738716\" style=\"fill: #ff00cc; stroke: #ff00cc\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.199363\" y=\"194.738394\" style=\"fill: #ff00c9; stroke: #ff00c9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.192085\" y=\"194.73807\" style=\"fill: #ff00c6; stroke: #ff00c6\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.184891\" y=\"194.737745\" style=\"fill: #ff00c3; stroke: #ff00c3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.17778\" y=\"194.737418\" style=\"fill: #ff00c0; stroke: #ff00c0\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.17075\" y=\"194.737091\" style=\"fill: #ff00bd; stroke: #ff00bd\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.163801\" y=\"194.736762\" style=\"fill: #ff00bb; stroke: #ff00bb\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.156931\" y=\"194.736433\" style=\"fill: #ff00b8; stroke: #ff00b8\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.150141\" y=\"194.736103\" style=\"fill: #ff00b5; stroke: #ff00b5\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.143428\" y=\"194.735772\" style=\"fill: #ff00b2; stroke: #ff00b2\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.136792\" y=\"194.735441\" style=\"fill: #ff00af; stroke: #ff00af\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.130232\" y=\"194.73511\" style=\"fill: #ff00ac; stroke: #ff00ac\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.123748\" y=\"194.734778\" style=\"fill: #ff00a9; stroke: #ff00a9\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.117338\" y=\"194.734445\" style=\"fill: #ff00a6; stroke: #ff00a6\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.111001\" y=\"194.734113\" style=\"fill: #ff00a3; stroke: #ff00a3\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.104737\" y=\"194.73378\" style=\"fill: #ff00a0; stroke: #ff00a0\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.098545\" y=\"194.733448\" style=\"fill: #ff009d; stroke: #ff009d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.092423\" y=\"194.733116\" style=\"fill: #ff009a; stroke: #ff009a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.086372\" y=\"194.732783\" style=\"fill: #ff0098; stroke: #ff0098\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.08039\" y=\"194.732451\" style=\"fill: #ff0095; stroke: #ff0095\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.074477\" y=\"194.73212\" style=\"fill: #ff0092; stroke: #ff0092\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.068631\" y=\"194.731788\" style=\"fill: #ff008f; stroke: #ff008f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.062853\" y=\"194.731457\" style=\"fill: #ff008c; stroke: #ff008c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.05714\" y=\"194.731127\" style=\"fill: #ff0089; stroke: #ff0089\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.051493\" y=\"194.730797\" style=\"fill: #ff0086; stroke: #ff0086\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.045911\" y=\"194.730468\" style=\"fill: #ff0083; stroke: #ff0083\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.040392\" y=\"194.73014\" style=\"fill: #ff0080; stroke: #ff0080\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.034936\" y=\"194.729812\" style=\"fill: #ff007d; stroke: #ff007d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.029543\" y=\"194.729485\" style=\"fill: #ff007a; stroke: #ff007a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.024212\" y=\"194.729159\" style=\"fill: #ff0077; stroke: #ff0077\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.018942\" y=\"194.728834\" style=\"fill: #ff0075; stroke: #ff0075\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.013732\" y=\"194.72851\" style=\"fill: #ff0072; stroke: #ff0072\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.008581\" y=\"194.728187\" style=\"fill: #ff006f; stroke: #ff006f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"568.00349\" y=\"194.727864\" style=\"fill: #ff006c; stroke: #ff006c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.998456\" y=\"194.727543\" style=\"fill: #ff0069; stroke: #ff0069\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.993481\" y=\"194.727224\" style=\"fill: #ff0066; stroke: #ff0066\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.988562\" y=\"194.726905\" style=\"fill: #ff0063; stroke: #ff0063\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.983699\" y=\"194.726587\" style=\"fill: #ff0060; stroke: #ff0060\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.978892\" y=\"194.726271\" style=\"fill: #ff005d; stroke: #ff005d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.97414\" y=\"194.725956\" style=\"fill: #ff005a; stroke: #ff005a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.969442\" y=\"194.725643\" style=\"fill: #ff0057; stroke: #ff0057\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.964798\" y=\"194.72533\" style=\"fill: #ff0055; stroke: #ff0055\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.960207\" y=\"194.72502\" style=\"fill: #ff0052; stroke: #ff0052\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.955668\" y=\"194.72471\" style=\"fill: #ff004f; stroke: #ff004f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.951181\" y=\"194.724402\" style=\"fill: #ff004c; stroke: #ff004c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.946746\" y=\"194.724096\" style=\"fill: #ff0049; stroke: #ff0049\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.942361\" y=\"194.723791\" style=\"fill: #ff0046; stroke: #ff0046\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.938026\" y=\"194.723487\" style=\"fill: #ff0043; stroke: #ff0043\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.93374\" y=\"194.723185\" style=\"fill: #ff0040; stroke: #ff0040\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.929504\" y=\"194.722885\" style=\"fill: #ff003d; stroke: #ff003d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.925316\" y=\"194.722586\" style=\"fill: #ff003a; stroke: #ff003a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.921176\" y=\"194.722289\" style=\"fill: #ff0037; stroke: #ff0037\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.917083\" y=\"194.721994\" style=\"fill: #ff0034; stroke: #ff0034\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.913037\" y=\"194.7217\" style=\"fill: #ff0032; stroke: #ff0032\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.909037\" y=\"194.721408\" style=\"fill: #ff002f; stroke: #ff002f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.905082\" y=\"194.721117\" style=\"fill: #ff002c; stroke: #ff002c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.901173\" y=\"194.720829\" style=\"fill: #ff0029; stroke: #ff0029\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.897308\" y=\"194.720542\" style=\"fill: #ff0026; stroke: #ff0026\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.893487\" y=\"194.720256\" style=\"fill: #ff0023; stroke: #ff0023\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.88971\" y=\"194.719973\" style=\"fill: #ff0020; stroke: #ff0020\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.885976\" y=\"194.719691\" style=\"fill: #ff001d; stroke: #ff001d\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.882285\" y=\"194.719411\" style=\"fill: #ff001a; stroke: #ff001a\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.878636\" y=\"194.719133\" style=\"fill: #ff0017; stroke: #ff0017\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.875028\" y=\"194.718856\" style=\"fill: #ff0014; stroke: #ff0014\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.871462\" y=\"194.718582\" style=\"fill: #ff0011; stroke: #ff0011\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.867936\" y=\"194.718309\" style=\"fill: #ff000f; stroke: #ff000f\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.86445\" y=\"194.718038\" style=\"fill: #ff000c; stroke: #ff000c\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.861004\" y=\"194.717769\" style=\"fill: #ff0009; stroke: #ff0009\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.857598\" y=\"194.717501\" style=\"fill: #ff0006; stroke: #ff0006\"/>\n",
       "    </g>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#C0_0_4dbeaaca78\" x=\"567.85423\" y=\"194.717236\" style=\"fill: #ff0003; stroke: #ff0003\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m501a4e6bf1\" d=\"M -3 3 \n",
       "L 3 3 \n",
       "L 3 -3 \n",
       "L -3 -3 \n",
       "z\n",
       "\" style=\"stroke: #000000\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <use xlink:href=\"#m501a4e6bf1\" x=\"567.561932\" y=\"194.69022\" style=\"fill: #ff0000; stroke: #000000\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_35\">\n",
       "      <path d=\"M 442.085321 299.518125 \n",
       "L 442.085321 22.318125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"442.085321\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- −0.75 -->\n",
       "      <g transform=\"translate(426.762665 314.116563) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-2212\" d=\"M 678 2272 \n",
       "L 4684 2272 \n",
       "L 4684 1741 \n",
       "L 678 1741 \n",
       "L 678 2272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-2212\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"83.789062\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"147.412109\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-37\" x=\"179.199219\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"242.822266\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <path d=\"M 480.130775 299.518125 \n",
       "L 480.130775 22.318125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"480.130775\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- −0.50 -->\n",
       "      <g transform=\"translate(464.808119 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-2212\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"83.789062\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"147.412109\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"179.199219\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"242.822266\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <path d=\"M 518.17623 299.518125 \n",
       "L 518.17623 22.318125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"518.17623\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- −0.25 -->\n",
       "      <g transform=\"translate(502.853574 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-2212\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"83.789062\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"147.412109\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-32\" x=\"179.199219\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"242.822266\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_41\">\n",
       "      <path d=\"M 556.221684 299.518125 \n",
       "L 556.221684 22.318125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_42\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"556.221684\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.00 -->\n",
       "      <g transform=\"translate(545.088872 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_43\">\n",
       "      <path d=\"M 594.267139 299.518125 \n",
       "L 594.267139 22.318125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_44\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"594.267139\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.25 -->\n",
       "      <g transform=\"translate(583.134326 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-32\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_45\">\n",
       "      <path d=\"M 632.312594 299.518125 \n",
       "L 632.312594 22.318125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_46\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"632.312594\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.50 -->\n",
       "      <g transform=\"translate(621.179781 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_13\">\n",
       "     <g id=\"line2d_47\">\n",
       "      <path d=\"M 670.358048 299.518125 \n",
       "L 670.358048 22.318125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_48\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"670.358048\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.75 -->\n",
       "      <g transform=\"translate(659.225236 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-37\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_14\">\n",
       "     <g id=\"line2d_49\">\n",
       "      <path d=\"M 708.403503 299.518125 \n",
       "L 708.403503 22.318125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_50\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mcef5502930\" x=\"708.403503\" y=\"299.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 1.00 -->\n",
       "      <g transform=\"translate(697.27069 314.116563) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"159.033203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_29\">\n",
       "     <!-- x -->\n",
       "     <g transform=\"translate(564.602557 327.794688) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-78\" d=\"M 3513 3500 \n",
       "L 2247 1797 \n",
       "L 3578 0 \n",
       "L 2900 0 \n",
       "L 1881 1375 \n",
       "L 863 0 \n",
       "L 184 0 \n",
       "L 1544 1831 \n",
       "L 300 3500 \n",
       "L 978 3500 \n",
       "L 1906 2253 \n",
       "L 2834 3500 \n",
       "L 3513 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-78\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_51\">\n",
       "      <path d=\"M 415.380114 297.587887 \n",
       "L 719.74375 297.587887 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_52\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"415.380114\" y=\"297.587887\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- −0.5 -->\n",
       "      <g transform=\"translate(384.097301 301.387106) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-2212\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"83.789062\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"147.412109\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"179.199219\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_53\">\n",
       "      <path d=\"M 415.380114 245.173935 \n",
       "L 719.74375 245.173935 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_54\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"415.380114\" y=\"245.173935\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- 0.0 -->\n",
       "      <g transform=\"translate(392.476989 248.973153) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_55\">\n",
       "      <path d=\"M 415.380114 192.759982 \n",
       "L 719.74375 192.759982 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_56\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"415.380114\" y=\"192.759982\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_32\">\n",
       "      <!-- 0.5 -->\n",
       "      <g transform=\"translate(392.476989 196.559201) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_57\">\n",
       "      <path d=\"M 415.380114 140.34603 \n",
       "L 719.74375 140.34603 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_58\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"415.380114\" y=\"140.34603\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_33\">\n",
       "      <!-- 1.0 -->\n",
       "      <g transform=\"translate(392.476989 144.145249) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_59\">\n",
       "      <path d=\"M 415.380114 87.932077 \n",
       "L 719.74375 87.932077 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_60\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"415.380114\" y=\"87.932077\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_34\">\n",
       "      <!-- 1.5 -->\n",
       "      <g transform=\"translate(392.476989 91.731296) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_61\">\n",
       "      <path d=\"M 415.380114 35.518125 \n",
       "L 719.74375 35.518125 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_62\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m27c10034a7\" x=\"415.380114\" y=\"35.518125\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_35\">\n",
       "      <!-- 2.0 -->\n",
       "      <g transform=\"translate(392.476989 39.317344) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"95.410156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_36\">\n",
       "     <!-- y -->\n",
       "     <g transform=\"translate(378.017614 163.8775) rotate(-90) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-79\" d=\"M 2059 -325 \n",
       "Q 1816 -950 1584 -1140 \n",
       "Q 1353 -1331 966 -1331 \n",
       "L 506 -1331 \n",
       "L 506 -850 \n",
       "L 844 -850 \n",
       "Q 1081 -850 1212 -737 \n",
       "Q 1344 -625 1503 -206 \n",
       "L 1606 56 \n",
       "L 191 3500 \n",
       "L 800 3500 \n",
       "L 1894 763 \n",
       "L 2988 3500 \n",
       "L 3597 3500 \n",
       "L 2059 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-79\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_63\">\n",
       "    <path d=\"M 708.403503 35.518125 \n",
       "L 683.175197 69.515907 \n",
       "L 664.278532 94.633555 \n",
       "L 649.137066 114.405853 \n",
       "L 636.957011 129.967507 \n",
       "L 626.431476 143.062129 \n",
       "L 617.970499 153.260082 \n",
       "L 610.634316 161.781695 \n",
       "L 604.300472 168.821022 \n",
       "L 598.855989 174.563785 \n",
       "L 593.866419 179.503237 \n",
       "L 589.66317 183.358601 \n",
       "L 585.904207 186.509069 \n",
       "L 582.606632 188.987495 \n",
       "L 579.615762 190.95417 \n",
       "L 577.003236 192.408554 \n",
       "L 574.624807 193.477792 \n",
       "L 572.496423 194.19106 \n",
       "L 570.56836 194.602898 \n",
       "L 568.833747 194.747739 \n",
       "L 567.85423 194.717236 \n",
       "L 567.85423 194.717236 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke-dasharray: 5.55,2.4; stroke-dashoffset: 0; stroke: #ff0000; stroke-opacity: 0.6; stroke-width: 1.5\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_3\">\n",
       "    <path d=\"M 542.697052 217.994473 \n",
       "L 541.4297 217.636324 \n",
       "L 539.096389 216.926442 \n",
       "L 538.35532 216.679506 \n",
       "L 535.28094 215.578923 \n",
       "L 533.255187 214.808707 \n",
       "L 532.20656 214.369298 \n",
       "L 529.13218 213.004398 \n",
       "L 528.463879 212.690972 \n",
       "L 526.0578 211.438337 \n",
       "L 524.474611 210.573236 \n",
       "L 522.983419 209.659876 \n",
       "L 521.106336 208.455501 \n",
       "L 519.909039 207.584078 \n",
       "L 518.271419 206.337765 \n",
       "L 516.834659 205.078706 \n",
       "L 515.896008 204.22003 \n",
       "L 513.926511 202.102294 \n",
       "L 513.760279 201.884568 \n",
       "L 512.36991 199.984559 \n",
       "L 511.143948 197.866823 \n",
       "L 510.685899 196.782313 \n",
       "L 510.26738 195.749088 \n",
       "L 509.727712 193.631352 \n",
       "L 509.503224 191.513617 \n",
       "L 509.595403 189.395882 \n",
       "L 510.00504 187.278146 \n",
       "L 510.685899 185.294234 \n",
       "L 510.734941 185.160411 \n",
       "L 511.8398 183.042675 \n",
       "L 513.279867 180.92494 \n",
       "L 513.760279 180.347779 \n",
       "L 515.134195 178.807204 \n",
       "L 516.834659 177.194804 \n",
       "L 517.407996 176.689469 \n",
       "L 519.909039 174.771273 \n",
       "L 520.190257 174.571733 \n",
       "L 522.983419 172.811021 \n",
       "L 523.598985 172.453998 \n",
       "L 526.0578 171.167044 \n",
       "L 527.794112 170.336262 \n",
       "L 529.13218 169.751376 \n",
       "L 532.20656 168.530683 \n",
       "L 533.079021 168.218527 \n",
       "L 535.28094 167.491131 \n",
       "L 538.35532 166.586524 \n",
       "L 540.232693 166.100792 \n",
       "L 541.4297 165.812403 \n",
       "L 544.504081 165.171078 \n",
       "L 547.578461 164.629438 \n",
       "L 550.652841 164.186256 \n",
       "L 552.45682 163.983056 \n",
       "L 553.727221 163.848747 \n",
       "L 556.801601 163.613646 \n",
       "L 559.875981 163.468181 \n",
       "L 562.950362 163.411612 \n",
       "L 566.024742 163.443263 \n",
       "L 569.099122 163.562523 \n",
       "L 572.173502 163.768843 \n",
       "L 574.42086 163.983056 \n",
       "L 575.247882 164.066452 \n",
       "L 578.322262 164.468087 \n",
       "L 581.396643 164.960395 \n",
       "L 584.471023 165.542992 \n",
       "L 587.020053 166.100792 \n",
       "L 587.545403 166.222875 \n",
       "L 590.619783 167.033515 \n",
       "L 593.694163 167.938932 \n",
       "L 594.552752 168.218527 \n",
       "L 596.768543 168.988249 \n",
       "L 599.842924 170.157121 \n",
       "L 600.276292 170.336262 \n",
       "L 602.917304 171.507097 \n",
       "L 604.896242 172.453998 \n",
       "L 605.991684 173.01977 \n",
       "L 608.790642 174.571733 \n",
       "L 609.066064 174.737836 \n",
       "L 612.094397 176.689469 \n",
       "L 612.140444 176.722043 \n",
       "L 614.910063 178.807204 \n",
       "L 615.214824 179.06192 \n",
       "L 617.316925 180.92494 \n",
       "L 618.289205 181.89516 \n",
       "L 619.377178 183.042675 \n",
       "L 621.127554 185.160411 \n",
       "L 621.363585 185.496935 \n",
       "L 622.549046 187.278146 \n",
       "L 623.703483 189.395882 \n",
       "L 624.437965 191.138605 \n",
       "L 624.588346 191.513617 \n",
       "L 625.179618 193.631352 \n",
       "L 625.506906 195.749088 \n",
       "L 625.56095 197.866823 \n",
       "L 625.331281 199.984559 \n",
       "L 624.806044 202.102294 \n",
       "L 624.437965 203.039818 \n",
       "L 623.945018 204.22003 \n",
       "L 622.718972 206.337765 \n",
       "L 621.363585 208.146058 \n",
       "L 621.115182 208.455501 \n",
       "L 619.01598 210.573236 \n",
       "L 618.289205 211.184041 \n",
       "L 616.352947 212.690972 \n",
       "L 615.214824 213.445129 \n",
       "L 612.974779 214.808707 \n",
       "L 612.140444 215.248644 \n",
       "L 609.066064 216.725805 \n",
       "L 608.604703 216.926442 \n",
       "L 605.991684 217.924615 \n",
       "L 602.917304 218.96997 \n",
       "L 602.671265 219.044178 \n",
       "L 599.842924 219.801951 \n",
       "L 596.768543 220.515845 \n",
       "L 593.694163 221.12225 \n",
       "L 593.453587 221.161913 \n",
       "L 590.619783 221.58097 \n",
       "L 587.545403 221.944308 \n",
       "L 584.471023 222.218534 \n",
       "L 581.396643 222.406171 \n",
       "L 578.322262 222.509717 \n",
       "L 577.382737 222.516415 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_4\">\n",
       "    <path d=\"M 508.968952 242.102469 \n",
       "L 501.462758 239.782774 \n",
       "L 495.313998 237.669311 \n",
       "L 489.165238 235.337548 \n",
       "L 483.016477 232.761073 \n",
       "L 476.867717 229.909379 \n",
       "L 472.201387 227.51512 \n",
       "L 467.644576 224.945251 \n",
       "L 464.570196 223.072396 \n",
       "L 461.495816 221.05544 \n",
       "L 458.421436 218.865407 \n",
       "L 455.347056 216.465686 \n",
       "L 452.272676 213.809481 \n",
       "L 449.198295 210.836132 \n",
       "L 448.938883 210.573236 \n",
       "L 446.123915 207.353306 \n",
       "L 445.303538 206.337765 \n",
       "L 443.049535 203.119219 \n",
       "L 442.401231 202.102294 \n",
       "L 441.21716 199.984559 \n",
       "L 439.975155 197.327557 \n",
       "L 439.34616 195.749088 \n",
       "L 438.660545 193.631352 \n",
       "L 438.131025 191.513617 \n",
       "L 437.756801 189.395882 \n",
       "L 437.536842 187.278146 \n",
       "L 437.469909 185.160411 \n",
       "L 437.554573 183.042675 \n",
       "L 437.789242 180.92494 \n",
       "L 438.17218 178.807204 \n",
       "L 438.701535 176.689469 \n",
       "L 439.975155 173.013555 \n",
       "L 440.197111 172.453998 \n",
       "L 441.177993 170.336262 \n",
       "L 443.049535 166.960151 \n",
       "L 443.576578 166.100792 \n",
       "L 446.123915 162.4882 \n",
       "L 448.359612 159.747585 \n",
       "L 450.28579 157.62985 \n",
       "L 452.378311 155.512114 \n",
       "L 455.347056 152.802706 \n",
       "L 458.421436 150.258613 \n",
       "L 462.746142 147.041173 \n",
       "L 467.644576 143.817478 \n",
       "L 470.718957 141.977338 \n",
       "L 473.793337 140.258517 \n",
       "L 479.942097 137.15274 \n",
       "L 483.016477 135.742525 \n",
       "L 489.165238 133.175696 \n",
       "L 495.313998 130.910323 \n",
       "L 501.462758 128.91621 \n",
       "L 507.611519 127.167857 \n",
       "L 513.760279 125.64352 \n",
       "L 519.909039 124.338651 \n",
       "L 526.0578 123.23151 \n",
       "L 532.20656 122.31754 \n",
       "L 538.35532 121.582307 \n",
       "L 544.504081 121.035231 \n",
       "L 550.652841 120.659476 \n",
       "L 556.801601 120.454177 \n",
       "L 562.950362 120.418601 \n",
       "L 569.099122 120.552142 \n",
       "L 575.247882 120.854319 \n",
       "L 581.396643 121.324782 \n",
       "L 587.545403 121.971029 \n",
       "L 593.694163 122.796088 \n",
       "L 599.842924 123.79409 \n",
       "L 605.991684 124.990724 \n",
       "L 612.140444 126.375978 \n",
       "L 618.352535 127.981553 \n",
       "L 625.449338 130.099289 \n",
       "L 631.687103 132.217024 \n",
       "L 637.269339 134.33476 \n",
       "L 642.884246 136.701571 \n",
       "L 649.033006 139.599969 \n",
       "L 655.181767 142.844895 \n",
       "L 661.330527 146.524415 \n",
       "L 665.29904 149.158908 \n",
       "L 670.553667 153.031765 \n",
       "L 673.628048 155.535485 \n",
       "L 678.257274 159.747585 \n",
       "L 680.365511 161.865321 \n",
       "L 684.148945 166.100792 \n",
       "L 685.925568 168.316551 \n",
       "L 688.999948 172.668082 \n",
       "L 691.394533 176.689469 \n",
       "L 692.492478 178.807204 \n",
       "L 694.347311 183.042675 \n",
       "L 695.148709 185.257631 \n",
       "L 696.312907 189.395882 \n",
       "L 697.081513 193.631352 \n",
       "L 697.302121 195.749088 \n",
       "L 697.410994 197.866823 \n",
       "L 697.405901 199.984559 \n",
       "L 697.284355 202.102294 \n",
       "L 697.043589 204.22003 \n",
       "L 696.680521 206.337765 \n",
       "L 696.19173 208.455501 \n",
       "L 695.148709 211.770229 \n",
       "L 694.813239 212.690972 \n",
       "L 693.900535 214.808707 \n",
       "L 692.074329 218.264909 \n",
       "L 691.615335 219.044178 \n",
       "L 688.999948 222.778751 \n",
       "L 688.614661 223.279649 \n",
       "L 685.925568 226.329092 \n",
       "L 684.768475 227.51512 \n",
       "L 682.484188 229.632855 \n",
       "L 679.776808 231.852641 \n",
       "L 676.702428 234.074981 \n",
       "L 673.628048 236.0534 \n",
       "L 670.026697 238.103797 \n",
       "L 664.404907 240.847786 \n",
       "L 660.923315 242.339268 \n",
       "L 655.181767 244.474926 \n",
       "L 648.41909 246.574739 \n",
       "L 642.884246 248.011013 \n",
       "L 636.735486 249.368266 \n",
       "L 628.677428 250.81021 \n",
       "L 624.437965 251.41938 \n",
       "L 618.289205 252.156298 \n",
       "L 609.525513 252.927945 \n",
       "L 602.917304 253.290957 \n",
       "L 593.694163 253.525672 \n",
       "L 584.471023 253.461295 \n",
       "L 575.247882 253.112533 \n",
       "L 566.024742 252.474219 \n",
       "L 556.801601 251.559733 \n",
       "L 547.578461 250.371621 \n",
       "L 543.390373 249.729959 \n",
       "L 543.390373 249.729959 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_5\">\n",
       "    <path d=\"M 719.74375 242.976139 \n",
       "L 717.836574 244.457003 \n",
       "L 716.66937 245.304221 \n",
       "L 714.865903 246.574739 \n",
       "L 713.59499 247.41359 \n",
       "L 711.595708 248.692474 \n",
       "L 710.52061 249.3382 \n",
       "L 707.987831 250.81021 \n",
       "L 707.446229 251.106396 \n",
       "L 704.371849 252.731969 \n",
       "L 703.988278 252.927945 \n",
       "L 701.297469 254.224472 \n",
       "L 699.528281 255.045681 \n",
       "L 698.223089 255.618241 \n",
       "L 695.148709 256.916635 \n",
       "L 694.541994 257.163416 \n",
       "L 692.074329 258.114194 \n",
       "L 688.999948 259.249545 \n",
       "L 688.910986 259.281151 \n",
       "L 685.925568 260.288241 \n",
       "L 682.851188 261.279094 \n",
       "L 682.463646 261.398887 \n",
       "L 679.776808 262.189342 \n",
       "L 676.702428 263.051889 \n",
       "L 674.965911 263.516622 \n",
       "L 673.628048 263.858215 \n",
       "L 670.553667 264.606535 \n",
       "L 667.479287 265.316328 \n",
       "L 666.02839 265.634358 \n",
       "L 664.404907 265.974779 \n",
       "L 661.330527 266.585508 \n",
       "L 658.256147 267.161257 \n",
       "L 655.181767 267.702595 \n",
       "L 654.883295 267.752093 \n",
       "L 652.107386 268.193787 \n",
       "L 649.033006 268.651291 \n",
       "L 645.958626 269.077369 \n",
       "L 642.884246 269.472504 \n",
       "L 639.809866 269.837163 \n",
       "L 639.511036 269.869829 \n",
       "L 636.735486 270.161872 \n",
       "L 633.661105 270.457042 \n",
       "L 630.586725 270.724156 \n",
       "L 627.512345 270.963605 \n",
       "L 624.437965 271.17577 \n",
       "L 621.363585 271.36102 \n",
       "L 618.289205 271.519717 \n",
       "L 615.214824 271.652208 \n",
       "L 612.140444 271.758834 \n",
       "L 609.066064 271.839924 \n",
       "L 605.991684 271.895797 \n",
       "L 602.917304 271.926763 \n",
       "L 599.842924 271.933122 \n",
       "L 596.768543 271.915165 \n",
       "L 593.694163 271.873174 \n",
       "L 590.619783 271.807421 \n",
       "L 587.545403 271.718169 \n",
       "L 584.471023 271.605673 \n",
       "L 581.396643 271.470179 \n",
       "L 578.322262 271.311924 \n",
       "L 575.247882 271.131137 \n",
       "L 572.173502 270.92804 \n",
       "L 569.099122 270.702844 \n",
       "L 566.024742 270.455755 \n",
       "L 562.950362 270.186971 \n",
       "L 559.875981 269.89668 \n",
       "L 559.611821 269.869829 \n",
       "L 556.801601 269.577121 \n",
       "L 553.727221 269.235215 \n",
       "L 550.652841 268.871904 \n",
       "L 547.578461 268.487367 \n",
       "L 544.504081 268.081775 \n",
       "L 542.12917 267.752093 \n",
       "L 541.4297 267.652564 \n",
       "L 538.35532 267.192864 \n",
       "L 535.28094 266.712222 \n",
       "L 532.20656 266.210798 \n",
       "L 529.13218 265.688748 \n",
       "L 528.824813 265.634358 \n",
       "L 526.0578 265.13231 \n",
       "L 522.983419 264.553659 \n",
       "L 519.909039 263.954512 \n",
       "L 517.737936 263.516622 \n",
       "L 516.834659 263.329698 \n",
       "L 513.760279 262.671468 \n",
       "L 510.685899 261.992901 \n",
       "L 508.073649 261.398887 \n",
       "L 507.611519 261.290992 \n",
       "L 506.173487 260.944759 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "    <path d=\"M 472.417154 251.060615 \n",
       "L 471.700901 250.81021 \n",
       "L 470.718957 250.456234 \n",
       "L 467.644576 249.325752 \n",
       "L 465.953715 248.692474 \n",
       "L 464.570196 248.157631 \n",
       "L 461.495816 246.947628 \n",
       "L 460.565424 246.574739 \n",
       "L 458.421436 245.686857 \n",
       "L 455.497945 244.457003 \n",
       "L 455.347056 244.391322 \n",
       "L 452.272676 243.028983 \n",
       "L 450.739643 242.339268 \n",
       "L 449.198295 241.620889 \n",
       "L 446.239145 240.221532 \n",
       "L 446.123915 240.164996 \n",
       "L 443.049535 238.632096 \n",
       "L 442.004766 238.103797 \n",
       "L 439.975155 237.037629 \n",
       "L 438.000162 235.986061 \n",
       "L 436.900775 235.376931 \n",
       "L 434.213559 233.868326 \n",
       "L 433.826395 233.641741 \n",
       "L 430.752014 231.818761 \n",
       "L 430.638579 231.750591 \n",
       "L 427.677634 229.892849 \n",
       "L 427.268309 229.632855 \n",
       "L 424.603254 227.862065 \n",
       "L 424.087343 227.51512 \n",
       "L 421.528874 225.711494 \n",
       "L 421.088526 225.397384 \n",
       "L 418.454494 223.423318 \n",
       "L 418.264997 223.279649 \n",
       "L 415.614584 221.161913 \n",
       "L 415.380114 220.963878 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "    <path d=\"M 415.380114 138.582584 \n",
       "L 415.393405 138.570231 \n",
       "L 417.764452 136.452495 \n",
       "L 418.454494 135.859368 \n",
       "L 420.271398 134.33476 \n",
       "L 421.528874 133.317099 \n",
       "L 422.921865 132.217024 \n",
       "L 424.603254 130.933922 \n",
       "L 425.724565 130.099289 \n",
       "L 427.677634 128.692069 \n",
       "L 428.09195 128.401033 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "    <path d=\"M 458.885671 111.499572 \n",
       "L 459.965556 111.03967 \n",
       "L 461.495816 110.402339 \n",
       "L 464.570196 109.163308 \n",
       "L 465.189523 108.921934 \n",
       "L 467.644576 107.985489 \n",
       "L 470.718957 106.85328 \n",
       "L 470.857038 106.804199 \n",
       "L 473.793337 105.781989 \n",
       "L 476.867717 104.751078 \n",
       "L 477.067855 104.686463 \n",
       "L 479.942097 103.777014 \n",
       "L 483.016477 102.842404 \n",
       "L 483.954371 102.568728 \n",
       "L 486.090857 101.957356 \n",
       "L 489.165238 101.114502 \n",
       "L 491.696135 100.450993 \n",
       "L 492.239618 100.311185 \n",
       "L 495.313998 99.555942 \n",
       "L 498.388378 98.836683 \n",
       "L 500.652675 98.333257 \n",
       "L 501.462758 98.156427 \n",
       "L 504.537138 97.520064 \n",
       "L 507.611519 96.918654 \n",
       "L 510.685899 96.352085 \n",
       "L 511.474974 96.215522 \n",
       "L 513.760279 95.826982 \n",
       "L 516.834659 95.338228 \n",
       "L 519.909039 94.883398 \n",
       "L 522.983419 94.462402 \n",
       "L 525.878029 94.097786 \n",
       "L 526.0578 94.075529 \n",
       "L 529.13218 93.727809 \n",
       "L 532.20656 93.413105 \n",
       "L 535.28094 93.131347 \n",
       "L 538.35532 92.882464 \n",
       "L 541.4297 92.666393 \n",
       "L 544.504081 92.483071 \n",
       "L 547.578461 92.332439 \n",
       "L 550.652841 92.214445 \n",
       "L 553.727221 92.129035 \n",
       "L 556.801601 92.076162 \n",
       "L 559.875981 92.055782 \n",
       "L 562.950362 92.067853 \n",
       "L 566.024742 92.112339 \n",
       "L 569.099122 92.189204 \n",
       "L 572.173502 92.298419 \n",
       "L 575.247882 92.439956 \n",
       "L 578.322262 92.61379 \n",
       "L 581.396643 92.819902 \n",
       "L 584.471023 93.058274 \n",
       "L 587.545403 93.328892 \n",
       "L 590.619783 93.631746 \n",
       "L 593.694163 93.966829 \n",
       "L 594.790187 94.097786 \n",
       "L 596.768543 94.33808 \n",
       "L 599.842924 94.744278 \n",
       "L 602.917304 95.183243 \n",
       "L 605.991684 95.654982 \n",
       "L 609.066064 96.159508 \n",
       "L 609.38654 96.215522 \n",
       "L 612.140444 96.705037 \n",
       "L 615.214824 97.284904 \n",
       "L 618.289205 97.898178 \n",
       "L 620.357522 98.333257 \n",
       "L 621.363585 98.548577 \n",
       "L 624.437965 99.240616 \n",
       "L 627.512345 99.966753 \n",
       "L 629.47054 100.450993 \n",
       "L 630.586725 100.731958 \n",
       "L 633.661105 101.54061 \n",
       "L 636.735486 102.384132 \n",
       "L 637.381604 102.568728 \n",
       "L 639.809866 103.275266 \n",
       "L 642.884246 104.20543 \n",
       "L 644.415496 104.686463 \n",
       "L 645.958626 105.180408 \n",
       "L 649.033006 106.200903 \n",
       "L 650.787782 106.804199 \n",
       "L 652.107386 107.26672 \n",
       "L 655.181767 108.38156 \n",
       "L 656.62364 108.921934 \n",
       "L 658.256147 109.546024 \n",
       "L 661.330527 110.759591 \n",
       "L 662.018406 111.03967 \n",
       "L 664.404907 112.031451 \n",
       "L 667.033301 113.157405 \n",
       "L 667.479287 113.352522 \n",
       "L 670.553667 114.737628 \n",
       "L 671.712988 115.275141 \n",
       "L 673.628048 116.182557 \n",
       "L 676.11171 117.392876 \n",
       "L 676.702428 117.687262 \n",
       "L 679.776808 119.261769 \n",
       "L 680.249942 119.510612 \n",
       "L 682.851188 120.910789 \n",
       "L 684.149901 121.628347 \n",
       "L 685.925568 122.633182 \n",
       "L 687.842597 123.746083 \n",
       "L 688.999948 124.434782 \n",
       "L 691.342125 125.863818 \n",
       "L 692.074329 126.32213 \n",
       "L 694.661311 127.981553 \n",
       "L 695.148709 128.302584 \n",
       "L 697.811853 130.099289 \n",
       "L 698.223089 130.38445 \n",
       "L 700.804447 132.217024 \n",
       "L 701.297469 132.577142 \n",
       "L 703.648892 134.33476 \n",
       "L 704.371849 134.891366 \n",
       "L 706.354185 136.452495 \n",
       "L 707.446229 137.339353 \n",
       "L 708.928603 138.570231 \n",
       "L 710.52061 139.93513 \n",
       "L 711.379775 140.687966 \n",
       "L 713.59499 142.694862 \n",
       "L 713.714743 142.805702 \n",
       "L 715.925382 144.923437 \n",
       "L 716.66937 145.66243 \n",
       "L 718.028529 147.041173 \n",
       "L 719.74375 148.848407 \n",
       "\" clip-path=\"url(#p45d8b6da80)\" style=\"fill: none; stroke: #000000; stroke-width: 1.5\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 415.380114 299.518125 \n",
       "L 415.380114 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 719.74375 299.518125 \n",
       "L 719.74375 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 415.380114 299.518125 \n",
       "L 719.74375 299.518125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 415.380114 22.318125 \n",
       "L 719.74375 22.318125 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_37\">\n",
       "    <!-- Trajectory -->\n",
       "    <g transform=\"translate(537.939744 16.318125) scale(0.12 -0.12)\">\n",
       "     <defs>\n",
       "      <path id=\"DejaVuSans-54\" d=\"M -19 4666 \n",
       "L 3928 4666 \n",
       "L 3928 4134 \n",
       "L 2272 4134 \n",
       "L 2272 0 \n",
       "L 1638 0 \n",
       "L 1638 4134 \n",
       "L -19 4134 \n",
       "L -19 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"DejaVuSans-6a\" d=\"M 603 3500 \n",
       "L 1178 3500 \n",
       "L 1178 -63 \n",
       "Q 1178 -731 923 -1031 \n",
       "Q 669 -1331 103 -1331 \n",
       "L -116 -1331 \n",
       "L -116 -844 \n",
       "L 38 -844 \n",
       "Q 366 -844 484 -692 \n",
       "Q 603 -541 603 -63 \n",
       "L 603 3500 \n",
       "z\n",
       "M 603 4863 \n",
       "L 1178 4863 \n",
       "L 1178 4134 \n",
       "L 603 4134 \n",
       "L 603 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"DejaVuSans-63\" d=\"M 3122 3366 \n",
       "L 3122 2828 \n",
       "Q 2878 2963 2633 3030 \n",
       "Q 2388 3097 2138 3097 \n",
       "Q 1578 3097 1268 2742 \n",
       "Q 959 2388 959 1747 \n",
       "Q 959 1106 1268 751 \n",
       "Q 1578 397 2138 397 \n",
       "Q 2388 397 2633 464 \n",
       "Q 2878 531 3122 666 \n",
       "L 3122 134 \n",
       "Q 2881 22 2623 -34 \n",
       "Q 2366 -91 2075 -91 \n",
       "Q 1284 -91 818 406 \n",
       "Q 353 903 353 1747 \n",
       "Q 353 2603 823 3093 \n",
       "Q 1294 3584 2113 3584 \n",
       "Q 2378 3584 2631 3529 \n",
       "Q 2884 3475 3122 3366 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#DejaVuSans-54\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-72\" x=\"46.333984\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-61\" x=\"87.447266\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-6a\" x=\"148.726562\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-65\" x=\"176.509766\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-63\" x=\"238.033203\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-74\" x=\"293.013672\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-6f\" x=\"332.222656\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-72\" x=\"393.404297\"/>\n",
       "     <use xlink:href=\"#DejaVuSans-79\" x=\"434.517578\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_38\">\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <!-- 0.4530 -->\n",
       "     <g transform=\"translate(545.71227 221.897582) rotate(-352.641342) scale(0.08 -0.08)\">\n",
       "      <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-34\" x=\"95.410156\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-35\" x=\"159.033203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-33\" x=\"222.65625\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-30\" x=\"286.279297\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_39\">\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <!-- 0.7864 -->\n",
       "     <g transform=\"translate(511.915333 245.594108) rotate(-347.512658) scale(0.08 -0.08)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-38\" d=\"M 2034 2216 \n",
       "Q 1584 2216 1326 1975 \n",
       "Q 1069 1734 1069 1313 \n",
       "Q 1069 891 1326 650 \n",
       "Q 1584 409 2034 409 \n",
       "Q 2484 409 2743 651 \n",
       "Q 3003 894 3003 1313 \n",
       "Q 3003 1734 2745 1975 \n",
       "Q 2488 2216 2034 2216 \n",
       "z\n",
       "M 1403 2484 \n",
       "Q 997 2584 770 2862 \n",
       "Q 544 3141 544 3541 \n",
       "Q 544 4100 942 4425 \n",
       "Q 1341 4750 2034 4750 \n",
       "Q 2731 4750 3128 4425 \n",
       "Q 3525 4100 3525 3541 \n",
       "Q 3525 3141 3298 2862 \n",
       "Q 3072 2584 2669 2484 \n",
       "Q 3125 2378 3379 2068 \n",
       "Q 3634 1759 3634 1313 \n",
       "Q 3634 634 3220 271 \n",
       "Q 2806 -91 2034 -91 \n",
       "Q 1263 -91 848 271 \n",
       "Q 434 634 434 1313 \n",
       "Q 434 1759 690 2068 \n",
       "Q 947 2378 1403 2484 \n",
       "z\n",
       "M 1172 3481 \n",
       "Q 1172 3119 1398 2916 \n",
       "Q 1625 2713 2034 2713 \n",
       "Q 2441 2713 2670 2916 \n",
       "Q 2900 3119 2900 3481 \n",
       "Q 2900 3844 2670 4047 \n",
       "Q 2441 4250 2034 4250 \n",
       "Q 1625 4250 1398 4047 \n",
       "Q 1172 3844 1172 3481 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-36\" d=\"M 2113 2584 \n",
       "Q 1688 2584 1439 2293 \n",
       "Q 1191 2003 1191 1497 \n",
       "Q 1191 994 1439 701 \n",
       "Q 1688 409 2113 409 \n",
       "Q 2538 409 2786 701 \n",
       "Q 3034 994 3034 1497 \n",
       "Q 3034 2003 2786 2293 \n",
       "Q 2538 2584 2113 2584 \n",
       "z\n",
       "M 3366 4563 \n",
       "L 3366 3988 \n",
       "Q 3128 4100 2886 4159 \n",
       "Q 2644 4219 2406 4219 \n",
       "Q 1781 4219 1451 3797 \n",
       "Q 1122 3375 1075 2522 \n",
       "Q 1259 2794 1537 2939 \n",
       "Q 1816 3084 2150 3084 \n",
       "Q 2853 3084 3261 2657 \n",
       "Q 3669 2231 3669 1497 \n",
       "Q 3669 778 3244 343 \n",
       "Q 2819 -91 2113 -91 \n",
       "Q 1303 -91 875 529 \n",
       "Q 447 1150 447 2328 \n",
       "Q 447 3434 972 4092 \n",
       "Q 1497 4750 2381 4750 \n",
       "Q 2619 4750 2861 4703 \n",
       "Q 3103 4656 3366 4563 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-37\" x=\"95.410156\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-38\" x=\"159.033203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-36\" x=\"222.65625\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-34\" x=\"286.279297\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_40\">\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <!-- 1.1197 -->\n",
       "     <g transform=\"translate(475.112021 254.636471) rotate(-343.699039) scale(0.08 -0.08)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-39\" d=\"M 703 97 \n",
       "L 703 672 \n",
       "Q 941 559 1184 500 \n",
       "Q 1428 441 1663 441 \n",
       "Q 2288 441 2617 861 \n",
       "Q 2947 1281 2994 2138 \n",
       "Q 2813 1869 2534 1725 \n",
       "Q 2256 1581 1919 1581 \n",
       "Q 1219 1581 811 2004 \n",
       "Q 403 2428 403 3163 \n",
       "Q 403 3881 828 4315 \n",
       "Q 1253 4750 1959 4750 \n",
       "Q 2769 4750 3195 4129 \n",
       "Q 3622 3509 3622 2328 \n",
       "Q 3622 1225 3098 567 \n",
       "Q 2575 -91 1691 -91 \n",
       "Q 1453 -91 1209 -44 \n",
       "Q 966 3 703 97 \n",
       "z\n",
       "M 1959 2075 \n",
       "Q 2384 2075 2632 2365 \n",
       "Q 2881 2656 2881 3163 \n",
       "Q 2881 3666 2632 3958 \n",
       "Q 2384 4250 1959 4250 \n",
       "Q 1534 4250 1286 3958 \n",
       "Q 1038 3666 1038 3163 \n",
       "Q 1038 2656 1286 2365 \n",
       "Q 1534 2075 1959 2075 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-31\" x=\"95.410156\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-31\" x=\"159.033203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-39\" x=\"222.65625\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-37\" x=\"286.279297\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_41\">\n",
       "    <g clip-path=\"url(#p45d8b6da80)\">\n",
       "     <!-- 1.1197 -->\n",
       "     <g transform=\"translate(431.832821 127.810424) rotate(-28.699666) scale(0.08 -0.08)\">\n",
       "      <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2e\" x=\"63.623047\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-31\" x=\"95.410156\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-31\" x=\"159.033203\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-39\" x=\"222.65625\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-37\" x=\"286.279297\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pb08c8a6baf\">\n",
       "   <rect x=\"50.14375\" y=\"22.318125\" width=\"304.363636\" height=\"277.2\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p45d8b6da80\">\n",
       "   <rect x=\"415.380114\" y=\"22.318125\" width=\"304.363636\" height=\"277.2\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1200x500 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "A = np.array([[1, -2.1], [1, 1.2], [1, 4.8], [1, 3.4]])\n",
    "b = np.array([-1, 1, 1, 1])\n",
    "oracle = LogRegOracle(A, b)\n",
    "test_2d(\"gd\", oracle, np.array([1., 2.0]), lr=0.01, tol=1e-6)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3d1c99f5",
   "metadata": {},
   "source": [
    "### Task 2.7 (0.5 points)\n",
    "\n",
    "Train simple logistic regression model on `breast_cancer` dataset using your gradient descent method. Take any feature from the dataset. Visualize the results."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "id": "caa786d0",
   "metadata": {
    "tags": [
     "remove-output"
    ]
   },
   "outputs": [],
   "source": [
    "from sklearn.datasets import load_breast_cancer\n",
    "breast = load_breast_cancer()\n",
    "y = breast['target']\n",
    "y[y == 0] = -1\n",
    "\n",
    "# YOUR CODE HERE"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "2c7d396b",
   "metadata": {},
   "source": [
    "## Newton's method\n",
    "\n",
    "Given a starting point $\\boldsymbol x_0 \\in\\mathbb R^n$ and learning rate $\\eta > 0$, iteratively calculate\n",
    "\n",
    "$$\n",
    "    \\boldsymbol x_{k+1} = \\boldsymbol x_k - \\eta \\big(\\nabla^2 f(\\boldsymbol x_k)\\big)^{-1} \\nabla f(\\boldsymbol x_k), \\quad k = 0, 1,\\ldots\n",
    "$$\n",
    "\n",
    "The process should stop when either $k = \\mathrm{max\\_iter}$ or \n",
    "\n",
    "$$\n",
    "\\Vert \\nabla f(\\boldsymbol x_k)\\Vert_2^2 \\leqslant \\varepsilon \\Vert \\nabla f(\\boldsymbol x_0)\\Vert_2^2\n",
    "$$\n",
    "\n",
    "where $\\varepsilon > 0$ is tolerance.\n",
    "\n",
    "### Task 2.8 (1 point)\n",
    "\n",
    "Complete the implementation of Newton's method."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 162,
   "id": "a785e84d",
   "metadata": {},
   "outputs": [],
   "source": [
    "import scipy\n",
    "\n",
    "def newton(oracle, x_0, learning_rate, tolerance=1e-5, max_iter=100, trace=False, display=False):\n",
    "    \"\"\"\n",
    "    Newton's optimization method.\n",
    "\n",
    "    Parameters\n",
    "    ----------\n",
    "    oracle : BaseSmoothOracle-descendant object\n",
    "        Oracle with .func(), .grad() and .hess() methods implemented for computing\n",
    "        function value, its gradient and Hessian respectively. If the Hessian\n",
    "        returned by the oracle is not positive-definite method stops with message=\"newton_direction_error\"\n",
    "    x_0 : np.array\n",
    "        Starting point for optimization algorithm\n",
    "    learning_rate : float\n",
    "        Learning rate.\n",
    "    tolerance : float\n",
    "        Epsilon value for stopping criterion.\n",
    "    max_iter : int\n",
    "        Maximum number of iterations.\n",
    "    trace : bool\n",
    "        If True, the progress information is appended into history dictionary during training.\n",
    "        Otherwise None is returned instead of history.\n",
    "    display : bool\n",
    "        If True, debug information is displayed during optimization.\n",
    "\n",
    "    Returns\n",
    "    -------\n",
    "    x_star : np.array\n",
    "        The point found by the optimization procedure\n",
    "    message : string\n",
    "        'success' or the description of error:\n",
    "            - 'iterations_exceeded': if after max_iter iterations of the method x_k still doesn't satisfy\n",
    "                the stopping criterion.\n",
    "            - 'newton_direction_error': in case of failure of solving linear system with Hessian matrix (e.g. non-invertible matrix).\n",
    "            - 'computational_error': in case of getting Infinity or None value during the computations.\n",
    "    history : dictionary of lists or None\n",
    "        Dictionary containing the progress information or None if trace=False.\n",
    "        Dictionary has to be organized as follows:\n",
    "            - history['time'] : list of floats, containing time passed from the start of the method\n",
    "            - history['func'] : list of function values f(x_k) on every step of the algorithm\n",
    "            - history['grad_norm'] : list of values Euclidian norms ||g(x_k)|| of the gradient on every step of the algorithm\n",
    "            - history['x'] : list of np.arrays, containing the trajectory of the algorithm. ONLY STORE IF x.size <= 2\n",
    "\n",
    "    Example:\n",
    "    --------\n",
    "    >> oracle = QuadraticOracle(np.eye(5), np.arange(5))\n",
    "    >> x_opt, message, history = newton(oracle, np.zeros(5), line_search_options={'method': 'Constant', 'c': 1.0})\n",
    "    >> print('Found optimal point: {}'.format(x_opt))\n",
    "       Found optimal point: [ 0.  1.  2.  3.  4.]\n",
    "    \"\"\"\n",
    "    history = defaultdict(list) if trace else None\n",
    "    x_k = np.copy(x_0)\n",
    "    grad_at_x_0 = oracle.grad(x_0)\n",
    "\n",
    "    INF = 1e100\n",
    "    start_time = datetime.now()\n",
    "\n",
    "    for i in range(max_iter + 1): \n",
    "        grad_at_x_k = oracle.grad(x_k)\n",
    "        hess_at_x_k = oracle.hess(x_k)  \n",
    "\n",
    "        if np.any(np.abs(x_k) > INF) or np.any(np.abs(grad_at_x_k) > INF):\n",
    "            return x_k, 'computational_error', history\n",
    "\n",
    "        if trace:\n",
    "            history['time'].append((datetime.now() - start_time).seconds)\n",
    "            history['func'].append(oracle.func(x_k))\n",
    "            history['grad_norm'].append(np.linalg.norm(grad_at_x_k))\n",
    "            if x_k.shape[0] <= 2:\n",
    "                history['x'].append(np.array(x_k))\n",
    "\n",
    "        if display:\n",
    "            print(\"iteration {}: |x_k-x_0| = {}, f(x_k) = {}, |grad(f(x_k))| = {}\".format(\n",
    "                i, np.linalg.norm(x_k - x_0), oracle.func(x_k), np.linalg.norm(grad_at_x_k))\n",
    "            )\n",
    "\n",
    "        # YOUR CODE HERE\n",
    "        pass"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "806ae164",
   "metadata": {},
   "source": [
    "### Task 2.9 (1 point)\n",
    "\n",
    "Apply Newton's methods to the previous tasks:\n",
    "\n",
    "* quadratic function\n",
    "* simple linear regression trained on `boston` dataset\n",
    "* simple logistic regression trained on `breast_cancer` dataset\n",
    "\n",
    "Compare the number of iterations and time execution of GD and Newton methods in this examples. Visualize your results."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "2d5fca12",
   "metadata": {},
   "outputs": [],
   "source": [
    "# YOUR CODE HERE"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "0884c5bf",
   "metadata": {},
   "source": [
    "## GD vs Newton\n",
    "\n",
    "### Task 2.10 (1 point)\n",
    "\n",
    "Run both gradient descent and Newton's methods on **full** `boston` and `breast_cancer` datasets. Do they converge? How many iterations are required for convergence? How much time? Justify your answers by numeric experiments and visualizations."
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.12.4"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
